@@ -1,4 +1,8 @@
 #include <libint2.h>
+#ifdef __cplusplus
 extern "C" {
+#endif
 void HRRPart0bra0ket0psg(const Libint_t* inteval, LIBINT2_REALTYPE* target, const LIBINT2_REALTYPE* src0, const LIBINT2_REALTYPE* src1, int lowdim);
+#ifdef __cplusplus
 };
+#endif
