@@ -1,3 +1,7 @@
+#ifdef __cplusplus
 extern "C" {
+#endif
 void OSVRRP0InBra_aB_pd__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(const Libint_t* inteval, LIBINT2_REALTYPE* target, const LIBINT2_REALTYPE* src0, const LIBINT2_REALTYPE* src1, const LIBINT2_REALTYPE* src2, const LIBINT2_REALTYPE* src3, const LIBINT2_REALTYPE* src4);
+#ifdef __cplusplus
 };
+#endif
