@@ -1,4 +1,8 @@
 #include <libint2.h>
+#ifdef __cplusplus
 extern "C" {
+#endif
 void _aB_G__0__K__1___TwoPRep_F__0__S__1___Ab__up_0_prereq(const Libint_t* inteval, LIBINT2_REALTYPE* parent_stack);
+#ifdef __cplusplus
 };
+#endif
