@@ -1,4 +1,8 @@
 #include <libint2.h>
+#ifdef __cplusplus
 extern "C" {
+#endif
 void _aB_K__0__I__1___TwoPRep_P__0__H__1___Ab__up_0_prereq(const Libint_t* inteval, LIBINT2_REALTYPE* parent_stack);
+#ifdef __cplusplus
 };
+#endif
