@@ -1,4 +1,8 @@
 #include <libint2.h>
+#ifdef __cplusplus
 extern "C" {
+#endif
 void _aB_P__0__K__1___TwoPRep_P__0__P__1___Ab__up_0(const Libint_t* inteval);
+#ifdef __cplusplus
 };
+#endif
