@@ -1,6 +1,10 @@
 #ifndef _libint2_libint2ifaceint_h_
 #define _libint2_libint2ifaceint_h_
 
+#include <./_aB_S__0__S__1___TwoPRep_S__0__S__1___Ab__up_0.h>
+
+#include <./_aB_S__0__S__1___TwoPRep_S__0__S__1___Ab__up_0_prereq.h>
+
 #include <./_aB_S__0__P__1___TwoPRep_S__0__S__1___Ab__up_0.h>
 
 #include <./_aB_S__0__P__1___TwoPRep_S__0__S__1___Ab__up_0_prereq.h>
