@@ -1,434 +1,19 @@
 #include <libint2.h>
 
+#ifdef __cplusplus
 extern "C" {
+#endif
 void HRRPart1bra0ket0lp(const Libint_t* inteval, LIBINT2_REALTYPE* target, const LIBINT2_REALTYPE* src0, const LIBINT2_REALTYPE* src1, int highdim) {
 
 LIBINT2_REALTYPE*const  stack = target;
+#ifdef __INTEL_COMPILER
+#pragma ivdep
+#endif
 for(int hsi = 0; hsi<highdim; hsi++) {
 {
 const int lsi = 0;
 {
 const int vi = 0;
-LIBINT2_REALTYPE fp1;
-fp1 = inteval->CD_z[vi] * src1[((hsi*45+44)*1+lsi)*1];
-LIBINT2_REALTYPE fp0;
-fp0 = src0[((hsi*55+54)*1+lsi)*1] + fp1;
-target[((hsi*135+134)*1+lsi)*1] = fp0;
-LIBINT2_REALTYPE fp3;
-fp3 = inteval->CD_y[vi] * src1[((hsi*45+44)*1+lsi)*1];
-LIBINT2_REALTYPE fp2;
-fp2 = src0[((hsi*55+53)*1+lsi)*1] + fp3;
-target[((hsi*135+133)*1+lsi)*1] = fp2;
-LIBINT2_REALTYPE fp5;
-fp5 = inteval->CD_x[vi] * src1[((hsi*45+44)*1+lsi)*1];
-LIBINT2_REALTYPE fp4;
-fp4 = src0[((hsi*55+44)*1+lsi)*1] + fp5;
-target[((hsi*135+132)*1+lsi)*1] = fp4;
-LIBINT2_REALTYPE fp7;
-fp7 = inteval->CD_z[vi] * src1[((hsi*45+43)*1+lsi)*1];
-LIBINT2_REALTYPE fp6;
-fp6 = src0[((hsi*55+53)*1+lsi)*1] + fp7;
-target[((hsi*135+131)*1+lsi)*1] = fp6;
-LIBINT2_REALTYPE fp9;
-fp9 = inteval->CD_y[vi] * src1[((hsi*45+43)*1+lsi)*1];
-LIBINT2_REALTYPE fp8;
-fp8 = src0[((hsi*55+52)*1+lsi)*1] + fp9;
-target[((hsi*135+130)*1+lsi)*1] = fp8;
-LIBINT2_REALTYPE fp11;
-fp11 = inteval->CD_x[vi] * src1[((hsi*45+43)*1+lsi)*1];
-LIBINT2_REALTYPE fp10;
-fp10 = src0[((hsi*55+43)*1+lsi)*1] + fp11;
-target[((hsi*135+129)*1+lsi)*1] = fp10;
-LIBINT2_REALTYPE fp13;
-fp13 = inteval->CD_z[vi] * src1[((hsi*45+42)*1+lsi)*1];
-LIBINT2_REALTYPE fp12;
-fp12 = src0[((hsi*55+52)*1+lsi)*1] + fp13;
-target[((hsi*135+128)*1+lsi)*1] = fp12;
-LIBINT2_REALTYPE fp15;
-fp15 = inteval->CD_y[vi] * src1[((hsi*45+42)*1+lsi)*1];
-LIBINT2_REALTYPE fp14;
-fp14 = src0[((hsi*55+51)*1+lsi)*1] + fp15;
-target[((hsi*135+127)*1+lsi)*1] = fp14;
-LIBINT2_REALTYPE fp17;
-fp17 = inteval->CD_x[vi] * src1[((hsi*45+42)*1+lsi)*1];
-LIBINT2_REALTYPE fp16;
-fp16 = src0[((hsi*55+42)*1+lsi)*1] + fp17;
-target[((hsi*135+126)*1+lsi)*1] = fp16;
-LIBINT2_REALTYPE fp19;
-fp19 = inteval->CD_z[vi] * src1[((hsi*45+41)*1+lsi)*1];
-LIBINT2_REALTYPE fp18;
-fp18 = src0[((hsi*55+51)*1+lsi)*1] + fp19;
-target[((hsi*135+125)*1+lsi)*1] = fp18;
-LIBINT2_REALTYPE fp21;
-fp21 = inteval->CD_y[vi] * src1[((hsi*45+41)*1+lsi)*1];
-LIBINT2_REALTYPE fp20;
-fp20 = src0[((hsi*55+50)*1+lsi)*1] + fp21;
-target[((hsi*135+124)*1+lsi)*1] = fp20;
-LIBINT2_REALTYPE fp23;
-fp23 = inteval->CD_x[vi] * src1[((hsi*45+41)*1+lsi)*1];
-LIBINT2_REALTYPE fp22;
-fp22 = src0[((hsi*55+41)*1+lsi)*1] + fp23;
-target[((hsi*135+123)*1+lsi)*1] = fp22;
-LIBINT2_REALTYPE fp25;
-fp25 = inteval->CD_z[vi] * src1[((hsi*45+40)*1+lsi)*1];
-LIBINT2_REALTYPE fp24;
-fp24 = src0[((hsi*55+50)*1+lsi)*1] + fp25;
-target[((hsi*135+122)*1+lsi)*1] = fp24;
-LIBINT2_REALTYPE fp27;
-fp27 = inteval->CD_y[vi] * src1[((hsi*45+40)*1+lsi)*1];
-LIBINT2_REALTYPE fp26;
-fp26 = src0[((hsi*55+49)*1+lsi)*1] + fp27;
-target[((hsi*135+121)*1+lsi)*1] = fp26;
-LIBINT2_REALTYPE fp29;
-fp29 = inteval->CD_x[vi] * src1[((hsi*45+40)*1+lsi)*1];
-LIBINT2_REALTYPE fp28;
-fp28 = src0[((hsi*55+40)*1+lsi)*1] + fp29;
-target[((hsi*135+120)*1+lsi)*1] = fp28;
-LIBINT2_REALTYPE fp31;
-fp31 = inteval->CD_z[vi] * src1[((hsi*45+39)*1+lsi)*1];
-LIBINT2_REALTYPE fp30;
-fp30 = src0[((hsi*55+49)*1+lsi)*1] + fp31;
-target[((hsi*135+119)*1+lsi)*1] = fp30;
-LIBINT2_REALTYPE fp33;
-fp33 = inteval->CD_y[vi] * src1[((hsi*45+39)*1+lsi)*1];
-LIBINT2_REALTYPE fp32;
-fp32 = src0[((hsi*55+48)*1+lsi)*1] + fp33;
-target[((hsi*135+118)*1+lsi)*1] = fp32;
-LIBINT2_REALTYPE fp35;
-fp35 = inteval->CD_x[vi] * src1[((hsi*45+39)*1+lsi)*1];
-LIBINT2_REALTYPE fp34;
-fp34 = src0[((hsi*55+39)*1+lsi)*1] + fp35;
-target[((hsi*135+117)*1+lsi)*1] = fp34;
-LIBINT2_REALTYPE fp37;
-fp37 = inteval->CD_z[vi] * src1[((hsi*45+38)*1+lsi)*1];
-LIBINT2_REALTYPE fp36;
-fp36 = src0[((hsi*55+48)*1+lsi)*1] + fp37;
-target[((hsi*135+116)*1+lsi)*1] = fp36;
-LIBINT2_REALTYPE fp39;
-fp39 = inteval->CD_y[vi] * src1[((hsi*45+38)*1+lsi)*1];
-LIBINT2_REALTYPE fp38;
-fp38 = src0[((hsi*55+47)*1+lsi)*1] + fp39;
-target[((hsi*135+115)*1+lsi)*1] = fp38;
-LIBINT2_REALTYPE fp41;
-fp41 = inteval->CD_x[vi] * src1[((hsi*45+38)*1+lsi)*1];
-LIBINT2_REALTYPE fp40;
-fp40 = src0[((hsi*55+38)*1+lsi)*1] + fp41;
-target[((hsi*135+114)*1+lsi)*1] = fp40;
-LIBINT2_REALTYPE fp43;
-fp43 = inteval->CD_z[vi] * src1[((hsi*45+37)*1+lsi)*1];
-LIBINT2_REALTYPE fp42;
-fp42 = src0[((hsi*55+47)*1+lsi)*1] + fp43;
-target[((hsi*135+113)*1+lsi)*1] = fp42;
-LIBINT2_REALTYPE fp45;
-fp45 = inteval->CD_y[vi] * src1[((hsi*45+37)*1+lsi)*1];
-LIBINT2_REALTYPE fp44;
-fp44 = src0[((hsi*55+46)*1+lsi)*1] + fp45;
-target[((hsi*135+112)*1+lsi)*1] = fp44;
-LIBINT2_REALTYPE fp47;
-fp47 = inteval->CD_x[vi] * src1[((hsi*45+37)*1+lsi)*1];
-LIBINT2_REALTYPE fp46;
-fp46 = src0[((hsi*55+37)*1+lsi)*1] + fp47;
-target[((hsi*135+111)*1+lsi)*1] = fp46;
-LIBINT2_REALTYPE fp49;
-fp49 = inteval->CD_z[vi] * src1[((hsi*45+36)*1+lsi)*1];
-LIBINT2_REALTYPE fp48;
-fp48 = src0[((hsi*55+46)*1+lsi)*1] + fp49;
-target[((hsi*135+110)*1+lsi)*1] = fp48;
-LIBINT2_REALTYPE fp51;
-fp51 = inteval->CD_y[vi] * src1[((hsi*45+36)*1+lsi)*1];
-LIBINT2_REALTYPE fp50;
-fp50 = src0[((hsi*55+45)*1+lsi)*1] + fp51;
-target[((hsi*135+109)*1+lsi)*1] = fp50;
-LIBINT2_REALTYPE fp53;
-fp53 = inteval->CD_x[vi] * src1[((hsi*45+36)*1+lsi)*1];
-LIBINT2_REALTYPE fp52;
-fp52 = src0[((hsi*55+36)*1+lsi)*1] + fp53;
-target[((hsi*135+108)*1+lsi)*1] = fp52;
-LIBINT2_REALTYPE fp55;
-fp55 = inteval->CD_z[vi] * src1[((hsi*45+35)*1+lsi)*1];
-LIBINT2_REALTYPE fp54;
-fp54 = src0[((hsi*55+44)*1+lsi)*1] + fp55;
-target[((hsi*135+107)*1+lsi)*1] = fp54;
-LIBINT2_REALTYPE fp57;
-fp57 = inteval->CD_y[vi] * src1[((hsi*45+35)*1+lsi)*1];
-LIBINT2_REALTYPE fp56;
-fp56 = src0[((hsi*55+43)*1+lsi)*1] + fp57;
-target[((hsi*135+106)*1+lsi)*1] = fp56;
-LIBINT2_REALTYPE fp59;
-fp59 = inteval->CD_x[vi] * src1[((hsi*45+35)*1+lsi)*1];
-LIBINT2_REALTYPE fp58;
-fp58 = src0[((hsi*55+35)*1+lsi)*1] + fp59;
-target[((hsi*135+105)*1+lsi)*1] = fp58;
-LIBINT2_REALTYPE fp61;
-fp61 = inteval->CD_z[vi] * src1[((hsi*45+34)*1+lsi)*1];
-LIBINT2_REALTYPE fp60;
-fp60 = src0[((hsi*55+43)*1+lsi)*1] + fp61;
-target[((hsi*135+104)*1+lsi)*1] = fp60;
-LIBINT2_REALTYPE fp63;
-fp63 = inteval->CD_y[vi] * src1[((hsi*45+34)*1+lsi)*1];
-LIBINT2_REALTYPE fp62;
-fp62 = src0[((hsi*55+42)*1+lsi)*1] + fp63;
-target[((hsi*135+103)*1+lsi)*1] = fp62;
-LIBINT2_REALTYPE fp65;
-fp65 = inteval->CD_x[vi] * src1[((hsi*45+34)*1+lsi)*1];
-LIBINT2_REALTYPE fp64;
-fp64 = src0[((hsi*55+34)*1+lsi)*1] + fp65;
-target[((hsi*135+102)*1+lsi)*1] = fp64;
-LIBINT2_REALTYPE fp67;
-fp67 = inteval->CD_z[vi] * src1[((hsi*45+33)*1+lsi)*1];
-LIBINT2_REALTYPE fp66;
-fp66 = src0[((hsi*55+42)*1+lsi)*1] + fp67;
-target[((hsi*135+101)*1+lsi)*1] = fp66;
-LIBINT2_REALTYPE fp69;
-fp69 = inteval->CD_y[vi] * src1[((hsi*45+33)*1+lsi)*1];
-LIBINT2_REALTYPE fp68;
-fp68 = src0[((hsi*55+41)*1+lsi)*1] + fp69;
-target[((hsi*135+100)*1+lsi)*1] = fp68;
-LIBINT2_REALTYPE fp71;
-fp71 = inteval->CD_x[vi] * src1[((hsi*45+33)*1+lsi)*1];
-LIBINT2_REALTYPE fp70;
-fp70 = src0[((hsi*55+33)*1+lsi)*1] + fp71;
-target[((hsi*135+99)*1+lsi)*1] = fp70;
-LIBINT2_REALTYPE fp73;
-fp73 = inteval->CD_z[vi] * src1[((hsi*45+32)*1+lsi)*1];
-LIBINT2_REALTYPE fp72;
-fp72 = src0[((hsi*55+41)*1+lsi)*1] + fp73;
-target[((hsi*135+98)*1+lsi)*1] = fp72;
-LIBINT2_REALTYPE fp75;
-fp75 = inteval->CD_y[vi] * src1[((hsi*45+32)*1+lsi)*1];
-LIBINT2_REALTYPE fp74;
-fp74 = src0[((hsi*55+40)*1+lsi)*1] + fp75;
-target[((hsi*135+97)*1+lsi)*1] = fp74;
-LIBINT2_REALTYPE fp77;
-fp77 = inteval->CD_x[vi] * src1[((hsi*45+32)*1+lsi)*1];
-LIBINT2_REALTYPE fp76;
-fp76 = src0[((hsi*55+32)*1+lsi)*1] + fp77;
-target[((hsi*135+96)*1+lsi)*1] = fp76;
-LIBINT2_REALTYPE fp79;
-fp79 = inteval->CD_z[vi] * src1[((hsi*45+31)*1+lsi)*1];
-LIBINT2_REALTYPE fp78;
-fp78 = src0[((hsi*55+40)*1+lsi)*1] + fp79;
-target[((hsi*135+95)*1+lsi)*1] = fp78;
-LIBINT2_REALTYPE fp81;
-fp81 = inteval->CD_y[vi] * src1[((hsi*45+31)*1+lsi)*1];
-LIBINT2_REALTYPE fp80;
-fp80 = src0[((hsi*55+39)*1+lsi)*1] + fp81;
-target[((hsi*135+94)*1+lsi)*1] = fp80;
-LIBINT2_REALTYPE fp83;
-fp83 = inteval->CD_x[vi] * src1[((hsi*45+31)*1+lsi)*1];
-LIBINT2_REALTYPE fp82;
-fp82 = src0[((hsi*55+31)*1+lsi)*1] + fp83;
-target[((hsi*135+93)*1+lsi)*1] = fp82;
-LIBINT2_REALTYPE fp85;
-fp85 = inteval->CD_z[vi] * src1[((hsi*45+30)*1+lsi)*1];
-LIBINT2_REALTYPE fp84;
-fp84 = src0[((hsi*55+39)*1+lsi)*1] + fp85;
-target[((hsi*135+92)*1+lsi)*1] = fp84;
-LIBINT2_REALTYPE fp87;
-fp87 = inteval->CD_y[vi] * src1[((hsi*45+30)*1+lsi)*1];
-LIBINT2_REALTYPE fp86;
-fp86 = src0[((hsi*55+38)*1+lsi)*1] + fp87;
-target[((hsi*135+91)*1+lsi)*1] = fp86;
-LIBINT2_REALTYPE fp89;
-fp89 = inteval->CD_x[vi] * src1[((hsi*45+30)*1+lsi)*1];
-LIBINT2_REALTYPE fp88;
-fp88 = src0[((hsi*55+30)*1+lsi)*1] + fp89;
-target[((hsi*135+90)*1+lsi)*1] = fp88;
-LIBINT2_REALTYPE fp91;
-fp91 = inteval->CD_z[vi] * src1[((hsi*45+29)*1+lsi)*1];
-LIBINT2_REALTYPE fp90;
-fp90 = src0[((hsi*55+38)*1+lsi)*1] + fp91;
-target[((hsi*135+89)*1+lsi)*1] = fp90;
-LIBINT2_REALTYPE fp93;
-fp93 = inteval->CD_y[vi] * src1[((hsi*45+29)*1+lsi)*1];
-LIBINT2_REALTYPE fp92;
-fp92 = src0[((hsi*55+37)*1+lsi)*1] + fp93;
-target[((hsi*135+88)*1+lsi)*1] = fp92;
-LIBINT2_REALTYPE fp95;
-fp95 = inteval->CD_x[vi] * src1[((hsi*45+29)*1+lsi)*1];
-LIBINT2_REALTYPE fp94;
-fp94 = src0[((hsi*55+29)*1+lsi)*1] + fp95;
-target[((hsi*135+87)*1+lsi)*1] = fp94;
-LIBINT2_REALTYPE fp97;
-fp97 = inteval->CD_z[vi] * src1[((hsi*45+28)*1+lsi)*1];
-LIBINT2_REALTYPE fp96;
-fp96 = src0[((hsi*55+37)*1+lsi)*1] + fp97;
-target[((hsi*135+86)*1+lsi)*1] = fp96;
-LIBINT2_REALTYPE fp99;
-fp99 = inteval->CD_y[vi] * src1[((hsi*45+28)*1+lsi)*1];
-LIBINT2_REALTYPE fp98;
-fp98 = src0[((hsi*55+36)*1+lsi)*1] + fp99;
-target[((hsi*135+85)*1+lsi)*1] = fp98;
-LIBINT2_REALTYPE fp101;
-fp101 = inteval->CD_x[vi] * src1[((hsi*45+28)*1+lsi)*1];
-LIBINT2_REALTYPE fp100;
-fp100 = src0[((hsi*55+28)*1+lsi)*1] + fp101;
-target[((hsi*135+84)*1+lsi)*1] = fp100;
-LIBINT2_REALTYPE fp103;
-fp103 = inteval->CD_z[vi] * src1[((hsi*45+27)*1+lsi)*1];
-LIBINT2_REALTYPE fp102;
-fp102 = src0[((hsi*55+35)*1+lsi)*1] + fp103;
-target[((hsi*135+83)*1+lsi)*1] = fp102;
-LIBINT2_REALTYPE fp105;
-fp105 = inteval->CD_y[vi] * src1[((hsi*45+27)*1+lsi)*1];
-LIBINT2_REALTYPE fp104;
-fp104 = src0[((hsi*55+34)*1+lsi)*1] + fp105;
-target[((hsi*135+82)*1+lsi)*1] = fp104;
-LIBINT2_REALTYPE fp107;
-fp107 = inteval->CD_x[vi] * src1[((hsi*45+27)*1+lsi)*1];
-LIBINT2_REALTYPE fp106;
-fp106 = src0[((hsi*55+27)*1+lsi)*1] + fp107;
-target[((hsi*135+81)*1+lsi)*1] = fp106;
-LIBINT2_REALTYPE fp109;
-fp109 = inteval->CD_z[vi] * src1[((hsi*45+26)*1+lsi)*1];
-LIBINT2_REALTYPE fp108;
-fp108 = src0[((hsi*55+34)*1+lsi)*1] + fp109;
-target[((hsi*135+80)*1+lsi)*1] = fp108;
-LIBINT2_REALTYPE fp111;
-fp111 = inteval->CD_y[vi] * src1[((hsi*45+26)*1+lsi)*1];
-LIBINT2_REALTYPE fp110;
-fp110 = src0[((hsi*55+33)*1+lsi)*1] + fp111;
-target[((hsi*135+79)*1+lsi)*1] = fp110;
-LIBINT2_REALTYPE fp113;
-fp113 = inteval->CD_x[vi] * src1[((hsi*45+26)*1+lsi)*1];
-LIBINT2_REALTYPE fp112;
-fp112 = src0[((hsi*55+26)*1+lsi)*1] + fp113;
-target[((hsi*135+78)*1+lsi)*1] = fp112;
-LIBINT2_REALTYPE fp115;
-fp115 = inteval->CD_z[vi] * src1[((hsi*45+25)*1+lsi)*1];
-LIBINT2_REALTYPE fp114;
-fp114 = src0[((hsi*55+33)*1+lsi)*1] + fp115;
-target[((hsi*135+77)*1+lsi)*1] = fp114;
-LIBINT2_REALTYPE fp117;
-fp117 = inteval->CD_y[vi] * src1[((hsi*45+25)*1+lsi)*1];
-LIBINT2_REALTYPE fp116;
-fp116 = src0[((hsi*55+32)*1+lsi)*1] + fp117;
-target[((hsi*135+76)*1+lsi)*1] = fp116;
-LIBINT2_REALTYPE fp119;
-fp119 = inteval->CD_x[vi] * src1[((hsi*45+25)*1+lsi)*1];
-LIBINT2_REALTYPE fp118;
-fp118 = src0[((hsi*55+25)*1+lsi)*1] + fp119;
-target[((hsi*135+75)*1+lsi)*1] = fp118;
-LIBINT2_REALTYPE fp121;
-fp121 = inteval->CD_z[vi] * src1[((hsi*45+24)*1+lsi)*1];
-LIBINT2_REALTYPE fp120;
-fp120 = src0[((hsi*55+32)*1+lsi)*1] + fp121;
-target[((hsi*135+74)*1+lsi)*1] = fp120;
-LIBINT2_REALTYPE fp123;
-fp123 = inteval->CD_y[vi] * src1[((hsi*45+24)*1+lsi)*1];
-LIBINT2_REALTYPE fp122;
-fp122 = src0[((hsi*55+31)*1+lsi)*1] + fp123;
-target[((hsi*135+73)*1+lsi)*1] = fp122;
-LIBINT2_REALTYPE fp125;
-fp125 = inteval->CD_x[vi] * src1[((hsi*45+24)*1+lsi)*1];
-LIBINT2_REALTYPE fp124;
-fp124 = src0[((hsi*55+24)*1+lsi)*1] + fp125;
-target[((hsi*135+72)*1+lsi)*1] = fp124;
-LIBINT2_REALTYPE fp127;
-fp127 = inteval->CD_z[vi] * src1[((hsi*45+23)*1+lsi)*1];
-LIBINT2_REALTYPE fp126;
-fp126 = src0[((hsi*55+31)*1+lsi)*1] + fp127;
-target[((hsi*135+71)*1+lsi)*1] = fp126;
-LIBINT2_REALTYPE fp129;
-fp129 = inteval->CD_y[vi] * src1[((hsi*45+23)*1+lsi)*1];
-LIBINT2_REALTYPE fp128;
-fp128 = src0[((hsi*55+30)*1+lsi)*1] + fp129;
-target[((hsi*135+70)*1+lsi)*1] = fp128;
-LIBINT2_REALTYPE fp131;
-fp131 = inteval->CD_x[vi] * src1[((hsi*45+23)*1+lsi)*1];
-LIBINT2_REALTYPE fp130;
-fp130 = src0[((hsi*55+23)*1+lsi)*1] + fp131;
-target[((hsi*135+69)*1+lsi)*1] = fp130;
-LIBINT2_REALTYPE fp133;
-fp133 = inteval->CD_z[vi] * src1[((hsi*45+22)*1+lsi)*1];
-LIBINT2_REALTYPE fp132;
-fp132 = src0[((hsi*55+30)*1+lsi)*1] + fp133;
-target[((hsi*135+68)*1+lsi)*1] = fp132;
-LIBINT2_REALTYPE fp135;
-fp135 = inteval->CD_y[vi] * src1[((hsi*45+22)*1+lsi)*1];
-LIBINT2_REALTYPE fp134;
-fp134 = src0[((hsi*55+29)*1+lsi)*1] + fp135;
-target[((hsi*135+67)*1+lsi)*1] = fp134;
-LIBINT2_REALTYPE fp137;
-fp137 = inteval->CD_x[vi] * src1[((hsi*45+22)*1+lsi)*1];
-LIBINT2_REALTYPE fp136;
-fp136 = src0[((hsi*55+22)*1+lsi)*1] + fp137;
-target[((hsi*135+66)*1+lsi)*1] = fp136;
-LIBINT2_REALTYPE fp139;
-fp139 = inteval->CD_z[vi] * src1[((hsi*45+21)*1+lsi)*1];
-LIBINT2_REALTYPE fp138;
-fp138 = src0[((hsi*55+29)*1+lsi)*1] + fp139;
-target[((hsi*135+65)*1+lsi)*1] = fp138;
-LIBINT2_REALTYPE fp141;
-fp141 = inteval->CD_y[vi] * src1[((hsi*45+21)*1+lsi)*1];
-LIBINT2_REALTYPE fp140;
-fp140 = src0[((hsi*55+28)*1+lsi)*1] + fp141;
-target[((hsi*135+64)*1+lsi)*1] = fp140;
-LIBINT2_REALTYPE fp143;
-fp143 = inteval->CD_x[vi] * src1[((hsi*45+21)*1+lsi)*1];
-LIBINT2_REALTYPE fp142;
-fp142 = src0[((hsi*55+21)*1+lsi)*1] + fp143;
-target[((hsi*135+63)*1+lsi)*1] = fp142;
-LIBINT2_REALTYPE fp145;
-fp145 = inteval->CD_z[vi] * src1[((hsi*45+20)*1+lsi)*1];
-LIBINT2_REALTYPE fp144;
-fp144 = src0[((hsi*55+27)*1+lsi)*1] + fp145;
-target[((hsi*135+62)*1+lsi)*1] = fp144;
-LIBINT2_REALTYPE fp147;
-fp147 = inteval->CD_y[vi] * src1[((hsi*45+20)*1+lsi)*1];
-LIBINT2_REALTYPE fp146;
-fp146 = src0[((hsi*55+26)*1+lsi)*1] + fp147;
-target[((hsi*135+61)*1+lsi)*1] = fp146;
-LIBINT2_REALTYPE fp149;
-fp149 = inteval->CD_x[vi] * src1[((hsi*45+20)*1+lsi)*1];
-LIBINT2_REALTYPE fp148;
-fp148 = src0[((hsi*55+20)*1+lsi)*1] + fp149;
-target[((hsi*135+60)*1+lsi)*1] = fp148;
-LIBINT2_REALTYPE fp151;
-fp151 = inteval->CD_z[vi] * src1[((hsi*45+19)*1+lsi)*1];
-LIBINT2_REALTYPE fp150;
-fp150 = src0[((hsi*55+26)*1+lsi)*1] + fp151;
-target[((hsi*135+59)*1+lsi)*1] = fp150;
-LIBINT2_REALTYPE fp153;
-fp153 = inteval->CD_y[vi] * src1[((hsi*45+19)*1+lsi)*1];
-LIBINT2_REALTYPE fp152;
-fp152 = src0[((hsi*55+25)*1+lsi)*1] + fp153;
-target[((hsi*135+58)*1+lsi)*1] = fp152;
-LIBINT2_REALTYPE fp155;
-fp155 = inteval->CD_x[vi] * src1[((hsi*45+19)*1+lsi)*1];
-LIBINT2_REALTYPE fp154;
-fp154 = src0[((hsi*55+19)*1+lsi)*1] + fp155;
-target[((hsi*135+57)*1+lsi)*1] = fp154;
-LIBINT2_REALTYPE fp157;
-fp157 = inteval->CD_z[vi] * src1[((hsi*45+18)*1+lsi)*1];
-LIBINT2_REALTYPE fp156;
-fp156 = src0[((hsi*55+25)*1+lsi)*1] + fp157;
-target[((hsi*135+56)*1+lsi)*1] = fp156;
-LIBINT2_REALTYPE fp159;
-fp159 = inteval->CD_y[vi] * src1[((hsi*45+18)*1+lsi)*1];
-LIBINT2_REALTYPE fp158;
-fp158 = src0[((hsi*55+24)*1+lsi)*1] + fp159;
-target[((hsi*135+55)*1+lsi)*1] = fp158;
-LIBINT2_REALTYPE fp161;
-fp161 = inteval->CD_x[vi] * src1[((hsi*45+18)*1+lsi)*1];
-LIBINT2_REALTYPE fp160;
-fp160 = src0[((hsi*55+18)*1+lsi)*1] + fp161;
-target[((hsi*135+54)*1+lsi)*1] = fp160;
-LIBINT2_REALTYPE fp163;
-fp163 = inteval->CD_z[vi] * src1[((hsi*45+17)*1+lsi)*1];
-LIBINT2_REALTYPE fp162;
-fp162 = src0[((hsi*55+24)*1+lsi)*1] + fp163;
-target[((hsi*135+53)*1+lsi)*1] = fp162;
-LIBINT2_REALTYPE fp165;
-fp165 = inteval->CD_y[vi] * src1[((hsi*45+17)*1+lsi)*1];
-LIBINT2_REALTYPE fp164;
-fp164 = src0[((hsi*55+23)*1+lsi)*1] + fp165;
-target[((hsi*135+52)*1+lsi)*1] = fp164;
-LIBINT2_REALTYPE fp167;
-fp167 = inteval->CD_x[vi] * src1[((hsi*45+17)*1+lsi)*1];
-LIBINT2_REALTYPE fp166;
-fp166 = src0[((hsi*55+17)*1+lsi)*1] + fp167;
-target[((hsi*135+51)*1+lsi)*1] = fp166;
 LIBINT2_REALTYPE fp169;
 fp169 = inteval->CD_z[vi] * src1[((hsi*45+16)*1+lsi)*1];
 LIBINT2_REALTYPE fp168;
@@ -514,91 +99,91 @@ fp201 = inteval->CD_y[vi] * src1[((hsi*45+11)*1+lsi)*1];
 LIBINT2_REALTYPE fp200;
 fp200 = src0[((hsi*55+16)*1+lsi)*1] + fp201;
 target[((hsi*135+34)*1+lsi)*1] = fp200;
-LIBINT2_REALTYPE fp203;
-fp203 = inteval->CD_x[vi] * src1[((hsi*45+11)*1+lsi)*1];
-LIBINT2_REALTYPE fp202;
-fp202 = src0[((hsi*55+11)*1+lsi)*1] + fp203;
-target[((hsi*135+33)*1+lsi)*1] = fp202;
-LIBINT2_REALTYPE fp205;
-fp205 = inteval->CD_z[vi] * src1[((hsi*45+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp204;
-fp204 = src0[((hsi*55+16)*1+lsi)*1] + fp205;
-target[((hsi*135+32)*1+lsi)*1] = fp204;
-LIBINT2_REALTYPE fp207;
-fp207 = inteval->CD_y[vi] * src1[((hsi*45+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp206;
-fp206 = src0[((hsi*55+15)*1+lsi)*1] + fp207;
-target[((hsi*135+31)*1+lsi)*1] = fp206;
-LIBINT2_REALTYPE fp209;
-fp209 = inteval->CD_x[vi] * src1[((hsi*45+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp208;
-fp208 = src0[((hsi*55+10)*1+lsi)*1] + fp209;
-target[((hsi*135+30)*1+lsi)*1] = fp208;
-LIBINT2_REALTYPE fp211;
-fp211 = inteval->CD_z[vi] * src1[((hsi*45+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp210;
-fp210 = src0[((hsi*55+14)*1+lsi)*1] + fp211;
-target[((hsi*135+29)*1+lsi)*1] = fp210;
-LIBINT2_REALTYPE fp213;
-fp213 = inteval->CD_y[vi] * src1[((hsi*45+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp212;
-fp212 = src0[((hsi*55+13)*1+lsi)*1] + fp213;
-target[((hsi*135+28)*1+lsi)*1] = fp212;
-LIBINT2_REALTYPE fp215;
-fp215 = inteval->CD_x[vi] * src1[((hsi*45+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp214;
-fp214 = src0[((hsi*55+9)*1+lsi)*1] + fp215;
-target[((hsi*135+27)*1+lsi)*1] = fp214;
-LIBINT2_REALTYPE fp217;
-fp217 = inteval->CD_z[vi] * src1[((hsi*45+8)*1+lsi)*1];
-LIBINT2_REALTYPE fp216;
-fp216 = src0[((hsi*55+13)*1+lsi)*1] + fp217;
-target[((hsi*135+26)*1+lsi)*1] = fp216;
-LIBINT2_REALTYPE fp219;
-fp219 = inteval->CD_y[vi] * src1[((hsi*45+8)*1+lsi)*1];
-LIBINT2_REALTYPE fp218;
-fp218 = src0[((hsi*55+12)*1+lsi)*1] + fp219;
-target[((hsi*135+25)*1+lsi)*1] = fp218;
-LIBINT2_REALTYPE fp221;
-fp221 = inteval->CD_x[vi] * src1[((hsi*45+8)*1+lsi)*1];
-LIBINT2_REALTYPE fp220;
-fp220 = src0[((hsi*55+8)*1+lsi)*1] + fp221;
-target[((hsi*135+24)*1+lsi)*1] = fp220;
-LIBINT2_REALTYPE fp223;
-fp223 = inteval->CD_z[vi] * src1[((hsi*45+7)*1+lsi)*1];
-LIBINT2_REALTYPE fp222;
-fp222 = src0[((hsi*55+12)*1+lsi)*1] + fp223;
-target[((hsi*135+23)*1+lsi)*1] = fp222;
-LIBINT2_REALTYPE fp225;
-fp225 = inteval->CD_y[vi] * src1[((hsi*45+7)*1+lsi)*1];
-LIBINT2_REALTYPE fp224;
-fp224 = src0[((hsi*55+11)*1+lsi)*1] + fp225;
-target[((hsi*135+22)*1+lsi)*1] = fp224;
-LIBINT2_REALTYPE fp227;
-fp227 = inteval->CD_x[vi] * src1[((hsi*45+7)*1+lsi)*1];
-LIBINT2_REALTYPE fp226;
-fp226 = src0[((hsi*55+7)*1+lsi)*1] + fp227;
-target[((hsi*135+21)*1+lsi)*1] = fp226;
-LIBINT2_REALTYPE fp229;
-fp229 = inteval->CD_z[vi] * src1[((hsi*45+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp228;
-fp228 = src0[((hsi*55+11)*1+lsi)*1] + fp229;
-target[((hsi*135+20)*1+lsi)*1] = fp228;
-LIBINT2_REALTYPE fp231;
-fp231 = inteval->CD_y[vi] * src1[((hsi*45+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp230;
-fp230 = src0[((hsi*55+10)*1+lsi)*1] + fp231;
-target[((hsi*135+19)*1+lsi)*1] = fp230;
-LIBINT2_REALTYPE fp233;
-fp233 = inteval->CD_x[vi] * src1[((hsi*45+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp232;
-fp232 = src0[((hsi*55+6)*1+lsi)*1] + fp233;
-target[((hsi*135+18)*1+lsi)*1] = fp232;
-LIBINT2_REALTYPE fp235;
-fp235 = inteval->CD_z[vi] * src1[((hsi*45+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp234;
-fp234 = src0[((hsi*55+9)*1+lsi)*1] + fp235;
-target[((hsi*135+17)*1+lsi)*1] = fp234;
+LIBINT2_REALTYPE fp135;
+fp135 = inteval->CD_y[vi] * src1[((hsi*45+22)*1+lsi)*1];
+LIBINT2_REALTYPE fp134;
+fp134 = src0[((hsi*55+29)*1+lsi)*1] + fp135;
+target[((hsi*135+67)*1+lsi)*1] = fp134;
+LIBINT2_REALTYPE fp137;
+fp137 = inteval->CD_x[vi] * src1[((hsi*45+22)*1+lsi)*1];
+LIBINT2_REALTYPE fp136;
+fp136 = src0[((hsi*55+22)*1+lsi)*1] + fp137;
+target[((hsi*135+66)*1+lsi)*1] = fp136;
+LIBINT2_REALTYPE fp139;
+fp139 = inteval->CD_z[vi] * src1[((hsi*45+21)*1+lsi)*1];
+LIBINT2_REALTYPE fp138;
+fp138 = src0[((hsi*55+29)*1+lsi)*1] + fp139;
+target[((hsi*135+65)*1+lsi)*1] = fp138;
+LIBINT2_REALTYPE fp141;
+fp141 = inteval->CD_y[vi] * src1[((hsi*45+21)*1+lsi)*1];
+LIBINT2_REALTYPE fp140;
+fp140 = src0[((hsi*55+28)*1+lsi)*1] + fp141;
+target[((hsi*135+64)*1+lsi)*1] = fp140;
+LIBINT2_REALTYPE fp143;
+fp143 = inteval->CD_x[vi] * src1[((hsi*45+21)*1+lsi)*1];
+LIBINT2_REALTYPE fp142;
+fp142 = src0[((hsi*55+21)*1+lsi)*1] + fp143;
+target[((hsi*135+63)*1+lsi)*1] = fp142;
+LIBINT2_REALTYPE fp145;
+fp145 = inteval->CD_z[vi] * src1[((hsi*45+20)*1+lsi)*1];
+LIBINT2_REALTYPE fp144;
+fp144 = src0[((hsi*55+27)*1+lsi)*1] + fp145;
+target[((hsi*135+62)*1+lsi)*1] = fp144;
+LIBINT2_REALTYPE fp147;
+fp147 = inteval->CD_y[vi] * src1[((hsi*45+20)*1+lsi)*1];
+LIBINT2_REALTYPE fp146;
+fp146 = src0[((hsi*55+26)*1+lsi)*1] + fp147;
+target[((hsi*135+61)*1+lsi)*1] = fp146;
+LIBINT2_REALTYPE fp149;
+fp149 = inteval->CD_x[vi] * src1[((hsi*45+20)*1+lsi)*1];
+LIBINT2_REALTYPE fp148;
+fp148 = src0[((hsi*55+20)*1+lsi)*1] + fp149;
+target[((hsi*135+60)*1+lsi)*1] = fp148;
+LIBINT2_REALTYPE fp151;
+fp151 = inteval->CD_z[vi] * src1[((hsi*45+19)*1+lsi)*1];
+LIBINT2_REALTYPE fp150;
+fp150 = src0[((hsi*55+26)*1+lsi)*1] + fp151;
+target[((hsi*135+59)*1+lsi)*1] = fp150;
+LIBINT2_REALTYPE fp153;
+fp153 = inteval->CD_y[vi] * src1[((hsi*45+19)*1+lsi)*1];
+LIBINT2_REALTYPE fp152;
+fp152 = src0[((hsi*55+25)*1+lsi)*1] + fp153;
+target[((hsi*135+58)*1+lsi)*1] = fp152;
+LIBINT2_REALTYPE fp155;
+fp155 = inteval->CD_x[vi] * src1[((hsi*45+19)*1+lsi)*1];
+LIBINT2_REALTYPE fp154;
+fp154 = src0[((hsi*55+19)*1+lsi)*1] + fp155;
+target[((hsi*135+57)*1+lsi)*1] = fp154;
+LIBINT2_REALTYPE fp157;
+fp157 = inteval->CD_z[vi] * src1[((hsi*45+18)*1+lsi)*1];
+LIBINT2_REALTYPE fp156;
+fp156 = src0[((hsi*55+25)*1+lsi)*1] + fp157;
+target[((hsi*135+56)*1+lsi)*1] = fp156;
+LIBINT2_REALTYPE fp159;
+fp159 = inteval->CD_y[vi] * src1[((hsi*45+18)*1+lsi)*1];
+LIBINT2_REALTYPE fp158;
+fp158 = src0[((hsi*55+24)*1+lsi)*1] + fp159;
+target[((hsi*135+55)*1+lsi)*1] = fp158;
+LIBINT2_REALTYPE fp161;
+fp161 = inteval->CD_x[vi] * src1[((hsi*45+18)*1+lsi)*1];
+LIBINT2_REALTYPE fp160;
+fp160 = src0[((hsi*55+18)*1+lsi)*1] + fp161;
+target[((hsi*135+54)*1+lsi)*1] = fp160;
+LIBINT2_REALTYPE fp163;
+fp163 = inteval->CD_z[vi] * src1[((hsi*45+17)*1+lsi)*1];
+LIBINT2_REALTYPE fp162;
+fp162 = src0[((hsi*55+24)*1+lsi)*1] + fp163;
+target[((hsi*135+53)*1+lsi)*1] = fp162;
+LIBINT2_REALTYPE fp165;
+fp165 = inteval->CD_y[vi] * src1[((hsi*45+17)*1+lsi)*1];
+LIBINT2_REALTYPE fp164;
+fp164 = src0[((hsi*55+23)*1+lsi)*1] + fp165;
+target[((hsi*135+52)*1+lsi)*1] = fp164;
+LIBINT2_REALTYPE fp167;
+fp167 = inteval->CD_x[vi] * src1[((hsi*45+17)*1+lsi)*1];
+LIBINT2_REALTYPE fp166;
+fp166 = src0[((hsi*55+17)*1+lsi)*1] + fp167;
+target[((hsi*135+51)*1+lsi)*1] = fp166;
 LIBINT2_REALTYPE fp237;
 fp237 = inteval->CD_y[vi] * src1[((hsi*45+5)*1+lsi)*1];
 LIBINT2_REALTYPE fp236;
@@ -684,6 +269,426 @@ fp269 = inteval->CD_x[vi] * src1[((hsi*45+0)*1+lsi)*1];
 LIBINT2_REALTYPE fp268;
 fp268 = src0[((hsi*55+0)*1+lsi)*1] + fp269;
 target[((hsi*135+0)*1+lsi)*1] = fp268;
+LIBINT2_REALTYPE fp203;
+fp203 = inteval->CD_x[vi] * src1[((hsi*45+11)*1+lsi)*1];
+LIBINT2_REALTYPE fp202;
+fp202 = src0[((hsi*55+11)*1+lsi)*1] + fp203;
+target[((hsi*135+33)*1+lsi)*1] = fp202;
+LIBINT2_REALTYPE fp205;
+fp205 = inteval->CD_z[vi] * src1[((hsi*45+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp204;
+fp204 = src0[((hsi*55+16)*1+lsi)*1] + fp205;
+target[((hsi*135+32)*1+lsi)*1] = fp204;
+LIBINT2_REALTYPE fp207;
+fp207 = inteval->CD_y[vi] * src1[((hsi*45+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp206;
+fp206 = src0[((hsi*55+15)*1+lsi)*1] + fp207;
+target[((hsi*135+31)*1+lsi)*1] = fp206;
+LIBINT2_REALTYPE fp209;
+fp209 = inteval->CD_x[vi] * src1[((hsi*45+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp208;
+fp208 = src0[((hsi*55+10)*1+lsi)*1] + fp209;
+target[((hsi*135+30)*1+lsi)*1] = fp208;
+LIBINT2_REALTYPE fp211;
+fp211 = inteval->CD_z[vi] * src1[((hsi*45+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp210;
+fp210 = src0[((hsi*55+14)*1+lsi)*1] + fp211;
+target[((hsi*135+29)*1+lsi)*1] = fp210;
+LIBINT2_REALTYPE fp213;
+fp213 = inteval->CD_y[vi] * src1[((hsi*45+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp212;
+fp212 = src0[((hsi*55+13)*1+lsi)*1] + fp213;
+target[((hsi*135+28)*1+lsi)*1] = fp212;
+LIBINT2_REALTYPE fp215;
+fp215 = inteval->CD_x[vi] * src1[((hsi*45+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp214;
+fp214 = src0[((hsi*55+9)*1+lsi)*1] + fp215;
+target[((hsi*135+27)*1+lsi)*1] = fp214;
+LIBINT2_REALTYPE fp217;
+fp217 = inteval->CD_z[vi] * src1[((hsi*45+8)*1+lsi)*1];
+LIBINT2_REALTYPE fp216;
+fp216 = src0[((hsi*55+13)*1+lsi)*1] + fp217;
+target[((hsi*135+26)*1+lsi)*1] = fp216;
+LIBINT2_REALTYPE fp219;
+fp219 = inteval->CD_y[vi] * src1[((hsi*45+8)*1+lsi)*1];
+LIBINT2_REALTYPE fp218;
+fp218 = src0[((hsi*55+12)*1+lsi)*1] + fp219;
+target[((hsi*135+25)*1+lsi)*1] = fp218;
+LIBINT2_REALTYPE fp221;
+fp221 = inteval->CD_x[vi] * src1[((hsi*45+8)*1+lsi)*1];
+LIBINT2_REALTYPE fp220;
+fp220 = src0[((hsi*55+8)*1+lsi)*1] + fp221;
+target[((hsi*135+24)*1+lsi)*1] = fp220;
+LIBINT2_REALTYPE fp223;
+fp223 = inteval->CD_z[vi] * src1[((hsi*45+7)*1+lsi)*1];
+LIBINT2_REALTYPE fp222;
+fp222 = src0[((hsi*55+12)*1+lsi)*1] + fp223;
+target[((hsi*135+23)*1+lsi)*1] = fp222;
+LIBINT2_REALTYPE fp225;
+fp225 = inteval->CD_y[vi] * src1[((hsi*45+7)*1+lsi)*1];
+LIBINT2_REALTYPE fp224;
+fp224 = src0[((hsi*55+11)*1+lsi)*1] + fp225;
+target[((hsi*135+22)*1+lsi)*1] = fp224;
+LIBINT2_REALTYPE fp227;
+fp227 = inteval->CD_x[vi] * src1[((hsi*45+7)*1+lsi)*1];
+LIBINT2_REALTYPE fp226;
+fp226 = src0[((hsi*55+7)*1+lsi)*1] + fp227;
+target[((hsi*135+21)*1+lsi)*1] = fp226;
+LIBINT2_REALTYPE fp229;
+fp229 = inteval->CD_z[vi] * src1[((hsi*45+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp228;
+fp228 = src0[((hsi*55+11)*1+lsi)*1] + fp229;
+target[((hsi*135+20)*1+lsi)*1] = fp228;
+LIBINT2_REALTYPE fp231;
+fp231 = inteval->CD_y[vi] * src1[((hsi*45+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp230;
+fp230 = src0[((hsi*55+10)*1+lsi)*1] + fp231;
+target[((hsi*135+19)*1+lsi)*1] = fp230;
+LIBINT2_REALTYPE fp233;
+fp233 = inteval->CD_x[vi] * src1[((hsi*45+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp232;
+fp232 = src0[((hsi*55+6)*1+lsi)*1] + fp233;
+target[((hsi*135+18)*1+lsi)*1] = fp232;
+LIBINT2_REALTYPE fp235;
+fp235 = inteval->CD_z[vi] * src1[((hsi*45+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp234;
+fp234 = src0[((hsi*55+9)*1+lsi)*1] + fp235;
+target[((hsi*135+17)*1+lsi)*1] = fp234;
+LIBINT2_REALTYPE fp35;
+fp35 = inteval->CD_x[vi] * src1[((hsi*45+39)*1+lsi)*1];
+LIBINT2_REALTYPE fp34;
+fp34 = src0[((hsi*55+39)*1+lsi)*1] + fp35;
+target[((hsi*135+117)*1+lsi)*1] = fp34;
+LIBINT2_REALTYPE fp37;
+fp37 = inteval->CD_z[vi] * src1[((hsi*45+38)*1+lsi)*1];
+LIBINT2_REALTYPE fp36;
+fp36 = src0[((hsi*55+48)*1+lsi)*1] + fp37;
+target[((hsi*135+116)*1+lsi)*1] = fp36;
+LIBINT2_REALTYPE fp39;
+fp39 = inteval->CD_y[vi] * src1[((hsi*45+38)*1+lsi)*1];
+LIBINT2_REALTYPE fp38;
+fp38 = src0[((hsi*55+47)*1+lsi)*1] + fp39;
+target[((hsi*135+115)*1+lsi)*1] = fp38;
+LIBINT2_REALTYPE fp41;
+fp41 = inteval->CD_x[vi] * src1[((hsi*45+38)*1+lsi)*1];
+LIBINT2_REALTYPE fp40;
+fp40 = src0[((hsi*55+38)*1+lsi)*1] + fp41;
+target[((hsi*135+114)*1+lsi)*1] = fp40;
+LIBINT2_REALTYPE fp43;
+fp43 = inteval->CD_z[vi] * src1[((hsi*45+37)*1+lsi)*1];
+LIBINT2_REALTYPE fp42;
+fp42 = src0[((hsi*55+47)*1+lsi)*1] + fp43;
+target[((hsi*135+113)*1+lsi)*1] = fp42;
+LIBINT2_REALTYPE fp45;
+fp45 = inteval->CD_y[vi] * src1[((hsi*45+37)*1+lsi)*1];
+LIBINT2_REALTYPE fp44;
+fp44 = src0[((hsi*55+46)*1+lsi)*1] + fp45;
+target[((hsi*135+112)*1+lsi)*1] = fp44;
+LIBINT2_REALTYPE fp47;
+fp47 = inteval->CD_x[vi] * src1[((hsi*45+37)*1+lsi)*1];
+LIBINT2_REALTYPE fp46;
+fp46 = src0[((hsi*55+37)*1+lsi)*1] + fp47;
+target[((hsi*135+111)*1+lsi)*1] = fp46;
+LIBINT2_REALTYPE fp49;
+fp49 = inteval->CD_z[vi] * src1[((hsi*45+36)*1+lsi)*1];
+LIBINT2_REALTYPE fp48;
+fp48 = src0[((hsi*55+46)*1+lsi)*1] + fp49;
+target[((hsi*135+110)*1+lsi)*1] = fp48;
+LIBINT2_REALTYPE fp51;
+fp51 = inteval->CD_y[vi] * src1[((hsi*45+36)*1+lsi)*1];
+LIBINT2_REALTYPE fp50;
+fp50 = src0[((hsi*55+45)*1+lsi)*1] + fp51;
+target[((hsi*135+109)*1+lsi)*1] = fp50;
+LIBINT2_REALTYPE fp53;
+fp53 = inteval->CD_x[vi] * src1[((hsi*45+36)*1+lsi)*1];
+LIBINT2_REALTYPE fp52;
+fp52 = src0[((hsi*55+36)*1+lsi)*1] + fp53;
+target[((hsi*135+108)*1+lsi)*1] = fp52;
+LIBINT2_REALTYPE fp55;
+fp55 = inteval->CD_z[vi] * src1[((hsi*45+35)*1+lsi)*1];
+LIBINT2_REALTYPE fp54;
+fp54 = src0[((hsi*55+44)*1+lsi)*1] + fp55;
+target[((hsi*135+107)*1+lsi)*1] = fp54;
+LIBINT2_REALTYPE fp57;
+fp57 = inteval->CD_y[vi] * src1[((hsi*45+35)*1+lsi)*1];
+LIBINT2_REALTYPE fp56;
+fp56 = src0[((hsi*55+43)*1+lsi)*1] + fp57;
+target[((hsi*135+106)*1+lsi)*1] = fp56;
+LIBINT2_REALTYPE fp59;
+fp59 = inteval->CD_x[vi] * src1[((hsi*45+35)*1+lsi)*1];
+LIBINT2_REALTYPE fp58;
+fp58 = src0[((hsi*55+35)*1+lsi)*1] + fp59;
+target[((hsi*135+105)*1+lsi)*1] = fp58;
+LIBINT2_REALTYPE fp61;
+fp61 = inteval->CD_z[vi] * src1[((hsi*45+34)*1+lsi)*1];
+LIBINT2_REALTYPE fp60;
+fp60 = src0[((hsi*55+43)*1+lsi)*1] + fp61;
+target[((hsi*135+104)*1+lsi)*1] = fp60;
+LIBINT2_REALTYPE fp63;
+fp63 = inteval->CD_y[vi] * src1[((hsi*45+34)*1+lsi)*1];
+LIBINT2_REALTYPE fp62;
+fp62 = src0[((hsi*55+42)*1+lsi)*1] + fp63;
+target[((hsi*135+103)*1+lsi)*1] = fp62;
+LIBINT2_REALTYPE fp65;
+fp65 = inteval->CD_x[vi] * src1[((hsi*45+34)*1+lsi)*1];
+LIBINT2_REALTYPE fp64;
+fp64 = src0[((hsi*55+34)*1+lsi)*1] + fp65;
+target[((hsi*135+102)*1+lsi)*1] = fp64;
+LIBINT2_REALTYPE fp67;
+fp67 = inteval->CD_z[vi] * src1[((hsi*45+33)*1+lsi)*1];
+LIBINT2_REALTYPE fp66;
+fp66 = src0[((hsi*55+42)*1+lsi)*1] + fp67;
+target[((hsi*135+101)*1+lsi)*1] = fp66;
+LIBINT2_REALTYPE fp1;
+fp1 = inteval->CD_z[vi] * src1[((hsi*45+44)*1+lsi)*1];
+LIBINT2_REALTYPE fp0;
+fp0 = src0[((hsi*55+54)*1+lsi)*1] + fp1;
+target[((hsi*135+134)*1+lsi)*1] = fp0;
+LIBINT2_REALTYPE fp3;
+fp3 = inteval->CD_y[vi] * src1[((hsi*45+44)*1+lsi)*1];
+LIBINT2_REALTYPE fp2;
+fp2 = src0[((hsi*55+53)*1+lsi)*1] + fp3;
+target[((hsi*135+133)*1+lsi)*1] = fp2;
+LIBINT2_REALTYPE fp5;
+fp5 = inteval->CD_x[vi] * src1[((hsi*45+44)*1+lsi)*1];
+LIBINT2_REALTYPE fp4;
+fp4 = src0[((hsi*55+44)*1+lsi)*1] + fp5;
+target[((hsi*135+132)*1+lsi)*1] = fp4;
+LIBINT2_REALTYPE fp7;
+fp7 = inteval->CD_z[vi] * src1[((hsi*45+43)*1+lsi)*1];
+LIBINT2_REALTYPE fp6;
+fp6 = src0[((hsi*55+53)*1+lsi)*1] + fp7;
+target[((hsi*135+131)*1+lsi)*1] = fp6;
+LIBINT2_REALTYPE fp9;
+fp9 = inteval->CD_y[vi] * src1[((hsi*45+43)*1+lsi)*1];
+LIBINT2_REALTYPE fp8;
+fp8 = src0[((hsi*55+52)*1+lsi)*1] + fp9;
+target[((hsi*135+130)*1+lsi)*1] = fp8;
+LIBINT2_REALTYPE fp11;
+fp11 = inteval->CD_x[vi] * src1[((hsi*45+43)*1+lsi)*1];
+LIBINT2_REALTYPE fp10;
+fp10 = src0[((hsi*55+43)*1+lsi)*1] + fp11;
+target[((hsi*135+129)*1+lsi)*1] = fp10;
+LIBINT2_REALTYPE fp13;
+fp13 = inteval->CD_z[vi] * src1[((hsi*45+42)*1+lsi)*1];
+LIBINT2_REALTYPE fp12;
+fp12 = src0[((hsi*55+52)*1+lsi)*1] + fp13;
+target[((hsi*135+128)*1+lsi)*1] = fp12;
+LIBINT2_REALTYPE fp15;
+fp15 = inteval->CD_y[vi] * src1[((hsi*45+42)*1+lsi)*1];
+LIBINT2_REALTYPE fp14;
+fp14 = src0[((hsi*55+51)*1+lsi)*1] + fp15;
+target[((hsi*135+127)*1+lsi)*1] = fp14;
+LIBINT2_REALTYPE fp17;
+fp17 = inteval->CD_x[vi] * src1[((hsi*45+42)*1+lsi)*1];
+LIBINT2_REALTYPE fp16;
+fp16 = src0[((hsi*55+42)*1+lsi)*1] + fp17;
+target[((hsi*135+126)*1+lsi)*1] = fp16;
+LIBINT2_REALTYPE fp19;
+fp19 = inteval->CD_z[vi] * src1[((hsi*45+41)*1+lsi)*1];
+LIBINT2_REALTYPE fp18;
+fp18 = src0[((hsi*55+51)*1+lsi)*1] + fp19;
+target[((hsi*135+125)*1+lsi)*1] = fp18;
+LIBINT2_REALTYPE fp21;
+fp21 = inteval->CD_y[vi] * src1[((hsi*45+41)*1+lsi)*1];
+LIBINT2_REALTYPE fp20;
+fp20 = src0[((hsi*55+50)*1+lsi)*1] + fp21;
+target[((hsi*135+124)*1+lsi)*1] = fp20;
+LIBINT2_REALTYPE fp23;
+fp23 = inteval->CD_x[vi] * src1[((hsi*45+41)*1+lsi)*1];
+LIBINT2_REALTYPE fp22;
+fp22 = src0[((hsi*55+41)*1+lsi)*1] + fp23;
+target[((hsi*135+123)*1+lsi)*1] = fp22;
+LIBINT2_REALTYPE fp25;
+fp25 = inteval->CD_z[vi] * src1[((hsi*45+40)*1+lsi)*1];
+LIBINT2_REALTYPE fp24;
+fp24 = src0[((hsi*55+50)*1+lsi)*1] + fp25;
+target[((hsi*135+122)*1+lsi)*1] = fp24;
+LIBINT2_REALTYPE fp27;
+fp27 = inteval->CD_y[vi] * src1[((hsi*45+40)*1+lsi)*1];
+LIBINT2_REALTYPE fp26;
+fp26 = src0[((hsi*55+49)*1+lsi)*1] + fp27;
+target[((hsi*135+121)*1+lsi)*1] = fp26;
+LIBINT2_REALTYPE fp29;
+fp29 = inteval->CD_x[vi] * src1[((hsi*45+40)*1+lsi)*1];
+LIBINT2_REALTYPE fp28;
+fp28 = src0[((hsi*55+40)*1+lsi)*1] + fp29;
+target[((hsi*135+120)*1+lsi)*1] = fp28;
+LIBINT2_REALTYPE fp31;
+fp31 = inteval->CD_z[vi] * src1[((hsi*45+39)*1+lsi)*1];
+LIBINT2_REALTYPE fp30;
+fp30 = src0[((hsi*55+49)*1+lsi)*1] + fp31;
+target[((hsi*135+119)*1+lsi)*1] = fp30;
+LIBINT2_REALTYPE fp33;
+fp33 = inteval->CD_y[vi] * src1[((hsi*45+39)*1+lsi)*1];
+LIBINT2_REALTYPE fp32;
+fp32 = src0[((hsi*55+48)*1+lsi)*1] + fp33;
+target[((hsi*135+118)*1+lsi)*1] = fp32;
+LIBINT2_REALTYPE fp101;
+fp101 = inteval->CD_x[vi] * src1[((hsi*45+28)*1+lsi)*1];
+LIBINT2_REALTYPE fp100;
+fp100 = src0[((hsi*55+28)*1+lsi)*1] + fp101;
+target[((hsi*135+84)*1+lsi)*1] = fp100;
+LIBINT2_REALTYPE fp103;
+fp103 = inteval->CD_z[vi] * src1[((hsi*45+27)*1+lsi)*1];
+LIBINT2_REALTYPE fp102;
+fp102 = src0[((hsi*55+35)*1+lsi)*1] + fp103;
+target[((hsi*135+83)*1+lsi)*1] = fp102;
+LIBINT2_REALTYPE fp105;
+fp105 = inteval->CD_y[vi] * src1[((hsi*45+27)*1+lsi)*1];
+LIBINT2_REALTYPE fp104;
+fp104 = src0[((hsi*55+34)*1+lsi)*1] + fp105;
+target[((hsi*135+82)*1+lsi)*1] = fp104;
+LIBINT2_REALTYPE fp107;
+fp107 = inteval->CD_x[vi] * src1[((hsi*45+27)*1+lsi)*1];
+LIBINT2_REALTYPE fp106;
+fp106 = src0[((hsi*55+27)*1+lsi)*1] + fp107;
+target[((hsi*135+81)*1+lsi)*1] = fp106;
+LIBINT2_REALTYPE fp109;
+fp109 = inteval->CD_z[vi] * src1[((hsi*45+26)*1+lsi)*1];
+LIBINT2_REALTYPE fp108;
+fp108 = src0[((hsi*55+34)*1+lsi)*1] + fp109;
+target[((hsi*135+80)*1+lsi)*1] = fp108;
+LIBINT2_REALTYPE fp111;
+fp111 = inteval->CD_y[vi] * src1[((hsi*45+26)*1+lsi)*1];
+LIBINT2_REALTYPE fp110;
+fp110 = src0[((hsi*55+33)*1+lsi)*1] + fp111;
+target[((hsi*135+79)*1+lsi)*1] = fp110;
+LIBINT2_REALTYPE fp113;
+fp113 = inteval->CD_x[vi] * src1[((hsi*45+26)*1+lsi)*1];
+LIBINT2_REALTYPE fp112;
+fp112 = src0[((hsi*55+26)*1+lsi)*1] + fp113;
+target[((hsi*135+78)*1+lsi)*1] = fp112;
+LIBINT2_REALTYPE fp115;
+fp115 = inteval->CD_z[vi] * src1[((hsi*45+25)*1+lsi)*1];
+LIBINT2_REALTYPE fp114;
+fp114 = src0[((hsi*55+33)*1+lsi)*1] + fp115;
+target[((hsi*135+77)*1+lsi)*1] = fp114;
+LIBINT2_REALTYPE fp117;
+fp117 = inteval->CD_y[vi] * src1[((hsi*45+25)*1+lsi)*1];
+LIBINT2_REALTYPE fp116;
+fp116 = src0[((hsi*55+32)*1+lsi)*1] + fp117;
+target[((hsi*135+76)*1+lsi)*1] = fp116;
+LIBINT2_REALTYPE fp119;
+fp119 = inteval->CD_x[vi] * src1[((hsi*45+25)*1+lsi)*1];
+LIBINT2_REALTYPE fp118;
+fp118 = src0[((hsi*55+25)*1+lsi)*1] + fp119;
+target[((hsi*135+75)*1+lsi)*1] = fp118;
+LIBINT2_REALTYPE fp121;
+fp121 = inteval->CD_z[vi] * src1[((hsi*45+24)*1+lsi)*1];
+LIBINT2_REALTYPE fp120;
+fp120 = src0[((hsi*55+32)*1+lsi)*1] + fp121;
+target[((hsi*135+74)*1+lsi)*1] = fp120;
+LIBINT2_REALTYPE fp123;
+fp123 = inteval->CD_y[vi] * src1[((hsi*45+24)*1+lsi)*1];
+LIBINT2_REALTYPE fp122;
+fp122 = src0[((hsi*55+31)*1+lsi)*1] + fp123;
+target[((hsi*135+73)*1+lsi)*1] = fp122;
+LIBINT2_REALTYPE fp125;
+fp125 = inteval->CD_x[vi] * src1[((hsi*45+24)*1+lsi)*1];
+LIBINT2_REALTYPE fp124;
+fp124 = src0[((hsi*55+24)*1+lsi)*1] + fp125;
+target[((hsi*135+72)*1+lsi)*1] = fp124;
+LIBINT2_REALTYPE fp127;
+fp127 = inteval->CD_z[vi] * src1[((hsi*45+23)*1+lsi)*1];
+LIBINT2_REALTYPE fp126;
+fp126 = src0[((hsi*55+31)*1+lsi)*1] + fp127;
+target[((hsi*135+71)*1+lsi)*1] = fp126;
+LIBINT2_REALTYPE fp129;
+fp129 = inteval->CD_y[vi] * src1[((hsi*45+23)*1+lsi)*1];
+LIBINT2_REALTYPE fp128;
+fp128 = src0[((hsi*55+30)*1+lsi)*1] + fp129;
+target[((hsi*135+70)*1+lsi)*1] = fp128;
+LIBINT2_REALTYPE fp131;
+fp131 = inteval->CD_x[vi] * src1[((hsi*45+23)*1+lsi)*1];
+LIBINT2_REALTYPE fp130;
+fp130 = src0[((hsi*55+23)*1+lsi)*1] + fp131;
+target[((hsi*135+69)*1+lsi)*1] = fp130;
+LIBINT2_REALTYPE fp133;
+fp133 = inteval->CD_z[vi] * src1[((hsi*45+22)*1+lsi)*1];
+LIBINT2_REALTYPE fp132;
+fp132 = src0[((hsi*55+30)*1+lsi)*1] + fp133;
+target[((hsi*135+68)*1+lsi)*1] = fp132;
+LIBINT2_REALTYPE fp99;
+fp99 = inteval->CD_y[vi] * src1[((hsi*45+28)*1+lsi)*1];
+LIBINT2_REALTYPE fp98;
+fp98 = src0[((hsi*55+36)*1+lsi)*1] + fp99;
+target[((hsi*135+85)*1+lsi)*1] = fp98;
+LIBINT2_REALTYPE fp97;
+fp97 = inteval->CD_z[vi] * src1[((hsi*45+28)*1+lsi)*1];
+LIBINT2_REALTYPE fp96;
+fp96 = src0[((hsi*55+37)*1+lsi)*1] + fp97;
+target[((hsi*135+86)*1+lsi)*1] = fp96;
+LIBINT2_REALTYPE fp95;
+fp95 = inteval->CD_x[vi] * src1[((hsi*45+29)*1+lsi)*1];
+LIBINT2_REALTYPE fp94;
+fp94 = src0[((hsi*55+29)*1+lsi)*1] + fp95;
+target[((hsi*135+87)*1+lsi)*1] = fp94;
+LIBINT2_REALTYPE fp93;
+fp93 = inteval->CD_y[vi] * src1[((hsi*45+29)*1+lsi)*1];
+LIBINT2_REALTYPE fp92;
+fp92 = src0[((hsi*55+37)*1+lsi)*1] + fp93;
+target[((hsi*135+88)*1+lsi)*1] = fp92;
+LIBINT2_REALTYPE fp91;
+fp91 = inteval->CD_z[vi] * src1[((hsi*45+29)*1+lsi)*1];
+LIBINT2_REALTYPE fp90;
+fp90 = src0[((hsi*55+38)*1+lsi)*1] + fp91;
+target[((hsi*135+89)*1+lsi)*1] = fp90;
+LIBINT2_REALTYPE fp89;
+fp89 = inteval->CD_x[vi] * src1[((hsi*45+30)*1+lsi)*1];
+LIBINT2_REALTYPE fp88;
+fp88 = src0[((hsi*55+30)*1+lsi)*1] + fp89;
+target[((hsi*135+90)*1+lsi)*1] = fp88;
+LIBINT2_REALTYPE fp87;
+fp87 = inteval->CD_y[vi] * src1[((hsi*45+30)*1+lsi)*1];
+LIBINT2_REALTYPE fp86;
+fp86 = src0[((hsi*55+38)*1+lsi)*1] + fp87;
+target[((hsi*135+91)*1+lsi)*1] = fp86;
+LIBINT2_REALTYPE fp85;
+fp85 = inteval->CD_z[vi] * src1[((hsi*45+30)*1+lsi)*1];
+LIBINT2_REALTYPE fp84;
+fp84 = src0[((hsi*55+39)*1+lsi)*1] + fp85;
+target[((hsi*135+92)*1+lsi)*1] = fp84;
+LIBINT2_REALTYPE fp83;
+fp83 = inteval->CD_x[vi] * src1[((hsi*45+31)*1+lsi)*1];
+LIBINT2_REALTYPE fp82;
+fp82 = src0[((hsi*55+31)*1+lsi)*1] + fp83;
+target[((hsi*135+93)*1+lsi)*1] = fp82;
+LIBINT2_REALTYPE fp81;
+fp81 = inteval->CD_y[vi] * src1[((hsi*45+31)*1+lsi)*1];
+LIBINT2_REALTYPE fp80;
+fp80 = src0[((hsi*55+39)*1+lsi)*1] + fp81;
+target[((hsi*135+94)*1+lsi)*1] = fp80;
+LIBINT2_REALTYPE fp79;
+fp79 = inteval->CD_z[vi] * src1[((hsi*45+31)*1+lsi)*1];
+LIBINT2_REALTYPE fp78;
+fp78 = src0[((hsi*55+40)*1+lsi)*1] + fp79;
+target[((hsi*135+95)*1+lsi)*1] = fp78;
+LIBINT2_REALTYPE fp77;
+fp77 = inteval->CD_x[vi] * src1[((hsi*45+32)*1+lsi)*1];
+LIBINT2_REALTYPE fp76;
+fp76 = src0[((hsi*55+32)*1+lsi)*1] + fp77;
+target[((hsi*135+96)*1+lsi)*1] = fp76;
+LIBINT2_REALTYPE fp75;
+fp75 = inteval->CD_y[vi] * src1[((hsi*45+32)*1+lsi)*1];
+LIBINT2_REALTYPE fp74;
+fp74 = src0[((hsi*55+40)*1+lsi)*1] + fp75;
+target[((hsi*135+97)*1+lsi)*1] = fp74;
+LIBINT2_REALTYPE fp73;
+fp73 = inteval->CD_z[vi] * src1[((hsi*45+32)*1+lsi)*1];
+LIBINT2_REALTYPE fp72;
+fp72 = src0[((hsi*55+41)*1+lsi)*1] + fp73;
+target[((hsi*135+98)*1+lsi)*1] = fp72;
+LIBINT2_REALTYPE fp71;
+fp71 = inteval->CD_x[vi] * src1[((hsi*45+33)*1+lsi)*1];
+LIBINT2_REALTYPE fp70;
+fp70 = src0[((hsi*55+33)*1+lsi)*1] + fp71;
+target[((hsi*135+99)*1+lsi)*1] = fp70;
+LIBINT2_REALTYPE fp69;
+fp69 = inteval->CD_y[vi] * src1[((hsi*45+33)*1+lsi)*1];
+LIBINT2_REALTYPE fp68;
+fp68 = src0[((hsi*55+41)*1+lsi)*1] + fp69;
+target[((hsi*135+100)*1+lsi)*1] = fp68;
 }
 }
 }
@@ -693,4 +698,6 @@ const int vi = 0;
 /** Number of flops = 270 */
 }
 
+#ifdef __cplusplus
 };
+#endif
