@@ -1,6 +1,8 @@
 #include <libint2.h>
 
+#ifdef __cplusplus
 extern "C" {
+#endif
 void OSVRRP0InBra_aB_d__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(const Libint_t* inteval, LIBINT2_REALTYPE* target, const LIBINT2_REALTYPE* src0, const LIBINT2_REALTYPE* src1, const LIBINT2_REALTYPE* src2, const LIBINT2_REALTYPE* src3, const LIBINT2_REALTYPE* src4) {
 
 LIBINT2_REALTYPE*const  stack = target;
@@ -10,14 +12,390 @@ const int hsi = 0;
 const int lsi = 0;
 {
 const int vi = 0;
-LIBINT2_REALTYPE fp2;
-fp2 = 3 * inteval->oo2ze[vi];
-LIBINT2_REALTYPE fp1;
-fp1 = fp2 * src4[((hsi*18+17)*1+lsi)*1];
+LIBINT2_REALTYPE fp177;
+fp177 = 3 * inteval->oo2ze[vi];
+LIBINT2_REALTYPE fp176;
+fp176 = fp177 * src4[((hsi*18+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp179;
+fp179 = inteval->WP_z[vi] * src1[((hsi*30+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp180;
+fp180 = inteval->PA_z[vi] * src0[((hsi*30+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp178;
+fp178 = fp180 + fp179;
+LIBINT2_REALTYPE fp175;
+fp175 = fp178 + fp176;
+target[((hsi*60+29)*1+lsi)*1] = fp175;
+LIBINT2_REALTYPE fp183;
+fp183 = 2 * inteval->oo2ze[vi];
+LIBINT2_REALTYPE fp182;
+fp182 = fp183 * src4[((hsi*18+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp185;
+fp185 = inteval->WP_z[vi] * src1[((hsi*30+8)*1+lsi)*1];
+LIBINT2_REALTYPE fp186;
+fp186 = inteval->PA_z[vi] * src0[((hsi*30+8)*1+lsi)*1];
+LIBINT2_REALTYPE fp184;
+fp184 = fp186 + fp185;
+LIBINT2_REALTYPE fp181;
+fp181 = fp184 + fp182;
+target[((hsi*60+28)*1+lsi)*1] = fp181;
+LIBINT2_REALTYPE fp188;
+fp188 = inteval->oo2ze[vi] * src4[((hsi*18+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp190;
+fp190 = inteval->WP_z[vi] * src1[((hsi*30+7)*1+lsi)*1];
+LIBINT2_REALTYPE fp191;
+fp191 = inteval->PA_z[vi] * src0[((hsi*30+7)*1+lsi)*1];
+LIBINT2_REALTYPE fp189;
+fp189 = fp191 + fp190;
+LIBINT2_REALTYPE fp187;
+fp187 = fp189 + fp188;
+target[((hsi*60+27)*1+lsi)*1] = fp187;
+LIBINT2_REALTYPE fp193;
+fp193 = inteval->WP_z[vi] * src1[((hsi*30+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp194;
+fp194 = inteval->PA_z[vi] * src0[((hsi*30+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp192;
+fp192 = fp194 + fp193;
+target[((hsi*60+26)*1+lsi)*1] = fp192;
+LIBINT2_REALTYPE fp197;
+fp197 = 2 * inteval->oo2ze[vi];
+LIBINT2_REALTYPE fp196;
+fp196 = fp197 * src4[((hsi*18+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp199;
+fp199 = inteval->WP_z[vi] * src1[((hsi*30+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp200;
+fp200 = inteval->PA_z[vi] * src0[((hsi*30+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp198;
+fp198 = fp200 + fp199;
+LIBINT2_REALTYPE fp195;
+fp195 = fp198 + fp196;
+target[((hsi*60+25)*1+lsi)*1] = fp195;
+LIBINT2_REALTYPE fp202;
+fp202 = inteval->oo2ze[vi] * src4[((hsi*18+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp204;
+fp204 = inteval->WP_z[vi] * src1[((hsi*30+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp205;
+fp205 = inteval->PA_z[vi] * src0[((hsi*30+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp203;
+fp203 = fp205 + fp204;
+LIBINT2_REALTYPE fp201;
+fp201 = fp203 + fp202;
+target[((hsi*60+24)*1+lsi)*1] = fp201;
+LIBINT2_REALTYPE fp207;
+fp207 = inteval->WP_z[vi] * src1[((hsi*30+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp208;
+fp208 = inteval->PA_z[vi] * src0[((hsi*30+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp206;
+fp206 = fp208 + fp207;
+target[((hsi*60+23)*1+lsi)*1] = fp206;
+LIBINT2_REALTYPE fp210;
+fp210 = inteval->oo2ze[vi] * src4[((hsi*18+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp212;
+fp212 = inteval->WP_z[vi] * src1[((hsi*30+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp213;
+fp213 = inteval->PA_z[vi] * src0[((hsi*30+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp211;
+fp211 = fp213 + fp212;
+LIBINT2_REALTYPE fp209;
+fp209 = fp211 + fp210;
+target[((hsi*60+22)*1+lsi)*1] = fp209;
+LIBINT2_REALTYPE fp215;
+fp215 = inteval->WP_z[vi] * src1[((hsi*30+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp216;
+fp216 = inteval->PA_z[vi] * src0[((hsi*30+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp214;
+fp214 = fp216 + fp215;
+target[((hsi*60+21)*1+lsi)*1] = fp214;
+LIBINT2_REALTYPE fp218;
+fp218 = inteval->WP_z[vi] * src1[((hsi*30+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp219;
+fp219 = inteval->PA_z[vi] * src0[((hsi*30+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp217;
+fp217 = fp219 + fp218;
+target[((hsi*60+20)*1+lsi)*1] = fp217;
+LIBINT2_REALTYPE fp221;
+fp221 = inteval->WP_y[vi] * src1[((hsi*30+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp222;
+fp222 = inteval->PA_y[vi] * src0[((hsi*30+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp220;
+fp220 = fp222 + fp221;
+target[((hsi*60+19)*1+lsi)*1] = fp220;
+LIBINT2_REALTYPE fp224;
+fp224 = inteval->oo2ze[vi] * src4[((hsi*18+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp226;
+fp226 = inteval->WP_y[vi] * src1[((hsi*30+8)*1+lsi)*1];
+LIBINT2_REALTYPE fp227;
+fp227 = inteval->PA_y[vi] * src0[((hsi*30+8)*1+lsi)*1];
+LIBINT2_REALTYPE fp225;
+fp225 = fp227 + fp226;
+LIBINT2_REALTYPE fp223;
+fp223 = fp225 + fp224;
+target[((hsi*60+18)*1+lsi)*1] = fp223;
+LIBINT2_REALTYPE fp230;
+fp230 = 2 * inteval->oo2ze[vi];
+LIBINT2_REALTYPE fp229;
+fp229 = fp230 * src4[((hsi*18+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp232;
+fp232 = inteval->WP_y[vi] * src1[((hsi*30+7)*1+lsi)*1];
+LIBINT2_REALTYPE fp233;
+fp233 = inteval->PA_y[vi] * src0[((hsi*30+7)*1+lsi)*1];
+LIBINT2_REALTYPE fp231;
+fp231 = fp233 + fp232;
+LIBINT2_REALTYPE fp228;
+fp228 = fp231 + fp229;
+target[((hsi*60+17)*1+lsi)*1] = fp228;
+LIBINT2_REALTYPE fp236;
+fp236 = 3 * inteval->oo2ze[vi];
+LIBINT2_REALTYPE fp235;
+fp235 = fp236 * src4[((hsi*18+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp238;
+fp238 = inteval->WP_y[vi] * src1[((hsi*30+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp239;
+fp239 = inteval->PA_y[vi] * src0[((hsi*30+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp237;
+fp237 = fp239 + fp238;
+LIBINT2_REALTYPE fp234;
+fp234 = fp237 + fp235;
+target[((hsi*60+16)*1+lsi)*1] = fp234;
+LIBINT2_REALTYPE fp241;
+fp241 = inteval->WP_y[vi] * src1[((hsi*30+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp242;
+fp242 = inteval->PA_y[vi] * src0[((hsi*30+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp240;
+fp240 = fp242 + fp241;
+target[((hsi*60+15)*1+lsi)*1] = fp240;
+LIBINT2_REALTYPE fp244;
+fp244 = inteval->oo2ze[vi] * src4[((hsi*18+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp246;
+fp246 = inteval->WP_y[vi] * src1[((hsi*30+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp247;
+fp247 = inteval->PA_y[vi] * src0[((hsi*30+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp245;
+fp245 = fp247 + fp246;
+LIBINT2_REALTYPE fp243;
+fp243 = fp245 + fp244;
+target[((hsi*60+14)*1+lsi)*1] = fp243;
+LIBINT2_REALTYPE fp250;
+fp250 = 2 * inteval->oo2ze[vi];
+LIBINT2_REALTYPE fp249;
+fp249 = fp250 * src4[((hsi*18+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp252;
+fp252 = inteval->WP_y[vi] * src1[((hsi*30+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp253;
+fp253 = inteval->PA_y[vi] * src0[((hsi*30+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp251;
+fp251 = fp253 + fp252;
+LIBINT2_REALTYPE fp248;
+fp248 = fp251 + fp249;
+target[((hsi*60+13)*1+lsi)*1] = fp248;
+LIBINT2_REALTYPE fp255;
+fp255 = inteval->WP_y[vi] * src1[((hsi*30+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp256;
+fp256 = inteval->PA_y[vi] * src0[((hsi*30+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp254;
+fp254 = fp256 + fp255;
+target[((hsi*60+12)*1+lsi)*1] = fp254;
+LIBINT2_REALTYPE fp258;
+fp258 = inteval->oo2ze[vi] * src4[((hsi*18+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp260;
+fp260 = inteval->WP_y[vi] * src1[((hsi*30+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp261;
+fp261 = inteval->PA_y[vi] * src0[((hsi*30+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp259;
+fp259 = fp261 + fp260;
+LIBINT2_REALTYPE fp257;
+fp257 = fp259 + fp258;
+target[((hsi*60+11)*1+lsi)*1] = fp257;
+LIBINT2_REALTYPE fp263;
+fp263 = inteval->WP_y[vi] * src1[((hsi*30+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp264;
+fp264 = inteval->PA_y[vi] * src0[((hsi*30+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp262;
+fp262 = fp264 + fp263;
+target[((hsi*60+10)*1+lsi)*1] = fp262;
 LIBINT2_REALTYPE fp268;
 fp268 = inteval->roz[vi] * src3[((hsi*10+9)*1+lsi)*1];
 LIBINT2_REALTYPE fp267;
 fp267 = src2[((hsi*10+9)*1+lsi)*1] - fp268;
+LIBINT2_REALTYPE fp266;
+fp266 = inteval->oo2z[vi] * fp267;
+LIBINT2_REALTYPE fp270;
+fp270 = inteval->WP_x[vi] * src1[((hsi*30+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp271;
+fp271 = inteval->PA_x[vi] * src0[((hsi*30+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp269;
+fp269 = fp271 + fp270;
+LIBINT2_REALTYPE fp265;
+fp265 = fp269 + fp266;
+target[((hsi*60+9)*1+lsi)*1] = fp265;
+LIBINT2_REALTYPE fp275;
+fp275 = inteval->roz[vi] * src3[((hsi*10+8)*1+lsi)*1];
+LIBINT2_REALTYPE fp274;
+fp274 = src2[((hsi*10+8)*1+lsi)*1] - fp275;
+LIBINT2_REALTYPE fp273;
+fp273 = inteval->oo2z[vi] * fp274;
+LIBINT2_REALTYPE fp277;
+fp277 = inteval->WP_x[vi] * src1[((hsi*30+8)*1+lsi)*1];
+LIBINT2_REALTYPE fp278;
+fp278 = inteval->PA_x[vi] * src0[((hsi*30+8)*1+lsi)*1];
+LIBINT2_REALTYPE fp276;
+fp276 = fp278 + fp277;
+LIBINT2_REALTYPE fp272;
+fp272 = fp276 + fp273;
+target[((hsi*60+8)*1+lsi)*1] = fp272;
+LIBINT2_REALTYPE fp282;
+fp282 = inteval->roz[vi] * src3[((hsi*10+7)*1+lsi)*1];
+LIBINT2_REALTYPE fp281;
+fp281 = src2[((hsi*10+7)*1+lsi)*1] - fp282;
+LIBINT2_REALTYPE fp280;
+fp280 = inteval->oo2z[vi] * fp281;
+LIBINT2_REALTYPE fp284;
+fp284 = inteval->WP_x[vi] * src1[((hsi*30+7)*1+lsi)*1];
+LIBINT2_REALTYPE fp285;
+fp285 = inteval->PA_x[vi] * src0[((hsi*30+7)*1+lsi)*1];
+LIBINT2_REALTYPE fp283;
+fp283 = fp285 + fp284;
+LIBINT2_REALTYPE fp279;
+fp279 = fp283 + fp280;
+target[((hsi*60+7)*1+lsi)*1] = fp279;
+LIBINT2_REALTYPE fp289;
+fp289 = inteval->roz[vi] * src3[((hsi*10+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp288;
+fp288 = src2[((hsi*10+6)*1+lsi)*1] - fp289;
+LIBINT2_REALTYPE fp287;
+fp287 = inteval->oo2z[vi] * fp288;
+LIBINT2_REALTYPE fp291;
+fp291 = inteval->WP_x[vi] * src1[((hsi*30+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp292;
+fp292 = inteval->PA_x[vi] * src0[((hsi*30+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp290;
+fp290 = fp292 + fp291;
+LIBINT2_REALTYPE fp286;
+fp286 = fp290 + fp287;
+target[((hsi*60+6)*1+lsi)*1] = fp286;
+LIBINT2_REALTYPE fp294;
+fp294 = inteval->oo2ze[vi] * src4[((hsi*18+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp298;
+fp298 = inteval->roz[vi] * src3[((hsi*10+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp297;
+fp297 = src2[((hsi*10+5)*1+lsi)*1] - fp298;
+LIBINT2_REALTYPE fp296;
+fp296 = inteval->oo2z[vi] * fp297;
+LIBINT2_REALTYPE fp300;
+fp300 = inteval->WP_x[vi] * src1[((hsi*30+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp301;
+fp301 = inteval->PA_x[vi] * src0[((hsi*30+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp299;
+fp299 = fp301 + fp300;
+LIBINT2_REALTYPE fp295;
+fp295 = fp299 + fp296;
+LIBINT2_REALTYPE fp293;
+fp293 = fp295 + fp294;
+target[((hsi*60+5)*1+lsi)*1] = fp293;
+LIBINT2_REALTYPE fp303;
+fp303 = inteval->oo2ze[vi] * src4[((hsi*18+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp307;
+fp307 = inteval->roz[vi] * src3[((hsi*10+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp306;
+fp306 = src2[((hsi*10+4)*1+lsi)*1] - fp307;
+LIBINT2_REALTYPE fp305;
+fp305 = inteval->oo2z[vi] * fp306;
+LIBINT2_REALTYPE fp309;
+fp309 = inteval->WP_x[vi] * src1[((hsi*30+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp310;
+fp310 = inteval->PA_x[vi] * src0[((hsi*30+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp308;
+fp308 = fp310 + fp309;
+LIBINT2_REALTYPE fp304;
+fp304 = fp308 + fp305;
+LIBINT2_REALTYPE fp302;
+fp302 = fp304 + fp303;
+target[((hsi*60+4)*1+lsi)*1] = fp302;
+LIBINT2_REALTYPE fp312;
+fp312 = inteval->oo2ze[vi] * src4[((hsi*18+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp316;
+fp316 = inteval->roz[vi] * src3[((hsi*10+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp315;
+fp315 = src2[((hsi*10+3)*1+lsi)*1] - fp316;
+LIBINT2_REALTYPE fp314;
+fp314 = inteval->oo2z[vi] * fp315;
+LIBINT2_REALTYPE fp318;
+fp318 = inteval->WP_x[vi] * src1[((hsi*30+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp319;
+fp319 = inteval->PA_x[vi] * src0[((hsi*30+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp317;
+fp317 = fp319 + fp318;
+LIBINT2_REALTYPE fp313;
+fp313 = fp317 + fp314;
+LIBINT2_REALTYPE fp311;
+fp311 = fp313 + fp312;
+target[((hsi*60+3)*1+lsi)*1] = fp311;
+LIBINT2_REALTYPE fp322;
+fp322 = 2 * inteval->oo2ze[vi];
+LIBINT2_REALTYPE fp321;
+fp321 = fp322 * src4[((hsi*18+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp326;
+fp326 = inteval->roz[vi] * src3[((hsi*10+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp325;
+fp325 = src2[((hsi*10+2)*1+lsi)*1] - fp326;
+LIBINT2_REALTYPE fp324;
+fp324 = inteval->oo2z[vi] * fp325;
+LIBINT2_REALTYPE fp328;
+fp328 = inteval->WP_x[vi] * src1[((hsi*30+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp329;
+fp329 = inteval->PA_x[vi] * src0[((hsi*30+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp327;
+fp327 = fp329 + fp328;
+LIBINT2_REALTYPE fp323;
+fp323 = fp327 + fp324;
+LIBINT2_REALTYPE fp320;
+fp320 = fp323 + fp321;
+target[((hsi*60+2)*1+lsi)*1] = fp320;
+LIBINT2_REALTYPE fp332;
+fp332 = 2 * inteval->oo2ze[vi];
+LIBINT2_REALTYPE fp331;
+fp331 = fp332 * src4[((hsi*18+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp336;
+fp336 = inteval->roz[vi] * src3[((hsi*10+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp335;
+fp335 = src2[((hsi*10+1)*1+lsi)*1] - fp336;
+LIBINT2_REALTYPE fp334;
+fp334 = inteval->oo2z[vi] * fp335;
+LIBINT2_REALTYPE fp338;
+fp338 = inteval->WP_x[vi] * src1[((hsi*30+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp339;
+fp339 = inteval->PA_x[vi] * src0[((hsi*30+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp337;
+fp337 = fp339 + fp338;
+LIBINT2_REALTYPE fp333;
+fp333 = fp337 + fp334;
+LIBINT2_REALTYPE fp330;
+fp330 = fp333 + fp331;
+target[((hsi*60+1)*1+lsi)*1] = fp330;
+LIBINT2_REALTYPE fp342;
+fp342 = 3 * inteval->oo2ze[vi];
+LIBINT2_REALTYPE fp341;
+fp341 = fp342 * src4[((hsi*18+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp346;
+fp346 = inteval->roz[vi] * src3[((hsi*10+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp345;
+fp345 = src2[((hsi*10+0)*1+lsi)*1] - fp346;
+LIBINT2_REALTYPE fp344;
+fp344 = inteval->oo2z[vi] * fp345;
+LIBINT2_REALTYPE fp348;
+fp348 = inteval->WP_x[vi] * src1[((hsi*30+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp349;
+fp349 = inteval->PA_x[vi] * src0[((hsi*30+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp347;
+fp347 = fp349 + fp348;
+LIBINT2_REALTYPE fp343;
+fp343 = fp347 + fp344;
+LIBINT2_REALTYPE fp340;
+fp340 = fp343 + fp341;
+target[((hsi*60+0)*1+lsi)*1] = fp340;
+LIBINT2_REALTYPE fp2;
+fp2 = 3 * inteval->oo2ze[vi];
+LIBINT2_REALTYPE fp1;
+fp1 = fp2 * src4[((hsi*18+17)*1+lsi)*1];
 LIBINT2_REALTYPE fp4;
 fp4 = inteval->oo2z[vi] * fp267;
 LIBINT2_REALTYPE fp6;
@@ -35,10 +413,6 @@ LIBINT2_REALTYPE fp10;
 fp10 = 2 * inteval->oo2ze[vi];
 LIBINT2_REALTYPE fp9;
 fp9 = fp10 * src4[((hsi*18+16)*1+lsi)*1];
-LIBINT2_REALTYPE fp275;
-fp275 = inteval->roz[vi] * src3[((hsi*10+8)*1+lsi)*1];
-LIBINT2_REALTYPE fp274;
-fp274 = src2[((hsi*10+8)*1+lsi)*1] - fp275;
 LIBINT2_REALTYPE fp12;
 fp12 = inteval->oo2z[vi] * fp274;
 LIBINT2_REALTYPE fp14;
@@ -54,10 +428,6 @@ fp8 = fp11 + fp9;
 target[((hsi*60+58)*1+lsi)*1] = fp8;
 LIBINT2_REALTYPE fp17;
 fp17 = inteval->oo2ze[vi] * src4[((hsi*18+15)*1+lsi)*1];
-LIBINT2_REALTYPE fp282;
-fp282 = inteval->roz[vi] * src3[((hsi*10+7)*1+lsi)*1];
-LIBINT2_REALTYPE fp281;
-fp281 = src2[((hsi*10+7)*1+lsi)*1] - fp282;
 LIBINT2_REALTYPE fp19;
 fp19 = inteval->oo2z[vi] * fp281;
 LIBINT2_REALTYPE fp21;
@@ -71,10 +441,6 @@ fp18 = fp20 + fp19;
 LIBINT2_REALTYPE fp16;
 fp16 = fp18 + fp17;
 target[((hsi*60+57)*1+lsi)*1] = fp16;
-LIBINT2_REALTYPE fp289;
-fp289 = inteval->roz[vi] * src3[((hsi*10+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp288;
-fp288 = src2[((hsi*10+6)*1+lsi)*1] - fp289;
 LIBINT2_REALTYPE fp24;
 fp24 = inteval->oo2z[vi] * fp288;
 LIBINT2_REALTYPE fp26;
@@ -90,10 +456,6 @@ LIBINT2_REALTYPE fp30;
 fp30 = 2 * inteval->oo2ze[vi];
 LIBINT2_REALTYPE fp29;
 fp29 = fp30 * src4[((hsi*18+14)*1+lsi)*1];
-LIBINT2_REALTYPE fp298;
-fp298 = inteval->roz[vi] * src3[((hsi*10+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp297;
-fp297 = src2[((hsi*10+5)*1+lsi)*1] - fp298;
 LIBINT2_REALTYPE fp32;
 fp32 = inteval->oo2z[vi] * fp297;
 LIBINT2_REALTYPE fp34;
@@ -109,10 +471,6 @@ fp28 = fp31 + fp29;
 target[((hsi*60+55)*1+lsi)*1] = fp28;
 LIBINT2_REALTYPE fp37;
 fp37 = inteval->oo2ze[vi] * src4[((hsi*18+13)*1+lsi)*1];
-LIBINT2_REALTYPE fp307;
-fp307 = inteval->roz[vi] * src3[((hsi*10+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp306;
-fp306 = src2[((hsi*10+4)*1+lsi)*1] - fp307;
 LIBINT2_REALTYPE fp39;
 fp39 = inteval->oo2z[vi] * fp306;
 LIBINT2_REALTYPE fp41;
@@ -126,10 +484,6 @@ fp38 = fp40 + fp39;
 LIBINT2_REALTYPE fp36;
 fp36 = fp38 + fp37;
 target[((hsi*60+54)*1+lsi)*1] = fp36;
-LIBINT2_REALTYPE fp316;
-fp316 = inteval->roz[vi] * src3[((hsi*10+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp315;
-fp315 = src2[((hsi*10+3)*1+lsi)*1] - fp316;
 LIBINT2_REALTYPE fp44;
 fp44 = inteval->oo2z[vi] * fp315;
 LIBINT2_REALTYPE fp46;
@@ -143,10 +497,6 @@ fp43 = fp45 + fp44;
 target[((hsi*60+53)*1+lsi)*1] = fp43;
 LIBINT2_REALTYPE fp49;
 fp49 = inteval->oo2ze[vi] * src4[((hsi*18+12)*1+lsi)*1];
-LIBINT2_REALTYPE fp326;
-fp326 = inteval->roz[vi] * src3[((hsi*10+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp325;
-fp325 = src2[((hsi*10+2)*1+lsi)*1] - fp326;
 LIBINT2_REALTYPE fp51;
 fp51 = inteval->oo2z[vi] * fp325;
 LIBINT2_REALTYPE fp53;
@@ -160,10 +510,6 @@ fp50 = fp52 + fp51;
 LIBINT2_REALTYPE fp48;
 fp48 = fp50 + fp49;
 target[((hsi*60+52)*1+lsi)*1] = fp48;
-LIBINT2_REALTYPE fp336;
-fp336 = inteval->roz[vi] * src3[((hsi*10+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp335;
-fp335 = src2[((hsi*10+1)*1+lsi)*1] - fp336;
 LIBINT2_REALTYPE fp56;
 fp56 = inteval->oo2z[vi] * fp335;
 LIBINT2_REALTYPE fp58;
@@ -175,10 +521,6 @@ fp57 = fp59 + fp58;
 LIBINT2_REALTYPE fp55;
 fp55 = fp57 + fp56;
 target[((hsi*60+51)*1+lsi)*1] = fp55;
-LIBINT2_REALTYPE fp346;
-fp346 = inteval->roz[vi] * src3[((hsi*10+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp345;
-fp345 = src2[((hsi*10+0)*1+lsi)*1] - fp346;
 LIBINT2_REALTYPE fp61;
 fp61 = inteval->oo2z[vi] * fp345;
 LIBINT2_REALTYPE fp63;
@@ -430,346 +772,6 @@ fp172 = fp174 + fp173;
 LIBINT2_REALTYPE fp170;
 fp170 = fp172 + fp171;
 target[((hsi*60+30)*1+lsi)*1] = fp170;
-LIBINT2_REALTYPE fp177;
-fp177 = 3 * inteval->oo2ze[vi];
-LIBINT2_REALTYPE fp176;
-fp176 = fp177 * src4[((hsi*18+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp179;
-fp179 = inteval->WP_z[vi] * src1[((hsi*30+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp180;
-fp180 = inteval->PA_z[vi] * src0[((hsi*30+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp178;
-fp178 = fp180 + fp179;
-LIBINT2_REALTYPE fp175;
-fp175 = fp178 + fp176;
-target[((hsi*60+29)*1+lsi)*1] = fp175;
-LIBINT2_REALTYPE fp183;
-fp183 = 2 * inteval->oo2ze[vi];
-LIBINT2_REALTYPE fp182;
-fp182 = fp183 * src4[((hsi*18+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp185;
-fp185 = inteval->WP_z[vi] * src1[((hsi*30+8)*1+lsi)*1];
-LIBINT2_REALTYPE fp186;
-fp186 = inteval->PA_z[vi] * src0[((hsi*30+8)*1+lsi)*1];
-LIBINT2_REALTYPE fp184;
-fp184 = fp186 + fp185;
-LIBINT2_REALTYPE fp181;
-fp181 = fp184 + fp182;
-target[((hsi*60+28)*1+lsi)*1] = fp181;
-LIBINT2_REALTYPE fp188;
-fp188 = inteval->oo2ze[vi] * src4[((hsi*18+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp190;
-fp190 = inteval->WP_z[vi] * src1[((hsi*30+7)*1+lsi)*1];
-LIBINT2_REALTYPE fp191;
-fp191 = inteval->PA_z[vi] * src0[((hsi*30+7)*1+lsi)*1];
-LIBINT2_REALTYPE fp189;
-fp189 = fp191 + fp190;
-LIBINT2_REALTYPE fp187;
-fp187 = fp189 + fp188;
-target[((hsi*60+27)*1+lsi)*1] = fp187;
-LIBINT2_REALTYPE fp193;
-fp193 = inteval->WP_z[vi] * src1[((hsi*30+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp194;
-fp194 = inteval->PA_z[vi] * src0[((hsi*30+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp192;
-fp192 = fp194 + fp193;
-target[((hsi*60+26)*1+lsi)*1] = fp192;
-LIBINT2_REALTYPE fp197;
-fp197 = 2 * inteval->oo2ze[vi];
-LIBINT2_REALTYPE fp196;
-fp196 = fp197 * src4[((hsi*18+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp199;
-fp199 = inteval->WP_z[vi] * src1[((hsi*30+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp200;
-fp200 = inteval->PA_z[vi] * src0[((hsi*30+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp198;
-fp198 = fp200 + fp199;
-LIBINT2_REALTYPE fp195;
-fp195 = fp198 + fp196;
-target[((hsi*60+25)*1+lsi)*1] = fp195;
-LIBINT2_REALTYPE fp202;
-fp202 = inteval->oo2ze[vi] * src4[((hsi*18+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp204;
-fp204 = inteval->WP_z[vi] * src1[((hsi*30+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp205;
-fp205 = inteval->PA_z[vi] * src0[((hsi*30+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp203;
-fp203 = fp205 + fp204;
-LIBINT2_REALTYPE fp201;
-fp201 = fp203 + fp202;
-target[((hsi*60+24)*1+lsi)*1] = fp201;
-LIBINT2_REALTYPE fp207;
-fp207 = inteval->WP_z[vi] * src1[((hsi*30+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp208;
-fp208 = inteval->PA_z[vi] * src0[((hsi*30+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp206;
-fp206 = fp208 + fp207;
-target[((hsi*60+23)*1+lsi)*1] = fp206;
-LIBINT2_REALTYPE fp210;
-fp210 = inteval->oo2ze[vi] * src4[((hsi*18+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp212;
-fp212 = inteval->WP_z[vi] * src1[((hsi*30+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp213;
-fp213 = inteval->PA_z[vi] * src0[((hsi*30+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp211;
-fp211 = fp213 + fp212;
-LIBINT2_REALTYPE fp209;
-fp209 = fp211 + fp210;
-target[((hsi*60+22)*1+lsi)*1] = fp209;
-LIBINT2_REALTYPE fp215;
-fp215 = inteval->WP_z[vi] * src1[((hsi*30+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp216;
-fp216 = inteval->PA_z[vi] * src0[((hsi*30+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp214;
-fp214 = fp216 + fp215;
-target[((hsi*60+21)*1+lsi)*1] = fp214;
-LIBINT2_REALTYPE fp218;
-fp218 = inteval->WP_z[vi] * src1[((hsi*30+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp219;
-fp219 = inteval->PA_z[vi] * src0[((hsi*30+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp217;
-fp217 = fp219 + fp218;
-target[((hsi*60+20)*1+lsi)*1] = fp217;
-LIBINT2_REALTYPE fp221;
-fp221 = inteval->WP_y[vi] * src1[((hsi*30+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp222;
-fp222 = inteval->PA_y[vi] * src0[((hsi*30+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp220;
-fp220 = fp222 + fp221;
-target[((hsi*60+19)*1+lsi)*1] = fp220;
-LIBINT2_REALTYPE fp224;
-fp224 = inteval->oo2ze[vi] * src4[((hsi*18+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp226;
-fp226 = inteval->WP_y[vi] * src1[((hsi*30+8)*1+lsi)*1];
-LIBINT2_REALTYPE fp227;
-fp227 = inteval->PA_y[vi] * src0[((hsi*30+8)*1+lsi)*1];
-LIBINT2_REALTYPE fp225;
-fp225 = fp227 + fp226;
-LIBINT2_REALTYPE fp223;
-fp223 = fp225 + fp224;
-target[((hsi*60+18)*1+lsi)*1] = fp223;
-LIBINT2_REALTYPE fp230;
-fp230 = 2 * inteval->oo2ze[vi];
-LIBINT2_REALTYPE fp229;
-fp229 = fp230 * src4[((hsi*18+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp232;
-fp232 = inteval->WP_y[vi] * src1[((hsi*30+7)*1+lsi)*1];
-LIBINT2_REALTYPE fp233;
-fp233 = inteval->PA_y[vi] * src0[((hsi*30+7)*1+lsi)*1];
-LIBINT2_REALTYPE fp231;
-fp231 = fp233 + fp232;
-LIBINT2_REALTYPE fp228;
-fp228 = fp231 + fp229;
-target[((hsi*60+17)*1+lsi)*1] = fp228;
-LIBINT2_REALTYPE fp236;
-fp236 = 3 * inteval->oo2ze[vi];
-LIBINT2_REALTYPE fp235;
-fp235 = fp236 * src4[((hsi*18+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp238;
-fp238 = inteval->WP_y[vi] * src1[((hsi*30+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp239;
-fp239 = inteval->PA_y[vi] * src0[((hsi*30+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp237;
-fp237 = fp239 + fp238;
-LIBINT2_REALTYPE fp234;
-fp234 = fp237 + fp235;
-target[((hsi*60+16)*1+lsi)*1] = fp234;
-LIBINT2_REALTYPE fp241;
-fp241 = inteval->WP_y[vi] * src1[((hsi*30+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp242;
-fp242 = inteval->PA_y[vi] * src0[((hsi*30+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp240;
-fp240 = fp242 + fp241;
-target[((hsi*60+15)*1+lsi)*1] = fp240;
-LIBINT2_REALTYPE fp244;
-fp244 = inteval->oo2ze[vi] * src4[((hsi*18+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp246;
-fp246 = inteval->WP_y[vi] * src1[((hsi*30+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp247;
-fp247 = inteval->PA_y[vi] * src0[((hsi*30+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp245;
-fp245 = fp247 + fp246;
-LIBINT2_REALTYPE fp243;
-fp243 = fp245 + fp244;
-target[((hsi*60+14)*1+lsi)*1] = fp243;
-LIBINT2_REALTYPE fp250;
-fp250 = 2 * inteval->oo2ze[vi];
-LIBINT2_REALTYPE fp249;
-fp249 = fp250 * src4[((hsi*18+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp252;
-fp252 = inteval->WP_y[vi] * src1[((hsi*30+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp253;
-fp253 = inteval->PA_y[vi] * src0[((hsi*30+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp251;
-fp251 = fp253 + fp252;
-LIBINT2_REALTYPE fp248;
-fp248 = fp251 + fp249;
-target[((hsi*60+13)*1+lsi)*1] = fp248;
-LIBINT2_REALTYPE fp255;
-fp255 = inteval->WP_y[vi] * src1[((hsi*30+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp256;
-fp256 = inteval->PA_y[vi] * src0[((hsi*30+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp254;
-fp254 = fp256 + fp255;
-target[((hsi*60+12)*1+lsi)*1] = fp254;
-LIBINT2_REALTYPE fp258;
-fp258 = inteval->oo2ze[vi] * src4[((hsi*18+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp260;
-fp260 = inteval->WP_y[vi] * src1[((hsi*30+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp261;
-fp261 = inteval->PA_y[vi] * src0[((hsi*30+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp259;
-fp259 = fp261 + fp260;
-LIBINT2_REALTYPE fp257;
-fp257 = fp259 + fp258;
-target[((hsi*60+11)*1+lsi)*1] = fp257;
-LIBINT2_REALTYPE fp263;
-fp263 = inteval->WP_y[vi] * src1[((hsi*30+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp264;
-fp264 = inteval->PA_y[vi] * src0[((hsi*30+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp262;
-fp262 = fp264 + fp263;
-target[((hsi*60+10)*1+lsi)*1] = fp262;
-LIBINT2_REALTYPE fp266;
-fp266 = inteval->oo2z[vi] * fp267;
-LIBINT2_REALTYPE fp270;
-fp270 = inteval->WP_x[vi] * src1[((hsi*30+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp271;
-fp271 = inteval->PA_x[vi] * src0[((hsi*30+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp269;
-fp269 = fp271 + fp270;
-LIBINT2_REALTYPE fp265;
-fp265 = fp269 + fp266;
-target[((hsi*60+9)*1+lsi)*1] = fp265;
-LIBINT2_REALTYPE fp273;
-fp273 = inteval->oo2z[vi] * fp274;
-LIBINT2_REALTYPE fp277;
-fp277 = inteval->WP_x[vi] * src1[((hsi*30+8)*1+lsi)*1];
-LIBINT2_REALTYPE fp278;
-fp278 = inteval->PA_x[vi] * src0[((hsi*30+8)*1+lsi)*1];
-LIBINT2_REALTYPE fp276;
-fp276 = fp278 + fp277;
-LIBINT2_REALTYPE fp272;
-fp272 = fp276 + fp273;
-target[((hsi*60+8)*1+lsi)*1] = fp272;
-LIBINT2_REALTYPE fp280;
-fp280 = inteval->oo2z[vi] * fp281;
-LIBINT2_REALTYPE fp284;
-fp284 = inteval->WP_x[vi] * src1[((hsi*30+7)*1+lsi)*1];
-LIBINT2_REALTYPE fp285;
-fp285 = inteval->PA_x[vi] * src0[((hsi*30+7)*1+lsi)*1];
-LIBINT2_REALTYPE fp283;
-fp283 = fp285 + fp284;
-LIBINT2_REALTYPE fp279;
-fp279 = fp283 + fp280;
-target[((hsi*60+7)*1+lsi)*1] = fp279;
-LIBINT2_REALTYPE fp287;
-fp287 = inteval->oo2z[vi] * fp288;
-LIBINT2_REALTYPE fp291;
-fp291 = inteval->WP_x[vi] * src1[((hsi*30+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp292;
-fp292 = inteval->PA_x[vi] * src0[((hsi*30+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp290;
-fp290 = fp292 + fp291;
-LIBINT2_REALTYPE fp286;
-fp286 = fp290 + fp287;
-target[((hsi*60+6)*1+lsi)*1] = fp286;
-LIBINT2_REALTYPE fp294;
-fp294 = inteval->oo2ze[vi] * src4[((hsi*18+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp296;
-fp296 = inteval->oo2z[vi] * fp297;
-LIBINT2_REALTYPE fp300;
-fp300 = inteval->WP_x[vi] * src1[((hsi*30+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp301;
-fp301 = inteval->PA_x[vi] * src0[((hsi*30+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp299;
-fp299 = fp301 + fp300;
-LIBINT2_REALTYPE fp295;
-fp295 = fp299 + fp296;
-LIBINT2_REALTYPE fp293;
-fp293 = fp295 + fp294;
-target[((hsi*60+5)*1+lsi)*1] = fp293;
-LIBINT2_REALTYPE fp303;
-fp303 = inteval->oo2ze[vi] * src4[((hsi*18+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp305;
-fp305 = inteval->oo2z[vi] * fp306;
-LIBINT2_REALTYPE fp309;
-fp309 = inteval->WP_x[vi] * src1[((hsi*30+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp310;
-fp310 = inteval->PA_x[vi] * src0[((hsi*30+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp308;
-fp308 = fp310 + fp309;
-LIBINT2_REALTYPE fp304;
-fp304 = fp308 + fp305;
-LIBINT2_REALTYPE fp302;
-fp302 = fp304 + fp303;
-target[((hsi*60+4)*1+lsi)*1] = fp302;
-LIBINT2_REALTYPE fp312;
-fp312 = inteval->oo2ze[vi] * src4[((hsi*18+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp314;
-fp314 = inteval->oo2z[vi] * fp315;
-LIBINT2_REALTYPE fp318;
-fp318 = inteval->WP_x[vi] * src1[((hsi*30+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp319;
-fp319 = inteval->PA_x[vi] * src0[((hsi*30+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp317;
-fp317 = fp319 + fp318;
-LIBINT2_REALTYPE fp313;
-fp313 = fp317 + fp314;
-LIBINT2_REALTYPE fp311;
-fp311 = fp313 + fp312;
-target[((hsi*60+3)*1+lsi)*1] = fp311;
-LIBINT2_REALTYPE fp322;
-fp322 = 2 * inteval->oo2ze[vi];
-LIBINT2_REALTYPE fp321;
-fp321 = fp322 * src4[((hsi*18+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp324;
-fp324 = inteval->oo2z[vi] * fp325;
-LIBINT2_REALTYPE fp328;
-fp328 = inteval->WP_x[vi] * src1[((hsi*30+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp329;
-fp329 = inteval->PA_x[vi] * src0[((hsi*30+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp327;
-fp327 = fp329 + fp328;
-LIBINT2_REALTYPE fp323;
-fp323 = fp327 + fp324;
-LIBINT2_REALTYPE fp320;
-fp320 = fp323 + fp321;
-target[((hsi*60+2)*1+lsi)*1] = fp320;
-LIBINT2_REALTYPE fp332;
-fp332 = 2 * inteval->oo2ze[vi];
-LIBINT2_REALTYPE fp331;
-fp331 = fp332 * src4[((hsi*18+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp334;
-fp334 = inteval->oo2z[vi] * fp335;
-LIBINT2_REALTYPE fp338;
-fp338 = inteval->WP_x[vi] * src1[((hsi*30+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp339;
-fp339 = inteval->PA_x[vi] * src0[((hsi*30+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp337;
-fp337 = fp339 + fp338;
-LIBINT2_REALTYPE fp333;
-fp333 = fp337 + fp334;
-LIBINT2_REALTYPE fp330;
-fp330 = fp333 + fp331;
-target[((hsi*60+1)*1+lsi)*1] = fp330;
-LIBINT2_REALTYPE fp342;
-fp342 = 3 * inteval->oo2ze[vi];
-LIBINT2_REALTYPE fp341;
-fp341 = fp342 * src4[((hsi*18+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp344;
-fp344 = inteval->oo2z[vi] * fp345;
-LIBINT2_REALTYPE fp348;
-fp348 = inteval->WP_x[vi] * src1[((hsi*30+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp349;
-fp349 = inteval->PA_x[vi] * src0[((hsi*30+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp347;
-fp347 = fp349 + fp348;
-LIBINT2_REALTYPE fp343;
-fp343 = fp347 + fp344;
-LIBINT2_REALTYPE fp340;
-fp340 = fp343 + fp341;
-target[((hsi*60+0)*1+lsi)*1] = fp340;
 }
 }
 }
@@ -779,4 +781,6 @@ const int vi = 0;
 /** Number of flops = 350 */
 }
 
+#ifdef __cplusplus
 };
+#endif
