@@ -1,11 +1,15 @@
 #include <libint2.h>
 #include <OSVRR_xs_xs.h>
 
+#ifdef __cplusplus
 extern "C" {
+#endif
 void OSVRRP0InBra_aB_d__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(const Libint_t* inteval, LIBINT2_REALTYPE* target, const LIBINT2_REALTYPE* src0, const LIBINT2_REALTYPE* src1, const LIBINT2_REALTYPE* src2, const LIBINT2_REALTYPE* src3, const LIBINT2_REALTYPE* src4) {
 
 using namespace libint2;
-libint2::OSVRR_xs_xs<0,2,9,false>::compute(inteval,target,src0,src1,src2,src3,src4);
+libint2::OSVRR_xs_xs<0,2,9,false,false>::compute(inteval,target,src0,src1,src2,src3,src4);
 }
 
+#ifdef __cplusplus
 };
+#endif
