@@ -1,6 +1,8 @@
 #include <libint2.h>
 
+#ifdef __cplusplus
 extern "C" {
+#endif
 void OSVRRP0InBra_aB_f__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(const Libint_t* inteval, LIBINT2_REALTYPE* target, const LIBINT2_REALTYPE* src0, const LIBINT2_REALTYPE* src1, const LIBINT2_REALTYPE* src2, const LIBINT2_REALTYPE* src3, const LIBINT2_REALTYPE* src4) {
 
 LIBINT2_REALTYPE*const  stack = target;
@@ -10,6 +12,370 @@ const int hsi = 0;
 const int lsi = 0;
 {
 const int vi = 0;
+LIBINT2_REALTYPE fp211;
+fp211 = 2 * inteval->oo2ze[vi];
+LIBINT2_REALTYPE fp210;
+fp210 = fp211 * src4[((hsi*18+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp213;
+fp213 = inteval->WP_z[vi] * src1[((hsi*36+11)*1+lsi)*1];
+LIBINT2_REALTYPE fp214;
+fp214 = inteval->PA_z[vi] * src0[((hsi*36+11)*1+lsi)*1];
+LIBINT2_REALTYPE fp212;
+fp212 = fp214 + fp213;
+LIBINT2_REALTYPE fp209;
+fp209 = fp212 + fp210;
+target[((hsi*60+29)*1+lsi)*1] = fp209;
+LIBINT2_REALTYPE fp216;
+fp216 = inteval->oo2ze[vi] * src4[((hsi*18+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp218;
+fp218 = inteval->WP_z[vi] * src1[((hsi*36+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp219;
+fp219 = inteval->PA_z[vi] * src0[((hsi*36+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp217;
+fp217 = fp219 + fp218;
+LIBINT2_REALTYPE fp215;
+fp215 = fp217 + fp216;
+target[((hsi*60+28)*1+lsi)*1] = fp215;
+LIBINT2_REALTYPE fp221;
+fp221 = inteval->WP_z[vi] * src1[((hsi*36+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp222;
+fp222 = inteval->PA_z[vi] * src0[((hsi*36+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp220;
+fp220 = fp222 + fp221;
+target[((hsi*60+27)*1+lsi)*1] = fp220;
+LIBINT2_REALTYPE fp224;
+fp224 = inteval->oo2ze[vi] * src4[((hsi*18+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp226;
+fp226 = inteval->WP_z[vi] * src1[((hsi*36+8)*1+lsi)*1];
+LIBINT2_REALTYPE fp227;
+fp227 = inteval->PA_z[vi] * src0[((hsi*36+8)*1+lsi)*1];
+LIBINT2_REALTYPE fp225;
+fp225 = fp227 + fp226;
+LIBINT2_REALTYPE fp223;
+fp223 = fp225 + fp224;
+target[((hsi*60+26)*1+lsi)*1] = fp223;
+LIBINT2_REALTYPE fp229;
+fp229 = inteval->WP_z[vi] * src1[((hsi*36+7)*1+lsi)*1];
+LIBINT2_REALTYPE fp230;
+fp230 = inteval->PA_z[vi] * src0[((hsi*36+7)*1+lsi)*1];
+LIBINT2_REALTYPE fp228;
+fp228 = fp230 + fp229;
+target[((hsi*60+25)*1+lsi)*1] = fp228;
+LIBINT2_REALTYPE fp232;
+fp232 = inteval->WP_z[vi] * src1[((hsi*36+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp233;
+fp233 = inteval->PA_z[vi] * src0[((hsi*36+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp231;
+fp231 = fp233 + fp232;
+target[((hsi*60+24)*1+lsi)*1] = fp231;
+LIBINT2_REALTYPE fp324;
+fp324 = inteval->roz[vi] * src3[((hsi*18+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp323;
+fp323 = src2[((hsi*18+5)*1+lsi)*1] - fp324;
+LIBINT2_REALTYPE fp235;
+fp235 = inteval->oo2z[vi] * fp323;
+LIBINT2_REALTYPE fp237;
+fp237 = inteval->WP_y[vi] * src1[((hsi*36+11)*1+lsi)*1];
+LIBINT2_REALTYPE fp238;
+fp238 = inteval->PA_y[vi] * src0[((hsi*36+11)*1+lsi)*1];
+LIBINT2_REALTYPE fp236;
+fp236 = fp238 + fp237;
+LIBINT2_REALTYPE fp234;
+fp234 = fp236 + fp235;
+target[((hsi*60+23)*1+lsi)*1] = fp234;
+LIBINT2_REALTYPE fp240;
+fp240 = inteval->oo2ze[vi] * src4[((hsi*18+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp332;
+fp332 = inteval->roz[vi] * src3[((hsi*18+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp331;
+fp331 = src2[((hsi*18+4)*1+lsi)*1] - fp332;
+LIBINT2_REALTYPE fp242;
+fp242 = inteval->oo2z[vi] * fp331;
+LIBINT2_REALTYPE fp244;
+fp244 = inteval->WP_y[vi] * src1[((hsi*36+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp245;
+fp245 = inteval->PA_y[vi] * src0[((hsi*36+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp243;
+fp243 = fp245 + fp244;
+LIBINT2_REALTYPE fp241;
+fp241 = fp243 + fp242;
+LIBINT2_REALTYPE fp239;
+fp239 = fp241 + fp240;
+target[((hsi*60+22)*1+lsi)*1] = fp239;
+LIBINT2_REALTYPE fp248;
+fp248 = 2 * inteval->oo2ze[vi];
+LIBINT2_REALTYPE fp247;
+fp247 = fp248 * src4[((hsi*18+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp340;
+fp340 = inteval->roz[vi] * src3[((hsi*18+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp339;
+fp339 = src2[((hsi*18+3)*1+lsi)*1] - fp340;
+LIBINT2_REALTYPE fp250;
+fp250 = inteval->oo2z[vi] * fp339;
+LIBINT2_REALTYPE fp252;
+fp252 = inteval->WP_y[vi] * src1[((hsi*36+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp253;
+fp253 = inteval->PA_y[vi] * src0[((hsi*36+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp251;
+fp251 = fp253 + fp252;
+LIBINT2_REALTYPE fp249;
+fp249 = fp251 + fp250;
+LIBINT2_REALTYPE fp246;
+fp246 = fp249 + fp247;
+target[((hsi*60+21)*1+lsi)*1] = fp246;
+LIBINT2_REALTYPE fp350;
+fp350 = inteval->roz[vi] * src3[((hsi*18+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp349;
+fp349 = src2[((hsi*18+2)*1+lsi)*1] - fp350;
+LIBINT2_REALTYPE fp255;
+fp255 = inteval->oo2z[vi] * fp349;
+LIBINT2_REALTYPE fp257;
+fp257 = inteval->WP_y[vi] * src1[((hsi*36+8)*1+lsi)*1];
+LIBINT2_REALTYPE fp258;
+fp258 = inteval->PA_y[vi] * src0[((hsi*36+8)*1+lsi)*1];
+LIBINT2_REALTYPE fp256;
+fp256 = fp258 + fp257;
+LIBINT2_REALTYPE fp254;
+fp254 = fp256 + fp255;
+target[((hsi*60+20)*1+lsi)*1] = fp254;
+LIBINT2_REALTYPE fp260;
+fp260 = inteval->oo2ze[vi] * src4[((hsi*18+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp360;
+fp360 = inteval->roz[vi] * src3[((hsi*18+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp359;
+fp359 = src2[((hsi*18+1)*1+lsi)*1] - fp360;
+LIBINT2_REALTYPE fp262;
+fp262 = inteval->oo2z[vi] * fp359;
+LIBINT2_REALTYPE fp264;
+fp264 = inteval->WP_y[vi] * src1[((hsi*36+7)*1+lsi)*1];
+LIBINT2_REALTYPE fp265;
+fp265 = inteval->PA_y[vi] * src0[((hsi*36+7)*1+lsi)*1];
+LIBINT2_REALTYPE fp263;
+fp263 = fp265 + fp264;
+LIBINT2_REALTYPE fp261;
+fp261 = fp263 + fp262;
+LIBINT2_REALTYPE fp259;
+fp259 = fp261 + fp260;
+target[((hsi*60+19)*1+lsi)*1] = fp259;
+LIBINT2_REALTYPE fp371;
+fp371 = inteval->roz[vi] * src3[((hsi*18+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp370;
+fp370 = src2[((hsi*18+0)*1+lsi)*1] - fp371;
+LIBINT2_REALTYPE fp267;
+fp267 = inteval->oo2z[vi] * fp370;
+LIBINT2_REALTYPE fp269;
+fp269 = inteval->WP_y[vi] * src1[((hsi*36+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp270;
+fp270 = inteval->PA_y[vi] * src0[((hsi*36+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp268;
+fp268 = fp270 + fp269;
+LIBINT2_REALTYPE fp266;
+fp266 = fp268 + fp267;
+target[((hsi*60+18)*1+lsi)*1] = fp266;
+LIBINT2_REALTYPE fp273;
+fp273 = 2 * inteval->oo2ze[vi];
+LIBINT2_REALTYPE fp272;
+fp272 = fp273 * src4[((hsi*18+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp275;
+fp275 = inteval->WP_z[vi] * src1[((hsi*36+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp276;
+fp276 = inteval->PA_z[vi] * src0[((hsi*36+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp274;
+fp274 = fp276 + fp275;
+LIBINT2_REALTYPE fp271;
+fp271 = fp274 + fp272;
+target[((hsi*60+17)*1+lsi)*1] = fp271;
+LIBINT2_REALTYPE fp278;
+fp278 = inteval->oo2ze[vi] * src4[((hsi*18+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp280;
+fp280 = inteval->WP_z[vi] * src1[((hsi*36+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp281;
+fp281 = inteval->PA_z[vi] * src0[((hsi*36+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp279;
+fp279 = fp281 + fp280;
+LIBINT2_REALTYPE fp277;
+fp277 = fp279 + fp278;
+target[((hsi*60+16)*1+lsi)*1] = fp277;
+LIBINT2_REALTYPE fp283;
+fp283 = inteval->WP_z[vi] * src1[((hsi*36+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp284;
+fp284 = inteval->PA_z[vi] * src0[((hsi*36+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp282;
+fp282 = fp284 + fp283;
+target[((hsi*60+15)*1+lsi)*1] = fp282;
+LIBINT2_REALTYPE fp286;
+fp286 = inteval->oo2ze[vi] * src4[((hsi*18+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp288;
+fp288 = inteval->WP_z[vi] * src1[((hsi*36+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp289;
+fp289 = inteval->PA_z[vi] * src0[((hsi*36+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp287;
+fp287 = fp289 + fp288;
+LIBINT2_REALTYPE fp285;
+fp285 = fp287 + fp286;
+target[((hsi*60+14)*1+lsi)*1] = fp285;
+LIBINT2_REALTYPE fp291;
+fp291 = inteval->WP_z[vi] * src1[((hsi*36+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp292;
+fp292 = inteval->PA_z[vi] * src0[((hsi*36+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp290;
+fp290 = fp292 + fp291;
+target[((hsi*60+13)*1+lsi)*1] = fp290;
+LIBINT2_REALTYPE fp294;
+fp294 = inteval->WP_z[vi] * src1[((hsi*36+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp295;
+fp295 = inteval->PA_z[vi] * src0[((hsi*36+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp293;
+fp293 = fp295 + fp294;
+target[((hsi*60+12)*1+lsi)*1] = fp293;
+LIBINT2_REALTYPE fp297;
+fp297 = inteval->WP_y[vi] * src1[((hsi*36+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp298;
+fp298 = inteval->PA_y[vi] * src0[((hsi*36+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp296;
+fp296 = fp298 + fp297;
+target[((hsi*60+11)*1+lsi)*1] = fp296;
+LIBINT2_REALTYPE fp300;
+fp300 = inteval->oo2ze[vi] * src4[((hsi*18+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp302;
+fp302 = inteval->WP_y[vi] * src1[((hsi*36+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp303;
+fp303 = inteval->PA_y[vi] * src0[((hsi*36+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp301;
+fp301 = fp303 + fp302;
+LIBINT2_REALTYPE fp299;
+fp299 = fp301 + fp300;
+target[((hsi*60+10)*1+lsi)*1] = fp299;
+LIBINT2_REALTYPE fp306;
+fp306 = 2 * inteval->oo2ze[vi];
+LIBINT2_REALTYPE fp305;
+fp305 = fp306 * src4[((hsi*18+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp308;
+fp308 = inteval->WP_y[vi] * src1[((hsi*36+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp309;
+fp309 = inteval->PA_y[vi] * src0[((hsi*36+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp307;
+fp307 = fp309 + fp308;
+LIBINT2_REALTYPE fp304;
+fp304 = fp307 + fp305;
+target[((hsi*60+9)*1+lsi)*1] = fp304;
+LIBINT2_REALTYPE fp311;
+fp311 = inteval->WP_y[vi] * src1[((hsi*36+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp312;
+fp312 = inteval->PA_y[vi] * src0[((hsi*36+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp310;
+fp310 = fp312 + fp311;
+target[((hsi*60+8)*1+lsi)*1] = fp310;
+LIBINT2_REALTYPE fp314;
+fp314 = inteval->oo2ze[vi] * src4[((hsi*18+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp316;
+fp316 = inteval->WP_y[vi] * src1[((hsi*36+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp317;
+fp317 = inteval->PA_y[vi] * src0[((hsi*36+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp315;
+fp315 = fp317 + fp316;
+LIBINT2_REALTYPE fp313;
+fp313 = fp315 + fp314;
+target[((hsi*60+7)*1+lsi)*1] = fp313;
+LIBINT2_REALTYPE fp319;
+fp319 = inteval->WP_y[vi] * src1[((hsi*36+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp320;
+fp320 = inteval->PA_y[vi] * src0[((hsi*36+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp318;
+fp318 = fp320 + fp319;
+target[((hsi*60+6)*1+lsi)*1] = fp318;
+LIBINT2_REALTYPE fp325;
+fp325 = 2 * inteval->oo2z[vi];
+LIBINT2_REALTYPE fp322;
+fp322 = fp325 * fp323;
+LIBINT2_REALTYPE fp327;
+fp327 = inteval->WP_x[vi] * src1[((hsi*36+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp328;
+fp328 = inteval->PA_x[vi] * src0[((hsi*36+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp326;
+fp326 = fp328 + fp327;
+LIBINT2_REALTYPE fp321;
+fp321 = fp326 + fp322;
+target[((hsi*60+5)*1+lsi)*1] = fp321;
+LIBINT2_REALTYPE fp333;
+fp333 = 2 * inteval->oo2z[vi];
+LIBINT2_REALTYPE fp330;
+fp330 = fp333 * fp331;
+LIBINT2_REALTYPE fp335;
+fp335 = inteval->WP_x[vi] * src1[((hsi*36+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp336;
+fp336 = inteval->PA_x[vi] * src0[((hsi*36+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp334;
+fp334 = fp336 + fp335;
+LIBINT2_REALTYPE fp329;
+fp329 = fp334 + fp330;
+target[((hsi*60+4)*1+lsi)*1] = fp329;
+LIBINT2_REALTYPE fp341;
+fp341 = 2 * inteval->oo2z[vi];
+LIBINT2_REALTYPE fp338;
+fp338 = fp341 * fp339;
+LIBINT2_REALTYPE fp343;
+fp343 = inteval->WP_x[vi] * src1[((hsi*36+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp344;
+fp344 = inteval->PA_x[vi] * src0[((hsi*36+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp342;
+fp342 = fp344 + fp343;
+LIBINT2_REALTYPE fp337;
+fp337 = fp342 + fp338;
+target[((hsi*60+3)*1+lsi)*1] = fp337;
+LIBINT2_REALTYPE fp346;
+fp346 = inteval->oo2ze[vi] * src4[((hsi*18+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp351;
+fp351 = 2 * inteval->oo2z[vi];
+LIBINT2_REALTYPE fp348;
+fp348 = fp351 * fp349;
+LIBINT2_REALTYPE fp353;
+fp353 = inteval->WP_x[vi] * src1[((hsi*36+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp354;
+fp354 = inteval->PA_x[vi] * src0[((hsi*36+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp352;
+fp352 = fp354 + fp353;
+LIBINT2_REALTYPE fp347;
+fp347 = fp352 + fp348;
+LIBINT2_REALTYPE fp345;
+fp345 = fp347 + fp346;
+target[((hsi*60+2)*1+lsi)*1] = fp345;
+LIBINT2_REALTYPE fp356;
+fp356 = inteval->oo2ze[vi] * src4[((hsi*18+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp361;
+fp361 = 2 * inteval->oo2z[vi];
+LIBINT2_REALTYPE fp358;
+fp358 = fp361 * fp359;
+LIBINT2_REALTYPE fp363;
+fp363 = inteval->WP_x[vi] * src1[((hsi*36+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp364;
+fp364 = inteval->PA_x[vi] * src0[((hsi*36+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp362;
+fp362 = fp364 + fp363;
+LIBINT2_REALTYPE fp357;
+fp357 = fp362 + fp358;
+LIBINT2_REALTYPE fp355;
+fp355 = fp357 + fp356;
+target[((hsi*60+1)*1+lsi)*1] = fp355;
+LIBINT2_REALTYPE fp367;
+fp367 = 2 * inteval->oo2ze[vi];
+LIBINT2_REALTYPE fp366;
+fp366 = fp367 * src4[((hsi*18+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp372;
+fp372 = 2 * inteval->oo2z[vi];
+LIBINT2_REALTYPE fp369;
+fp369 = fp372 * fp370;
+LIBINT2_REALTYPE fp374;
+fp374 = inteval->WP_x[vi] * src1[((hsi*36+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp375;
+fp375 = inteval->PA_x[vi] * src0[((hsi*36+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp373;
+fp373 = fp375 + fp374;
+LIBINT2_REALTYPE fp368;
+fp368 = fp373 + fp369;
+LIBINT2_REALTYPE fp365;
+fp365 = fp368 + fp366;
+target[((hsi*60+0)*1+lsi)*1] = fp365;
 LIBINT2_REALTYPE fp2;
 fp2 = 2 * inteval->oo2ze[vi];
 LIBINT2_REALTYPE fp1;
@@ -382,10 +748,6 @@ LIBINT2_REALTYPE fp174;
 fp174 = 2 * inteval->oo2ze[vi];
 LIBINT2_REALTYPE fp173;
 fp173 = fp174 * src4[((hsi*18+8)*1+lsi)*1];
-LIBINT2_REALTYPE fp324;
-fp324 = inteval->roz[vi] * src3[((hsi*18+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp323;
-fp323 = src2[((hsi*18+5)*1+lsi)*1] - fp324;
 LIBINT2_REALTYPE fp176;
 fp176 = inteval->oo2z[vi] * fp323;
 LIBINT2_REALTYPE fp178;
@@ -401,10 +763,6 @@ fp172 = fp175 + fp173;
 target[((hsi*60+35)*1+lsi)*1] = fp172;
 LIBINT2_REALTYPE fp181;
 fp181 = inteval->oo2ze[vi] * src4[((hsi*18+7)*1+lsi)*1];
-LIBINT2_REALTYPE fp332;
-fp332 = inteval->roz[vi] * src3[((hsi*18+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp331;
-fp331 = src2[((hsi*18+4)*1+lsi)*1] - fp332;
 LIBINT2_REALTYPE fp183;
 fp183 = inteval->oo2z[vi] * fp331;
 LIBINT2_REALTYPE fp185;
@@ -418,10 +776,6 @@ fp182 = fp184 + fp183;
 LIBINT2_REALTYPE fp180;
 fp180 = fp182 + fp181;
 target[((hsi*60+34)*1+lsi)*1] = fp180;
-LIBINT2_REALTYPE fp340;
-fp340 = inteval->roz[vi] * src3[((hsi*18+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp339;
-fp339 = src2[((hsi*18+3)*1+lsi)*1] - fp340;
 LIBINT2_REALTYPE fp188;
 fp188 = inteval->oo2z[vi] * fp339;
 LIBINT2_REALTYPE fp190;
@@ -435,10 +789,6 @@ fp187 = fp189 + fp188;
 target[((hsi*60+33)*1+lsi)*1] = fp187;
 LIBINT2_REALTYPE fp193;
 fp193 = inteval->oo2ze[vi] * src4[((hsi*18+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp350;
-fp350 = inteval->roz[vi] * src3[((hsi*18+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp349;
-fp349 = src2[((hsi*18+2)*1+lsi)*1] - fp350;
 LIBINT2_REALTYPE fp195;
 fp195 = inteval->oo2z[vi] * fp349;
 LIBINT2_REALTYPE fp197;
@@ -452,10 +802,6 @@ fp194 = fp196 + fp195;
 LIBINT2_REALTYPE fp192;
 fp192 = fp194 + fp193;
 target[((hsi*60+32)*1+lsi)*1] = fp192;
-LIBINT2_REALTYPE fp360;
-fp360 = inteval->roz[vi] * src3[((hsi*18+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp359;
-fp359 = src2[((hsi*18+1)*1+lsi)*1] - fp360;
 LIBINT2_REALTYPE fp200;
 fp200 = inteval->oo2z[vi] * fp359;
 LIBINT2_REALTYPE fp202;
@@ -467,10 +813,6 @@ fp201 = fp203 + fp202;
 LIBINT2_REALTYPE fp199;
 fp199 = fp201 + fp200;
 target[((hsi*60+31)*1+lsi)*1] = fp199;
-LIBINT2_REALTYPE fp371;
-fp371 = inteval->roz[vi] * src3[((hsi*18+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp370;
-fp370 = src2[((hsi*18+0)*1+lsi)*1] - fp371;
 LIBINT2_REALTYPE fp205;
 fp205 = inteval->oo2z[vi] * fp370;
 LIBINT2_REALTYPE fp207;
@@ -482,346 +824,6 @@ fp206 = fp208 + fp207;
 LIBINT2_REALTYPE fp204;
 fp204 = fp206 + fp205;
 target[((hsi*60+30)*1+lsi)*1] = fp204;
-LIBINT2_REALTYPE fp211;
-fp211 = 2 * inteval->oo2ze[vi];
-LIBINT2_REALTYPE fp210;
-fp210 = fp211 * src4[((hsi*18+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp213;
-fp213 = inteval->WP_z[vi] * src1[((hsi*36+11)*1+lsi)*1];
-LIBINT2_REALTYPE fp214;
-fp214 = inteval->PA_z[vi] * src0[((hsi*36+11)*1+lsi)*1];
-LIBINT2_REALTYPE fp212;
-fp212 = fp214 + fp213;
-LIBINT2_REALTYPE fp209;
-fp209 = fp212 + fp210;
-target[((hsi*60+29)*1+lsi)*1] = fp209;
-LIBINT2_REALTYPE fp216;
-fp216 = inteval->oo2ze[vi] * src4[((hsi*18+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp218;
-fp218 = inteval->WP_z[vi] * src1[((hsi*36+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp219;
-fp219 = inteval->PA_z[vi] * src0[((hsi*36+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp217;
-fp217 = fp219 + fp218;
-LIBINT2_REALTYPE fp215;
-fp215 = fp217 + fp216;
-target[((hsi*60+28)*1+lsi)*1] = fp215;
-LIBINT2_REALTYPE fp221;
-fp221 = inteval->WP_z[vi] * src1[((hsi*36+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp222;
-fp222 = inteval->PA_z[vi] * src0[((hsi*36+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp220;
-fp220 = fp222 + fp221;
-target[((hsi*60+27)*1+lsi)*1] = fp220;
-LIBINT2_REALTYPE fp224;
-fp224 = inteval->oo2ze[vi] * src4[((hsi*18+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp226;
-fp226 = inteval->WP_z[vi] * src1[((hsi*36+8)*1+lsi)*1];
-LIBINT2_REALTYPE fp227;
-fp227 = inteval->PA_z[vi] * src0[((hsi*36+8)*1+lsi)*1];
-LIBINT2_REALTYPE fp225;
-fp225 = fp227 + fp226;
-LIBINT2_REALTYPE fp223;
-fp223 = fp225 + fp224;
-target[((hsi*60+26)*1+lsi)*1] = fp223;
-LIBINT2_REALTYPE fp229;
-fp229 = inteval->WP_z[vi] * src1[((hsi*36+7)*1+lsi)*1];
-LIBINT2_REALTYPE fp230;
-fp230 = inteval->PA_z[vi] * src0[((hsi*36+7)*1+lsi)*1];
-LIBINT2_REALTYPE fp228;
-fp228 = fp230 + fp229;
-target[((hsi*60+25)*1+lsi)*1] = fp228;
-LIBINT2_REALTYPE fp232;
-fp232 = inteval->WP_z[vi] * src1[((hsi*36+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp233;
-fp233 = inteval->PA_z[vi] * src0[((hsi*36+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp231;
-fp231 = fp233 + fp232;
-target[((hsi*60+24)*1+lsi)*1] = fp231;
-LIBINT2_REALTYPE fp235;
-fp235 = inteval->oo2z[vi] * fp323;
-LIBINT2_REALTYPE fp237;
-fp237 = inteval->WP_y[vi] * src1[((hsi*36+11)*1+lsi)*1];
-LIBINT2_REALTYPE fp238;
-fp238 = inteval->PA_y[vi] * src0[((hsi*36+11)*1+lsi)*1];
-LIBINT2_REALTYPE fp236;
-fp236 = fp238 + fp237;
-LIBINT2_REALTYPE fp234;
-fp234 = fp236 + fp235;
-target[((hsi*60+23)*1+lsi)*1] = fp234;
-LIBINT2_REALTYPE fp240;
-fp240 = inteval->oo2ze[vi] * src4[((hsi*18+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp242;
-fp242 = inteval->oo2z[vi] * fp331;
-LIBINT2_REALTYPE fp244;
-fp244 = inteval->WP_y[vi] * src1[((hsi*36+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp245;
-fp245 = inteval->PA_y[vi] * src0[((hsi*36+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp243;
-fp243 = fp245 + fp244;
-LIBINT2_REALTYPE fp241;
-fp241 = fp243 + fp242;
-LIBINT2_REALTYPE fp239;
-fp239 = fp241 + fp240;
-target[((hsi*60+22)*1+lsi)*1] = fp239;
-LIBINT2_REALTYPE fp248;
-fp248 = 2 * inteval->oo2ze[vi];
-LIBINT2_REALTYPE fp247;
-fp247 = fp248 * src4[((hsi*18+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp250;
-fp250 = inteval->oo2z[vi] * fp339;
-LIBINT2_REALTYPE fp252;
-fp252 = inteval->WP_y[vi] * src1[((hsi*36+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp253;
-fp253 = inteval->PA_y[vi] * src0[((hsi*36+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp251;
-fp251 = fp253 + fp252;
-LIBINT2_REALTYPE fp249;
-fp249 = fp251 + fp250;
-LIBINT2_REALTYPE fp246;
-fp246 = fp249 + fp247;
-target[((hsi*60+21)*1+lsi)*1] = fp246;
-LIBINT2_REALTYPE fp255;
-fp255 = inteval->oo2z[vi] * fp349;
-LIBINT2_REALTYPE fp257;
-fp257 = inteval->WP_y[vi] * src1[((hsi*36+8)*1+lsi)*1];
-LIBINT2_REALTYPE fp258;
-fp258 = inteval->PA_y[vi] * src0[((hsi*36+8)*1+lsi)*1];
-LIBINT2_REALTYPE fp256;
-fp256 = fp258 + fp257;
-LIBINT2_REALTYPE fp254;
-fp254 = fp256 + fp255;
-target[((hsi*60+20)*1+lsi)*1] = fp254;
-LIBINT2_REALTYPE fp260;
-fp260 = inteval->oo2ze[vi] * src4[((hsi*18+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp262;
-fp262 = inteval->oo2z[vi] * fp359;
-LIBINT2_REALTYPE fp264;
-fp264 = inteval->WP_y[vi] * src1[((hsi*36+7)*1+lsi)*1];
-LIBINT2_REALTYPE fp265;
-fp265 = inteval->PA_y[vi] * src0[((hsi*36+7)*1+lsi)*1];
-LIBINT2_REALTYPE fp263;
-fp263 = fp265 + fp264;
-LIBINT2_REALTYPE fp261;
-fp261 = fp263 + fp262;
-LIBINT2_REALTYPE fp259;
-fp259 = fp261 + fp260;
-target[((hsi*60+19)*1+lsi)*1] = fp259;
-LIBINT2_REALTYPE fp267;
-fp267 = inteval->oo2z[vi] * fp370;
-LIBINT2_REALTYPE fp269;
-fp269 = inteval->WP_y[vi] * src1[((hsi*36+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp270;
-fp270 = inteval->PA_y[vi] * src0[((hsi*36+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp268;
-fp268 = fp270 + fp269;
-LIBINT2_REALTYPE fp266;
-fp266 = fp268 + fp267;
-target[((hsi*60+18)*1+lsi)*1] = fp266;
-LIBINT2_REALTYPE fp273;
-fp273 = 2 * inteval->oo2ze[vi];
-LIBINT2_REALTYPE fp272;
-fp272 = fp273 * src4[((hsi*18+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp275;
-fp275 = inteval->WP_z[vi] * src1[((hsi*36+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp276;
-fp276 = inteval->PA_z[vi] * src0[((hsi*36+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp274;
-fp274 = fp276 + fp275;
-LIBINT2_REALTYPE fp271;
-fp271 = fp274 + fp272;
-target[((hsi*60+17)*1+lsi)*1] = fp271;
-LIBINT2_REALTYPE fp278;
-fp278 = inteval->oo2ze[vi] * src4[((hsi*18+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp280;
-fp280 = inteval->WP_z[vi] * src1[((hsi*36+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp281;
-fp281 = inteval->PA_z[vi] * src0[((hsi*36+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp279;
-fp279 = fp281 + fp280;
-LIBINT2_REALTYPE fp277;
-fp277 = fp279 + fp278;
-target[((hsi*60+16)*1+lsi)*1] = fp277;
-LIBINT2_REALTYPE fp283;
-fp283 = inteval->WP_z[vi] * src1[((hsi*36+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp284;
-fp284 = inteval->PA_z[vi] * src0[((hsi*36+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp282;
-fp282 = fp284 + fp283;
-target[((hsi*60+15)*1+lsi)*1] = fp282;
-LIBINT2_REALTYPE fp286;
-fp286 = inteval->oo2ze[vi] * src4[((hsi*18+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp288;
-fp288 = inteval->WP_z[vi] * src1[((hsi*36+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp289;
-fp289 = inteval->PA_z[vi] * src0[((hsi*36+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp287;
-fp287 = fp289 + fp288;
-LIBINT2_REALTYPE fp285;
-fp285 = fp287 + fp286;
-target[((hsi*60+14)*1+lsi)*1] = fp285;
-LIBINT2_REALTYPE fp291;
-fp291 = inteval->WP_z[vi] * src1[((hsi*36+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp292;
-fp292 = inteval->PA_z[vi] * src0[((hsi*36+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp290;
-fp290 = fp292 + fp291;
-target[((hsi*60+13)*1+lsi)*1] = fp290;
-LIBINT2_REALTYPE fp294;
-fp294 = inteval->WP_z[vi] * src1[((hsi*36+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp295;
-fp295 = inteval->PA_z[vi] * src0[((hsi*36+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp293;
-fp293 = fp295 + fp294;
-target[((hsi*60+12)*1+lsi)*1] = fp293;
-LIBINT2_REALTYPE fp297;
-fp297 = inteval->WP_y[vi] * src1[((hsi*36+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp298;
-fp298 = inteval->PA_y[vi] * src0[((hsi*36+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp296;
-fp296 = fp298 + fp297;
-target[((hsi*60+11)*1+lsi)*1] = fp296;
-LIBINT2_REALTYPE fp300;
-fp300 = inteval->oo2ze[vi] * src4[((hsi*18+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp302;
-fp302 = inteval->WP_y[vi] * src1[((hsi*36+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp303;
-fp303 = inteval->PA_y[vi] * src0[((hsi*36+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp301;
-fp301 = fp303 + fp302;
-LIBINT2_REALTYPE fp299;
-fp299 = fp301 + fp300;
-target[((hsi*60+10)*1+lsi)*1] = fp299;
-LIBINT2_REALTYPE fp306;
-fp306 = 2 * inteval->oo2ze[vi];
-LIBINT2_REALTYPE fp305;
-fp305 = fp306 * src4[((hsi*18+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp308;
-fp308 = inteval->WP_y[vi] * src1[((hsi*36+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp309;
-fp309 = inteval->PA_y[vi] * src0[((hsi*36+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp307;
-fp307 = fp309 + fp308;
-LIBINT2_REALTYPE fp304;
-fp304 = fp307 + fp305;
-target[((hsi*60+9)*1+lsi)*1] = fp304;
-LIBINT2_REALTYPE fp311;
-fp311 = inteval->WP_y[vi] * src1[((hsi*36+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp312;
-fp312 = inteval->PA_y[vi] * src0[((hsi*36+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp310;
-fp310 = fp312 + fp311;
-target[((hsi*60+8)*1+lsi)*1] = fp310;
-LIBINT2_REALTYPE fp314;
-fp314 = inteval->oo2ze[vi] * src4[((hsi*18+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp316;
-fp316 = inteval->WP_y[vi] * src1[((hsi*36+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp317;
-fp317 = inteval->PA_y[vi] * src0[((hsi*36+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp315;
-fp315 = fp317 + fp316;
-LIBINT2_REALTYPE fp313;
-fp313 = fp315 + fp314;
-target[((hsi*60+7)*1+lsi)*1] = fp313;
-LIBINT2_REALTYPE fp319;
-fp319 = inteval->WP_y[vi] * src1[((hsi*36+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp320;
-fp320 = inteval->PA_y[vi] * src0[((hsi*36+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp318;
-fp318 = fp320 + fp319;
-target[((hsi*60+6)*1+lsi)*1] = fp318;
-LIBINT2_REALTYPE fp325;
-fp325 = 2 * inteval->oo2z[vi];
-LIBINT2_REALTYPE fp322;
-fp322 = fp325 * fp323;
-LIBINT2_REALTYPE fp327;
-fp327 = inteval->WP_x[vi] * src1[((hsi*36+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp328;
-fp328 = inteval->PA_x[vi] * src0[((hsi*36+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp326;
-fp326 = fp328 + fp327;
-LIBINT2_REALTYPE fp321;
-fp321 = fp326 + fp322;
-target[((hsi*60+5)*1+lsi)*1] = fp321;
-LIBINT2_REALTYPE fp333;
-fp333 = 2 * inteval->oo2z[vi];
-LIBINT2_REALTYPE fp330;
-fp330 = fp333 * fp331;
-LIBINT2_REALTYPE fp335;
-fp335 = inteval->WP_x[vi] * src1[((hsi*36+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp336;
-fp336 = inteval->PA_x[vi] * src0[((hsi*36+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp334;
-fp334 = fp336 + fp335;
-LIBINT2_REALTYPE fp329;
-fp329 = fp334 + fp330;
-target[((hsi*60+4)*1+lsi)*1] = fp329;
-LIBINT2_REALTYPE fp341;
-fp341 = 2 * inteval->oo2z[vi];
-LIBINT2_REALTYPE fp338;
-fp338 = fp341 * fp339;
-LIBINT2_REALTYPE fp343;
-fp343 = inteval->WP_x[vi] * src1[((hsi*36+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp344;
-fp344 = inteval->PA_x[vi] * src0[((hsi*36+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp342;
-fp342 = fp344 + fp343;
-LIBINT2_REALTYPE fp337;
-fp337 = fp342 + fp338;
-target[((hsi*60+3)*1+lsi)*1] = fp337;
-LIBINT2_REALTYPE fp346;
-fp346 = inteval->oo2ze[vi] * src4[((hsi*18+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp351;
-fp351 = 2 * inteval->oo2z[vi];
-LIBINT2_REALTYPE fp348;
-fp348 = fp351 * fp349;
-LIBINT2_REALTYPE fp353;
-fp353 = inteval->WP_x[vi] * src1[((hsi*36+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp354;
-fp354 = inteval->PA_x[vi] * src0[((hsi*36+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp352;
-fp352 = fp354 + fp353;
-LIBINT2_REALTYPE fp347;
-fp347 = fp352 + fp348;
-LIBINT2_REALTYPE fp345;
-fp345 = fp347 + fp346;
-target[((hsi*60+2)*1+lsi)*1] = fp345;
-LIBINT2_REALTYPE fp356;
-fp356 = inteval->oo2ze[vi] * src4[((hsi*18+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp361;
-fp361 = 2 * inteval->oo2z[vi];
-LIBINT2_REALTYPE fp358;
-fp358 = fp361 * fp359;
-LIBINT2_REALTYPE fp363;
-fp363 = inteval->WP_x[vi] * src1[((hsi*36+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp364;
-fp364 = inteval->PA_x[vi] * src0[((hsi*36+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp362;
-fp362 = fp364 + fp363;
-LIBINT2_REALTYPE fp357;
-fp357 = fp362 + fp358;
-LIBINT2_REALTYPE fp355;
-fp355 = fp357 + fp356;
-target[((hsi*60+1)*1+lsi)*1] = fp355;
-LIBINT2_REALTYPE fp367;
-fp367 = 2 * inteval->oo2ze[vi];
-LIBINT2_REALTYPE fp366;
-fp366 = fp367 * src4[((hsi*18+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp372;
-fp372 = 2 * inteval->oo2z[vi];
-LIBINT2_REALTYPE fp369;
-fp369 = fp372 * fp370;
-LIBINT2_REALTYPE fp374;
-fp374 = inteval->WP_x[vi] * src1[((hsi*36+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp375;
-fp375 = inteval->PA_x[vi] * src0[((hsi*36+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp373;
-fp373 = fp375 + fp374;
-LIBINT2_REALTYPE fp368;
-fp368 = fp373 + fp369;
-LIBINT2_REALTYPE fp365;
-fp365 = fp368 + fp366;
-target[((hsi*60+0)*1+lsi)*1] = fp365;
 }
 }
 }
@@ -831,4 +833,6 @@ const int vi = 0;
 /** Number of flops = 376 */
 }
 
+#ifdef __cplusplus
 };
+#endif
