@@ -1,6 +1,8 @@
 #include <libint2.h>
 
+#ifdef __cplusplus
 extern "C" {
+#endif
 void OSVRRP0InBra_aB_g__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(const Libint_t* inteval, LIBINT2_REALTYPE* target, const LIBINT2_REALTYPE* src0, const LIBINT2_REALTYPE* src1, const LIBINT2_REALTYPE* src2, const LIBINT2_REALTYPE* src3, const LIBINT2_REALTYPE* src4) {
 
 LIBINT2_REALTYPE*const  stack = target;
@@ -10,6 +12,279 @@ const int hsi = 0;
 const int lsi = 0;
 {
 const int vi = 0;
+LIBINT2_REALTYPE fp155;
+fp155 = inteval->WP_z[vi] * src1[((hsi*30+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp156;
+fp156 = inteval->PA_z[vi] * src0[((hsi*30+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp154;
+fp154 = fp156 + fp155;
+target[((hsi*45+22)*1+lsi)*1] = fp154;
+LIBINT2_REALTYPE fp158;
+fp158 = inteval->WP_z[vi] * src1[((hsi*30+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp159;
+fp159 = inteval->PA_z[vi] * src0[((hsi*30+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp157;
+fp157 = fp159 + fp158;
+target[((hsi*45+21)*1+lsi)*1] = fp157;
+LIBINT2_REALTYPE fp163;
+fp163 = inteval->roz[vi] * src3[((hsi*18+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp162;
+fp162 = src2[((hsi*18+5)*1+lsi)*1] - fp163;
+LIBINT2_REALTYPE fp164;
+fp164 = 2 * inteval->oo2z[vi];
+LIBINT2_REALTYPE fp161;
+fp161 = fp164 * fp162;
+LIBINT2_REALTYPE fp166;
+fp166 = inteval->WP_y[vi] * src1[((hsi*30+11)*1+lsi)*1];
+LIBINT2_REALTYPE fp167;
+fp167 = inteval->PA_y[vi] * src0[((hsi*30+11)*1+lsi)*1];
+LIBINT2_REALTYPE fp165;
+fp165 = fp167 + fp166;
+LIBINT2_REALTYPE fp160;
+fp160 = fp165 + fp161;
+target[((hsi*45+20)*1+lsi)*1] = fp160;
+LIBINT2_REALTYPE fp169;
+fp169 = inteval->oo2ze[vi] * src4[((hsi*10+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp173;
+fp173 = inteval->roz[vi] * src3[((hsi*18+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp172;
+fp172 = src2[((hsi*18+4)*1+lsi)*1] - fp173;
+LIBINT2_REALTYPE fp174;
+fp174 = 2 * inteval->oo2z[vi];
+LIBINT2_REALTYPE fp171;
+fp171 = fp174 * fp172;
+LIBINT2_REALTYPE fp176;
+fp176 = inteval->WP_y[vi] * src1[((hsi*30+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp177;
+fp177 = inteval->PA_y[vi] * src0[((hsi*30+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp175;
+fp175 = fp177 + fp176;
+LIBINT2_REALTYPE fp170;
+fp170 = fp175 + fp171;
+LIBINT2_REALTYPE fp168;
+fp168 = fp170 + fp169;
+target[((hsi*45+19)*1+lsi)*1] = fp168;
+LIBINT2_REALTYPE fp181;
+fp181 = inteval->roz[vi] * src3[((hsi*18+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp180;
+fp180 = src2[((hsi*18+3)*1+lsi)*1] - fp181;
+LIBINT2_REALTYPE fp182;
+fp182 = 2 * inteval->oo2z[vi];
+LIBINT2_REALTYPE fp179;
+fp179 = fp182 * fp180;
+LIBINT2_REALTYPE fp184;
+fp184 = inteval->WP_y[vi] * src1[((hsi*30+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp185;
+fp185 = inteval->PA_y[vi] * src0[((hsi*30+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp183;
+fp183 = fp185 + fp184;
+LIBINT2_REALTYPE fp178;
+fp178 = fp183 + fp179;
+target[((hsi*45+18)*1+lsi)*1] = fp178;
+LIBINT2_REALTYPE fp187;
+fp187 = inteval->oo2ze[vi] * src4[((hsi*10+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp256;
+fp256 = inteval->roz[vi] * src3[((hsi*18+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp255;
+fp255 = src2[((hsi*18+2)*1+lsi)*1] - fp256;
+LIBINT2_REALTYPE fp189;
+fp189 = inteval->oo2z[vi] * fp255;
+LIBINT2_REALTYPE fp191;
+fp191 = inteval->WP_z[vi] * src1[((hsi*30+8)*1+lsi)*1];
+LIBINT2_REALTYPE fp192;
+fp192 = inteval->PA_z[vi] * src0[((hsi*30+8)*1+lsi)*1];
+LIBINT2_REALTYPE fp190;
+fp190 = fp192 + fp191;
+LIBINT2_REALTYPE fp188;
+fp188 = fp190 + fp189;
+LIBINT2_REALTYPE fp186;
+fp186 = fp188 + fp187;
+target[((hsi*45+17)*1+lsi)*1] = fp186;
+LIBINT2_REALTYPE fp264;
+fp264 = inteval->roz[vi] * src3[((hsi*18+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp263;
+fp263 = src2[((hsi*18+1)*1+lsi)*1] - fp264;
+LIBINT2_REALTYPE fp194;
+fp194 = inteval->oo2z[vi] * fp263;
+LIBINT2_REALTYPE fp196;
+fp196 = inteval->WP_z[vi] * src1[((hsi*30+7)*1+lsi)*1];
+LIBINT2_REALTYPE fp197;
+fp197 = inteval->PA_z[vi] * src0[((hsi*30+7)*1+lsi)*1];
+LIBINT2_REALTYPE fp195;
+fp195 = fp197 + fp196;
+LIBINT2_REALTYPE fp193;
+fp193 = fp195 + fp194;
+target[((hsi*45+16)*1+lsi)*1] = fp193;
+LIBINT2_REALTYPE fp274;
+fp274 = inteval->roz[vi] * src3[((hsi*18+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp273;
+fp273 = src2[((hsi*18+0)*1+lsi)*1] - fp274;
+LIBINT2_REALTYPE fp199;
+fp199 = inteval->oo2z[vi] * fp273;
+LIBINT2_REALTYPE fp201;
+fp201 = inteval->WP_z[vi] * src1[((hsi*30+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp202;
+fp202 = inteval->PA_z[vi] * src0[((hsi*30+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp200;
+fp200 = fp202 + fp201;
+LIBINT2_REALTYPE fp198;
+fp198 = fp200 + fp199;
+target[((hsi*45+15)*1+lsi)*1] = fp198;
+LIBINT2_REALTYPE fp204;
+fp204 = inteval->oo2ze[vi] * src4[((hsi*10+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp206;
+fp206 = inteval->WP_z[vi] * src1[((hsi*30+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp207;
+fp207 = inteval->PA_z[vi] * src0[((hsi*30+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp205;
+fp205 = fp207 + fp206;
+LIBINT2_REALTYPE fp203;
+fp203 = fp205 + fp204;
+target[((hsi*45+14)*1+lsi)*1] = fp203;
+LIBINT2_REALTYPE fp209;
+fp209 = inteval->WP_z[vi] * src1[((hsi*30+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp210;
+fp210 = inteval->PA_z[vi] * src0[((hsi*30+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp208;
+fp208 = fp210 + fp209;
+target[((hsi*45+13)*1+lsi)*1] = fp208;
+LIBINT2_REALTYPE fp212;
+fp212 = inteval->WP_z[vi] * src1[((hsi*30+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp213;
+fp213 = inteval->PA_z[vi] * src0[((hsi*30+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp211;
+fp211 = fp213 + fp212;
+target[((hsi*45+12)*1+lsi)*1] = fp211;
+LIBINT2_REALTYPE fp215;
+fp215 = inteval->oo2z[vi] * fp255;
+LIBINT2_REALTYPE fp217;
+fp217 = inteval->WP_y[vi] * src1[((hsi*30+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp218;
+fp218 = inteval->PA_y[vi] * src0[((hsi*30+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp216;
+fp216 = fp218 + fp217;
+LIBINT2_REALTYPE fp214;
+fp214 = fp216 + fp215;
+target[((hsi*45+11)*1+lsi)*1] = fp214;
+LIBINT2_REALTYPE fp220;
+fp220 = inteval->oo2ze[vi] * src4[((hsi*10+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp222;
+fp222 = inteval->oo2z[vi] * fp263;
+LIBINT2_REALTYPE fp224;
+fp224 = inteval->WP_y[vi] * src1[((hsi*30+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp225;
+fp225 = inteval->PA_y[vi] * src0[((hsi*30+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp223;
+fp223 = fp225 + fp224;
+LIBINT2_REALTYPE fp221;
+fp221 = fp223 + fp222;
+LIBINT2_REALTYPE fp219;
+fp219 = fp221 + fp220;
+target[((hsi*45+10)*1+lsi)*1] = fp219;
+LIBINT2_REALTYPE fp227;
+fp227 = inteval->oo2z[vi] * fp273;
+LIBINT2_REALTYPE fp229;
+fp229 = inteval->WP_y[vi] * src1[((hsi*30+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp230;
+fp230 = inteval->PA_y[vi] * src0[((hsi*30+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp228;
+fp228 = fp230 + fp229;
+LIBINT2_REALTYPE fp226;
+fp226 = fp228 + fp227;
+target[((hsi*45+9)*1+lsi)*1] = fp226;
+LIBINT2_REALTYPE fp232;
+fp232 = inteval->oo2ze[vi] * src4[((hsi*10+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp234;
+fp234 = inteval->WP_z[vi] * src1[((hsi*30+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp235;
+fp235 = inteval->PA_z[vi] * src0[((hsi*30+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp233;
+fp233 = fp235 + fp234;
+LIBINT2_REALTYPE fp231;
+fp231 = fp233 + fp232;
+target[((hsi*45+8)*1+lsi)*1] = fp231;
+LIBINT2_REALTYPE fp237;
+fp237 = inteval->WP_z[vi] * src1[((hsi*30+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp238;
+fp238 = inteval->PA_z[vi] * src0[((hsi*30+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp236;
+fp236 = fp238 + fp237;
+target[((hsi*45+7)*1+lsi)*1] = fp236;
+LIBINT2_REALTYPE fp240;
+fp240 = inteval->WP_z[vi] * src1[((hsi*30+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp241;
+fp241 = inteval->PA_z[vi] * src0[((hsi*30+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp239;
+fp239 = fp241 + fp240;
+target[((hsi*45+6)*1+lsi)*1] = fp239;
+LIBINT2_REALTYPE fp243;
+fp243 = inteval->WP_y[vi] * src1[((hsi*30+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp244;
+fp244 = inteval->PA_y[vi] * src0[((hsi*30+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp242;
+fp242 = fp244 + fp243;
+target[((hsi*45+5)*1+lsi)*1] = fp242;
+LIBINT2_REALTYPE fp246;
+fp246 = inteval->oo2ze[vi] * src4[((hsi*10+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp248;
+fp248 = inteval->WP_y[vi] * src1[((hsi*30+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp249;
+fp249 = inteval->PA_y[vi] * src0[((hsi*30+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp247;
+fp247 = fp249 + fp248;
+LIBINT2_REALTYPE fp245;
+fp245 = fp247 + fp246;
+target[((hsi*45+4)*1+lsi)*1] = fp245;
+LIBINT2_REALTYPE fp251;
+fp251 = inteval->WP_y[vi] * src1[((hsi*30+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp252;
+fp252 = inteval->PA_y[vi] * src0[((hsi*30+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp250;
+fp250 = fp252 + fp251;
+target[((hsi*45+3)*1+lsi)*1] = fp250;
+LIBINT2_REALTYPE fp257;
+fp257 = 3 * inteval->oo2z[vi];
+LIBINT2_REALTYPE fp254;
+fp254 = fp257 * fp255;
+LIBINT2_REALTYPE fp259;
+fp259 = inteval->WP_x[vi] * src1[((hsi*30+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp260;
+fp260 = inteval->PA_x[vi] * src0[((hsi*30+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp258;
+fp258 = fp260 + fp259;
+LIBINT2_REALTYPE fp253;
+fp253 = fp258 + fp254;
+target[((hsi*45+2)*1+lsi)*1] = fp253;
+LIBINT2_REALTYPE fp265;
+fp265 = 3 * inteval->oo2z[vi];
+LIBINT2_REALTYPE fp262;
+fp262 = fp265 * fp263;
+LIBINT2_REALTYPE fp267;
+fp267 = inteval->WP_x[vi] * src1[((hsi*30+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp268;
+fp268 = inteval->PA_x[vi] * src0[((hsi*30+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp266;
+fp266 = fp268 + fp267;
+LIBINT2_REALTYPE fp261;
+fp261 = fp266 + fp262;
+target[((hsi*45+1)*1+lsi)*1] = fp261;
+LIBINT2_REALTYPE fp270;
+fp270 = inteval->oo2ze[vi] * src4[((hsi*10+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp275;
+fp275 = 3 * inteval->oo2z[vi];
+LIBINT2_REALTYPE fp272;
+fp272 = fp275 * fp273;
+LIBINT2_REALTYPE fp277;
+fp277 = inteval->WP_x[vi] * src1[((hsi*30+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp278;
+fp278 = inteval->PA_x[vi] * src0[((hsi*30+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp276;
+fp276 = fp278 + fp277;
+LIBINT2_REALTYPE fp271;
+fp271 = fp276 + fp272;
+LIBINT2_REALTYPE fp269;
+fp269 = fp271 + fp270;
+target[((hsi*45+0)*1+lsi)*1] = fp269;
 LIBINT2_REALTYPE fp1;
 fp1 = inteval->oo2ze[vi] * src4[((hsi*10+9)*1+lsi)*1];
 LIBINT2_REALTYPE fp5;
@@ -294,10 +569,6 @@ fp124 = fp129 + fp125;
 target[((hsi*45+27)*1+lsi)*1] = fp124;
 LIBINT2_REALTYPE fp133;
 fp133 = inteval->oo2ze[vi] * src4[((hsi*10+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp163;
-fp163 = inteval->roz[vi] * src3[((hsi*18+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp162;
-fp162 = src2[((hsi*18+5)*1+lsi)*1] - fp163;
 LIBINT2_REALTYPE fp135;
 fp135 = inteval->oo2z[vi] * fp162;
 LIBINT2_REALTYPE fp137;
@@ -311,10 +582,6 @@ fp134 = fp136 + fp135;
 LIBINT2_REALTYPE fp132;
 fp132 = fp134 + fp133;
 target[((hsi*45+26)*1+lsi)*1] = fp132;
-LIBINT2_REALTYPE fp173;
-fp173 = inteval->roz[vi] * src3[((hsi*18+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp172;
-fp172 = src2[((hsi*18+4)*1+lsi)*1] - fp173;
 LIBINT2_REALTYPE fp140;
 fp140 = inteval->oo2z[vi] * fp172;
 LIBINT2_REALTYPE fp142;
@@ -326,10 +593,6 @@ fp141 = fp143 + fp142;
 LIBINT2_REALTYPE fp139;
 fp139 = fp141 + fp140;
 target[((hsi*45+25)*1+lsi)*1] = fp139;
-LIBINT2_REALTYPE fp181;
-fp181 = inteval->roz[vi] * src3[((hsi*18+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp180;
-fp180 = src2[((hsi*18+3)*1+lsi)*1] - fp181;
 LIBINT2_REALTYPE fp145;
 fp145 = inteval->oo2z[vi] * fp180;
 LIBINT2_REALTYPE fp147;
@@ -352,267 +615,6 @@ fp151 = fp153 + fp152;
 LIBINT2_REALTYPE fp149;
 fp149 = fp151 + fp150;
 target[((hsi*45+23)*1+lsi)*1] = fp149;
-LIBINT2_REALTYPE fp155;
-fp155 = inteval->WP_z[vi] * src1[((hsi*30+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp156;
-fp156 = inteval->PA_z[vi] * src0[((hsi*30+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp154;
-fp154 = fp156 + fp155;
-target[((hsi*45+22)*1+lsi)*1] = fp154;
-LIBINT2_REALTYPE fp158;
-fp158 = inteval->WP_z[vi] * src1[((hsi*30+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp159;
-fp159 = inteval->PA_z[vi] * src0[((hsi*30+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp157;
-fp157 = fp159 + fp158;
-target[((hsi*45+21)*1+lsi)*1] = fp157;
-LIBINT2_REALTYPE fp164;
-fp164 = 2 * inteval->oo2z[vi];
-LIBINT2_REALTYPE fp161;
-fp161 = fp164 * fp162;
-LIBINT2_REALTYPE fp166;
-fp166 = inteval->WP_y[vi] * src1[((hsi*30+11)*1+lsi)*1];
-LIBINT2_REALTYPE fp167;
-fp167 = inteval->PA_y[vi] * src0[((hsi*30+11)*1+lsi)*1];
-LIBINT2_REALTYPE fp165;
-fp165 = fp167 + fp166;
-LIBINT2_REALTYPE fp160;
-fp160 = fp165 + fp161;
-target[((hsi*45+20)*1+lsi)*1] = fp160;
-LIBINT2_REALTYPE fp169;
-fp169 = inteval->oo2ze[vi] * src4[((hsi*10+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp174;
-fp174 = 2 * inteval->oo2z[vi];
-LIBINT2_REALTYPE fp171;
-fp171 = fp174 * fp172;
-LIBINT2_REALTYPE fp176;
-fp176 = inteval->WP_y[vi] * src1[((hsi*30+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp177;
-fp177 = inteval->PA_y[vi] * src0[((hsi*30+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp175;
-fp175 = fp177 + fp176;
-LIBINT2_REALTYPE fp170;
-fp170 = fp175 + fp171;
-LIBINT2_REALTYPE fp168;
-fp168 = fp170 + fp169;
-target[((hsi*45+19)*1+lsi)*1] = fp168;
-LIBINT2_REALTYPE fp182;
-fp182 = 2 * inteval->oo2z[vi];
-LIBINT2_REALTYPE fp179;
-fp179 = fp182 * fp180;
-LIBINT2_REALTYPE fp184;
-fp184 = inteval->WP_y[vi] * src1[((hsi*30+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp185;
-fp185 = inteval->PA_y[vi] * src0[((hsi*30+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp183;
-fp183 = fp185 + fp184;
-LIBINT2_REALTYPE fp178;
-fp178 = fp183 + fp179;
-target[((hsi*45+18)*1+lsi)*1] = fp178;
-LIBINT2_REALTYPE fp187;
-fp187 = inteval->oo2ze[vi] * src4[((hsi*10+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp256;
-fp256 = inteval->roz[vi] * src3[((hsi*18+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp255;
-fp255 = src2[((hsi*18+2)*1+lsi)*1] - fp256;
-LIBINT2_REALTYPE fp189;
-fp189 = inteval->oo2z[vi] * fp255;
-LIBINT2_REALTYPE fp191;
-fp191 = inteval->WP_z[vi] * src1[((hsi*30+8)*1+lsi)*1];
-LIBINT2_REALTYPE fp192;
-fp192 = inteval->PA_z[vi] * src0[((hsi*30+8)*1+lsi)*1];
-LIBINT2_REALTYPE fp190;
-fp190 = fp192 + fp191;
-LIBINT2_REALTYPE fp188;
-fp188 = fp190 + fp189;
-LIBINT2_REALTYPE fp186;
-fp186 = fp188 + fp187;
-target[((hsi*45+17)*1+lsi)*1] = fp186;
-LIBINT2_REALTYPE fp264;
-fp264 = inteval->roz[vi] * src3[((hsi*18+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp263;
-fp263 = src2[((hsi*18+1)*1+lsi)*1] - fp264;
-LIBINT2_REALTYPE fp194;
-fp194 = inteval->oo2z[vi] * fp263;
-LIBINT2_REALTYPE fp196;
-fp196 = inteval->WP_z[vi] * src1[((hsi*30+7)*1+lsi)*1];
-LIBINT2_REALTYPE fp197;
-fp197 = inteval->PA_z[vi] * src0[((hsi*30+7)*1+lsi)*1];
-LIBINT2_REALTYPE fp195;
-fp195 = fp197 + fp196;
-LIBINT2_REALTYPE fp193;
-fp193 = fp195 + fp194;
-target[((hsi*45+16)*1+lsi)*1] = fp193;
-LIBINT2_REALTYPE fp274;
-fp274 = inteval->roz[vi] * src3[((hsi*18+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp273;
-fp273 = src2[((hsi*18+0)*1+lsi)*1] - fp274;
-LIBINT2_REALTYPE fp199;
-fp199 = inteval->oo2z[vi] * fp273;
-LIBINT2_REALTYPE fp201;
-fp201 = inteval->WP_z[vi] * src1[((hsi*30+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp202;
-fp202 = inteval->PA_z[vi] * src0[((hsi*30+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp200;
-fp200 = fp202 + fp201;
-LIBINT2_REALTYPE fp198;
-fp198 = fp200 + fp199;
-target[((hsi*45+15)*1+lsi)*1] = fp198;
-LIBINT2_REALTYPE fp204;
-fp204 = inteval->oo2ze[vi] * src4[((hsi*10+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp206;
-fp206 = inteval->WP_z[vi] * src1[((hsi*30+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp207;
-fp207 = inteval->PA_z[vi] * src0[((hsi*30+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp205;
-fp205 = fp207 + fp206;
-LIBINT2_REALTYPE fp203;
-fp203 = fp205 + fp204;
-target[((hsi*45+14)*1+lsi)*1] = fp203;
-LIBINT2_REALTYPE fp209;
-fp209 = inteval->WP_z[vi] * src1[((hsi*30+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp210;
-fp210 = inteval->PA_z[vi] * src0[((hsi*30+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp208;
-fp208 = fp210 + fp209;
-target[((hsi*45+13)*1+lsi)*1] = fp208;
-LIBINT2_REALTYPE fp212;
-fp212 = inteval->WP_z[vi] * src1[((hsi*30+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp213;
-fp213 = inteval->PA_z[vi] * src0[((hsi*30+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp211;
-fp211 = fp213 + fp212;
-target[((hsi*45+12)*1+lsi)*1] = fp211;
-LIBINT2_REALTYPE fp215;
-fp215 = inteval->oo2z[vi] * fp255;
-LIBINT2_REALTYPE fp217;
-fp217 = inteval->WP_y[vi] * src1[((hsi*30+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp218;
-fp218 = inteval->PA_y[vi] * src0[((hsi*30+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp216;
-fp216 = fp218 + fp217;
-LIBINT2_REALTYPE fp214;
-fp214 = fp216 + fp215;
-target[((hsi*45+11)*1+lsi)*1] = fp214;
-LIBINT2_REALTYPE fp220;
-fp220 = inteval->oo2ze[vi] * src4[((hsi*10+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp222;
-fp222 = inteval->oo2z[vi] * fp263;
-LIBINT2_REALTYPE fp224;
-fp224 = inteval->WP_y[vi] * src1[((hsi*30+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp225;
-fp225 = inteval->PA_y[vi] * src0[((hsi*30+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp223;
-fp223 = fp225 + fp224;
-LIBINT2_REALTYPE fp221;
-fp221 = fp223 + fp222;
-LIBINT2_REALTYPE fp219;
-fp219 = fp221 + fp220;
-target[((hsi*45+10)*1+lsi)*1] = fp219;
-LIBINT2_REALTYPE fp227;
-fp227 = inteval->oo2z[vi] * fp273;
-LIBINT2_REALTYPE fp229;
-fp229 = inteval->WP_y[vi] * src1[((hsi*30+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp230;
-fp230 = inteval->PA_y[vi] * src0[((hsi*30+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp228;
-fp228 = fp230 + fp229;
-LIBINT2_REALTYPE fp226;
-fp226 = fp228 + fp227;
-target[((hsi*45+9)*1+lsi)*1] = fp226;
-LIBINT2_REALTYPE fp232;
-fp232 = inteval->oo2ze[vi] * src4[((hsi*10+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp234;
-fp234 = inteval->WP_z[vi] * src1[((hsi*30+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp235;
-fp235 = inteval->PA_z[vi] * src0[((hsi*30+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp233;
-fp233 = fp235 + fp234;
-LIBINT2_REALTYPE fp231;
-fp231 = fp233 + fp232;
-target[((hsi*45+8)*1+lsi)*1] = fp231;
-LIBINT2_REALTYPE fp237;
-fp237 = inteval->WP_z[vi] * src1[((hsi*30+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp238;
-fp238 = inteval->PA_z[vi] * src0[((hsi*30+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp236;
-fp236 = fp238 + fp237;
-target[((hsi*45+7)*1+lsi)*1] = fp236;
-LIBINT2_REALTYPE fp240;
-fp240 = inteval->WP_z[vi] * src1[((hsi*30+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp241;
-fp241 = inteval->PA_z[vi] * src0[((hsi*30+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp239;
-fp239 = fp241 + fp240;
-target[((hsi*45+6)*1+lsi)*1] = fp239;
-LIBINT2_REALTYPE fp243;
-fp243 = inteval->WP_y[vi] * src1[((hsi*30+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp244;
-fp244 = inteval->PA_y[vi] * src0[((hsi*30+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp242;
-fp242 = fp244 + fp243;
-target[((hsi*45+5)*1+lsi)*1] = fp242;
-LIBINT2_REALTYPE fp246;
-fp246 = inteval->oo2ze[vi] * src4[((hsi*10+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp248;
-fp248 = inteval->WP_y[vi] * src1[((hsi*30+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp249;
-fp249 = inteval->PA_y[vi] * src0[((hsi*30+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp247;
-fp247 = fp249 + fp248;
-LIBINT2_REALTYPE fp245;
-fp245 = fp247 + fp246;
-target[((hsi*45+4)*1+lsi)*1] = fp245;
-LIBINT2_REALTYPE fp251;
-fp251 = inteval->WP_y[vi] * src1[((hsi*30+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp252;
-fp252 = inteval->PA_y[vi] * src0[((hsi*30+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp250;
-fp250 = fp252 + fp251;
-target[((hsi*45+3)*1+lsi)*1] = fp250;
-LIBINT2_REALTYPE fp257;
-fp257 = 3 * inteval->oo2z[vi];
-LIBINT2_REALTYPE fp254;
-fp254 = fp257 * fp255;
-LIBINT2_REALTYPE fp259;
-fp259 = inteval->WP_x[vi] * src1[((hsi*30+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp260;
-fp260 = inteval->PA_x[vi] * src0[((hsi*30+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp258;
-fp258 = fp260 + fp259;
-LIBINT2_REALTYPE fp253;
-fp253 = fp258 + fp254;
-target[((hsi*45+2)*1+lsi)*1] = fp253;
-LIBINT2_REALTYPE fp265;
-fp265 = 3 * inteval->oo2z[vi];
-LIBINT2_REALTYPE fp262;
-fp262 = fp265 * fp263;
-LIBINT2_REALTYPE fp267;
-fp267 = inteval->WP_x[vi] * src1[((hsi*30+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp268;
-fp268 = inteval->PA_x[vi] * src0[((hsi*30+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp266;
-fp266 = fp268 + fp267;
-LIBINT2_REALTYPE fp261;
-fp261 = fp266 + fp262;
-target[((hsi*45+1)*1+lsi)*1] = fp261;
-LIBINT2_REALTYPE fp270;
-fp270 = inteval->oo2ze[vi] * src4[((hsi*10+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp275;
-fp275 = 3 * inteval->oo2z[vi];
-LIBINT2_REALTYPE fp272;
-fp272 = fp275 * fp273;
-LIBINT2_REALTYPE fp277;
-fp277 = inteval->WP_x[vi] * src1[((hsi*30+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp278;
-fp278 = inteval->PA_x[vi] * src0[((hsi*30+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp276;
-fp276 = fp278 + fp277;
-LIBINT2_REALTYPE fp271;
-fp271 = fp276 + fp272;
-LIBINT2_REALTYPE fp269;
-fp269 = fp271 + fp270;
-target[((hsi*45+0)*1+lsi)*1] = fp269;
 }
 }
 }
@@ -622,4 +624,6 @@ const int vi = 0;
 /** Number of flops = 279 */
 }
 
+#ifdef __cplusplus
 };
+#endif
