@@ -1,6 +1,8 @@
 #include <libint2.h>
 
+#ifdef __cplusplus
 extern "C" {
+#endif
 void OSVRRP0InBra_aB_h__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(const Libint_t* inteval, LIBINT2_REALTYPE* target, const LIBINT2_REALTYPE* src0, const LIBINT2_REALTYPE* src1, const LIBINT2_REALTYPE* src2, const LIBINT2_REALTYPE* src3, const LIBINT2_REALTYPE* src4) {
 
 LIBINT2_REALTYPE*const  stack = target;
@@ -10,6 +12,456 @@ const int hsi = 0;
 const int lsi = 0;
 {
 const int vi = 0;
+LIBINT2_REALTYPE fp233;
+fp233 = inteval->oo2ze[vi] * src4[((hsi*15+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp237;
+fp237 = inteval->roz[vi] * src3[((hsi*30+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp236;
+fp236 = src2[((hsi*30+10)*1+lsi)*1] - fp237;
+LIBINT2_REALTYPE fp238;
+fp238 = 3 * inteval->oo2z[vi];
+LIBINT2_REALTYPE fp235;
+fp235 = fp238 * fp236;
+LIBINT2_REALTYPE fp240;
+fp240 = inteval->WP_y[vi] * src1[((hsi*45+19)*1+lsi)*1];
+LIBINT2_REALTYPE fp241;
+fp241 = inteval->PA_y[vi] * src0[((hsi*45+19)*1+lsi)*1];
+LIBINT2_REALTYPE fp239;
+fp239 = fp241 + fp240;
+LIBINT2_REALTYPE fp234;
+fp234 = fp239 + fp235;
+LIBINT2_REALTYPE fp232;
+fp232 = fp234 + fp233;
+target[((hsi*63+31)*1+lsi)*1] = fp232;
+LIBINT2_REALTYPE fp245;
+fp245 = inteval->roz[vi] * src3[((hsi*30+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp244;
+fp244 = src2[((hsi*30+9)*1+lsi)*1] - fp245;
+LIBINT2_REALTYPE fp246;
+fp246 = 3 * inteval->oo2z[vi];
+LIBINT2_REALTYPE fp243;
+fp243 = fp246 * fp244;
+LIBINT2_REALTYPE fp248;
+fp248 = inteval->WP_y[vi] * src1[((hsi*45+18)*1+lsi)*1];
+LIBINT2_REALTYPE fp249;
+fp249 = inteval->PA_y[vi] * src0[((hsi*45+18)*1+lsi)*1];
+LIBINT2_REALTYPE fp247;
+fp247 = fp249 + fp248;
+LIBINT2_REALTYPE fp242;
+fp242 = fp247 + fp243;
+target[((hsi*63+30)*1+lsi)*1] = fp242;
+LIBINT2_REALTYPE fp251;
+fp251 = inteval->oo2ze[vi] * src4[((hsi*15+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp255;
+fp255 = inteval->roz[vi] * src3[((hsi*30+8)*1+lsi)*1];
+LIBINT2_REALTYPE fp254;
+fp254 = src2[((hsi*30+8)*1+lsi)*1] - fp255;
+LIBINT2_REALTYPE fp256;
+fp256 = 2 * inteval->oo2z[vi];
+LIBINT2_REALTYPE fp253;
+fp253 = fp256 * fp254;
+LIBINT2_REALTYPE fp258;
+fp258 = inteval->WP_z[vi] * src1[((hsi*45+17)*1+lsi)*1];
+LIBINT2_REALTYPE fp259;
+fp259 = inteval->PA_z[vi] * src0[((hsi*45+17)*1+lsi)*1];
+LIBINT2_REALTYPE fp257;
+fp257 = fp259 + fp258;
+LIBINT2_REALTYPE fp252;
+fp252 = fp257 + fp253;
+LIBINT2_REALTYPE fp250;
+fp250 = fp252 + fp251;
+target[((hsi*63+29)*1+lsi)*1] = fp250;
+LIBINT2_REALTYPE fp263;
+fp263 = inteval->roz[vi] * src3[((hsi*30+7)*1+lsi)*1];
+LIBINT2_REALTYPE fp262;
+fp262 = src2[((hsi*30+7)*1+lsi)*1] - fp263;
+LIBINT2_REALTYPE fp264;
+fp264 = 2 * inteval->oo2z[vi];
+LIBINT2_REALTYPE fp261;
+fp261 = fp264 * fp262;
+LIBINT2_REALTYPE fp266;
+fp266 = inteval->WP_z[vi] * src1[((hsi*45+16)*1+lsi)*1];
+LIBINT2_REALTYPE fp267;
+fp267 = inteval->PA_z[vi] * src0[((hsi*45+16)*1+lsi)*1];
+LIBINT2_REALTYPE fp265;
+fp265 = fp267 + fp266;
+LIBINT2_REALTYPE fp260;
+fp260 = fp265 + fp261;
+target[((hsi*63+28)*1+lsi)*1] = fp260;
+LIBINT2_REALTYPE fp271;
+fp271 = inteval->roz[vi] * src3[((hsi*30+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp270;
+fp270 = src2[((hsi*30+6)*1+lsi)*1] - fp271;
+LIBINT2_REALTYPE fp272;
+fp272 = 2 * inteval->oo2z[vi];
+LIBINT2_REALTYPE fp269;
+fp269 = fp272 * fp270;
+LIBINT2_REALTYPE fp274;
+fp274 = inteval->WP_z[vi] * src1[((hsi*45+15)*1+lsi)*1];
+LIBINT2_REALTYPE fp275;
+fp275 = inteval->PA_z[vi] * src0[((hsi*45+15)*1+lsi)*1];
+LIBINT2_REALTYPE fp273;
+fp273 = fp275 + fp274;
+LIBINT2_REALTYPE fp268;
+fp268 = fp273 + fp269;
+target[((hsi*63+27)*1+lsi)*1] = fp268;
+LIBINT2_REALTYPE fp277;
+fp277 = inteval->oo2ze[vi] * src4[((hsi*15+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp281;
+fp281 = inteval->roz[vi] * src3[((hsi*30+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp280;
+fp280 = src2[((hsi*30+5)*1+lsi)*1] - fp281;
+LIBINT2_REALTYPE fp279;
+fp279 = inteval->oo2z[vi] * fp280;
+LIBINT2_REALTYPE fp283;
+fp283 = inteval->WP_z[vi] * src1[((hsi*45+14)*1+lsi)*1];
+LIBINT2_REALTYPE fp284;
+fp284 = inteval->PA_z[vi] * src0[((hsi*45+14)*1+lsi)*1];
+LIBINT2_REALTYPE fp282;
+fp282 = fp284 + fp283;
+LIBINT2_REALTYPE fp278;
+fp278 = fp282 + fp279;
+LIBINT2_REALTYPE fp276;
+fp276 = fp278 + fp277;
+target[((hsi*63+26)*1+lsi)*1] = fp276;
+LIBINT2_REALTYPE fp288;
+fp288 = inteval->roz[vi] * src3[((hsi*30+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp287;
+fp287 = src2[((hsi*30+4)*1+lsi)*1] - fp288;
+LIBINT2_REALTYPE fp286;
+fp286 = inteval->oo2z[vi] * fp287;
+LIBINT2_REALTYPE fp290;
+fp290 = inteval->WP_z[vi] * src1[((hsi*45+13)*1+lsi)*1];
+LIBINT2_REALTYPE fp291;
+fp291 = inteval->PA_z[vi] * src0[((hsi*45+13)*1+lsi)*1];
+LIBINT2_REALTYPE fp289;
+fp289 = fp291 + fp290;
+LIBINT2_REALTYPE fp285;
+fp285 = fp289 + fp286;
+target[((hsi*63+25)*1+lsi)*1] = fp285;
+LIBINT2_REALTYPE fp295;
+fp295 = inteval->roz[vi] * src3[((hsi*30+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp294;
+fp294 = src2[((hsi*30+3)*1+lsi)*1] - fp295;
+LIBINT2_REALTYPE fp293;
+fp293 = inteval->oo2z[vi] * fp294;
+LIBINT2_REALTYPE fp297;
+fp297 = inteval->WP_z[vi] * src1[((hsi*45+12)*1+lsi)*1];
+LIBINT2_REALTYPE fp298;
+fp298 = inteval->PA_z[vi] * src0[((hsi*45+12)*1+lsi)*1];
+LIBINT2_REALTYPE fp296;
+fp296 = fp298 + fp297;
+LIBINT2_REALTYPE fp292;
+fp292 = fp296 + fp293;
+target[((hsi*63+24)*1+lsi)*1] = fp292;
+LIBINT2_REALTYPE fp300;
+fp300 = inteval->oo2ze[vi] * src4[((hsi*15+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp302;
+fp302 = inteval->WP_z[vi] * src1[((hsi*45+11)*1+lsi)*1];
+LIBINT2_REALTYPE fp303;
+fp303 = inteval->PA_z[vi] * src0[((hsi*45+11)*1+lsi)*1];
+LIBINT2_REALTYPE fp301;
+fp301 = fp303 + fp302;
+LIBINT2_REALTYPE fp299;
+fp299 = fp301 + fp300;
+target[((hsi*63+23)*1+lsi)*1] = fp299;
+LIBINT2_REALTYPE fp305;
+fp305 = inteval->WP_z[vi] * src1[((hsi*45+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp306;
+fp306 = inteval->PA_z[vi] * src0[((hsi*45+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp304;
+fp304 = fp306 + fp305;
+target[((hsi*63+22)*1+lsi)*1] = fp304;
+LIBINT2_REALTYPE fp308;
+fp308 = inteval->WP_z[vi] * src1[((hsi*45+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp309;
+fp309 = inteval->PA_z[vi] * src0[((hsi*45+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp307;
+fp307 = fp309 + fp308;
+target[((hsi*63+21)*1+lsi)*1] = fp307;
+LIBINT2_REALTYPE fp313;
+fp313 = inteval->roz[vi] * src3[((hsi*30+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp312;
+fp312 = src2[((hsi*30+5)*1+lsi)*1] - fp313;
+LIBINT2_REALTYPE fp314;
+fp314 = 2 * inteval->oo2z[vi];
+LIBINT2_REALTYPE fp311;
+fp311 = fp314 * fp312;
+LIBINT2_REALTYPE fp316;
+fp316 = inteval->WP_y[vi] * src1[((hsi*45+11)*1+lsi)*1];
+LIBINT2_REALTYPE fp317;
+fp317 = inteval->PA_y[vi] * src0[((hsi*45+11)*1+lsi)*1];
+LIBINT2_REALTYPE fp315;
+fp315 = fp317 + fp316;
+LIBINT2_REALTYPE fp310;
+fp310 = fp315 + fp311;
+target[((hsi*63+20)*1+lsi)*1] = fp310;
+LIBINT2_REALTYPE fp319;
+fp319 = inteval->oo2ze[vi] * src4[((hsi*15+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp323;
+fp323 = inteval->roz[vi] * src3[((hsi*30+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp322;
+fp322 = src2[((hsi*30+4)*1+lsi)*1] - fp323;
+LIBINT2_REALTYPE fp324;
+fp324 = 2 * inteval->oo2z[vi];
+LIBINT2_REALTYPE fp321;
+fp321 = fp324 * fp322;
+LIBINT2_REALTYPE fp326;
+fp326 = inteval->WP_y[vi] * src1[((hsi*45+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp327;
+fp327 = inteval->PA_y[vi] * src0[((hsi*45+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp325;
+fp325 = fp327 + fp326;
+LIBINT2_REALTYPE fp320;
+fp320 = fp325 + fp321;
+LIBINT2_REALTYPE fp318;
+fp318 = fp320 + fp319;
+target[((hsi*63+19)*1+lsi)*1] = fp318;
+LIBINT2_REALTYPE fp331;
+fp331 = inteval->roz[vi] * src3[((hsi*30+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp330;
+fp330 = src2[((hsi*30+3)*1+lsi)*1] - fp331;
+LIBINT2_REALTYPE fp332;
+fp332 = 2 * inteval->oo2z[vi];
+LIBINT2_REALTYPE fp329;
+fp329 = fp332 * fp330;
+LIBINT2_REALTYPE fp334;
+fp334 = inteval->WP_y[vi] * src1[((hsi*45+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp335;
+fp335 = inteval->PA_y[vi] * src0[((hsi*45+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp333;
+fp333 = fp335 + fp334;
+LIBINT2_REALTYPE fp328;
+fp328 = fp333 + fp329;
+target[((hsi*63+18)*1+lsi)*1] = fp328;
+LIBINT2_REALTYPE fp337;
+fp337 = inteval->oo2ze[vi] * src4[((hsi*15+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp341;
+fp341 = inteval->roz[vi] * src3[((hsi*30+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp340;
+fp340 = src2[((hsi*30+2)*1+lsi)*1] - fp341;
+LIBINT2_REALTYPE fp339;
+fp339 = inteval->oo2z[vi] * fp340;
+LIBINT2_REALTYPE fp343;
+fp343 = inteval->WP_z[vi] * src1[((hsi*45+8)*1+lsi)*1];
+LIBINT2_REALTYPE fp344;
+fp344 = inteval->PA_z[vi] * src0[((hsi*45+8)*1+lsi)*1];
+LIBINT2_REALTYPE fp342;
+fp342 = fp344 + fp343;
+LIBINT2_REALTYPE fp338;
+fp338 = fp342 + fp339;
+LIBINT2_REALTYPE fp336;
+fp336 = fp338 + fp337;
+target[((hsi*63+17)*1+lsi)*1] = fp336;
+LIBINT2_REALTYPE fp348;
+fp348 = inteval->roz[vi] * src3[((hsi*30+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp347;
+fp347 = src2[((hsi*30+1)*1+lsi)*1] - fp348;
+LIBINT2_REALTYPE fp346;
+fp346 = inteval->oo2z[vi] * fp347;
+LIBINT2_REALTYPE fp350;
+fp350 = inteval->WP_z[vi] * src1[((hsi*45+7)*1+lsi)*1];
+LIBINT2_REALTYPE fp351;
+fp351 = inteval->PA_z[vi] * src0[((hsi*45+7)*1+lsi)*1];
+LIBINT2_REALTYPE fp349;
+fp349 = fp351 + fp350;
+LIBINT2_REALTYPE fp345;
+fp345 = fp349 + fp346;
+target[((hsi*63+16)*1+lsi)*1] = fp345;
+LIBINT2_REALTYPE fp355;
+fp355 = inteval->roz[vi] * src3[((hsi*30+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp354;
+fp354 = src2[((hsi*30+0)*1+lsi)*1] - fp355;
+LIBINT2_REALTYPE fp353;
+fp353 = inteval->oo2z[vi] * fp354;
+LIBINT2_REALTYPE fp357;
+fp357 = inteval->WP_z[vi] * src1[((hsi*45+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp358;
+fp358 = inteval->PA_z[vi] * src0[((hsi*45+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp356;
+fp356 = fp358 + fp357;
+LIBINT2_REALTYPE fp352;
+fp352 = fp356 + fp353;
+target[((hsi*63+15)*1+lsi)*1] = fp352;
+LIBINT2_REALTYPE fp360;
+fp360 = inteval->oo2ze[vi] * src4[((hsi*15+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp362;
+fp362 = inteval->WP_z[vi] * src1[((hsi*45+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp363;
+fp363 = inteval->PA_z[vi] * src0[((hsi*45+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp361;
+fp361 = fp363 + fp362;
+LIBINT2_REALTYPE fp359;
+fp359 = fp361 + fp360;
+target[((hsi*63+14)*1+lsi)*1] = fp359;
+LIBINT2_REALTYPE fp365;
+fp365 = inteval->WP_z[vi] * src1[((hsi*45+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp366;
+fp366 = inteval->PA_z[vi] * src0[((hsi*45+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp364;
+fp364 = fp366 + fp365;
+target[((hsi*63+13)*1+lsi)*1] = fp364;
+LIBINT2_REALTYPE fp368;
+fp368 = inteval->WP_z[vi] * src1[((hsi*45+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp369;
+fp369 = inteval->PA_z[vi] * src0[((hsi*45+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp367;
+fp367 = fp369 + fp368;
+target[((hsi*63+12)*1+lsi)*1] = fp367;
+LIBINT2_REALTYPE fp373;
+fp373 = inteval->roz[vi] * src3[((hsi*30+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp372;
+fp372 = src2[((hsi*30+2)*1+lsi)*1] - fp373;
+LIBINT2_REALTYPE fp371;
+fp371 = inteval->oo2z[vi] * fp372;
+LIBINT2_REALTYPE fp375;
+fp375 = inteval->WP_y[vi] * src1[((hsi*45+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp376;
+fp376 = inteval->PA_y[vi] * src0[((hsi*45+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp374;
+fp374 = fp376 + fp375;
+LIBINT2_REALTYPE fp370;
+fp370 = fp374 + fp371;
+target[((hsi*63+11)*1+lsi)*1] = fp370;
+LIBINT2_REALTYPE fp378;
+fp378 = inteval->oo2ze[vi] * src4[((hsi*15+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp382;
+fp382 = inteval->roz[vi] * src3[((hsi*30+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp381;
+fp381 = src2[((hsi*30+1)*1+lsi)*1] - fp382;
+LIBINT2_REALTYPE fp380;
+fp380 = inteval->oo2z[vi] * fp381;
+LIBINT2_REALTYPE fp384;
+fp384 = inteval->WP_y[vi] * src1[((hsi*45+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp385;
+fp385 = inteval->PA_y[vi] * src0[((hsi*45+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp383;
+fp383 = fp385 + fp384;
+LIBINT2_REALTYPE fp379;
+fp379 = fp383 + fp380;
+LIBINT2_REALTYPE fp377;
+fp377 = fp379 + fp378;
+target[((hsi*63+10)*1+lsi)*1] = fp377;
+LIBINT2_REALTYPE fp389;
+fp389 = inteval->roz[vi] * src3[((hsi*30+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp388;
+fp388 = src2[((hsi*30+0)*1+lsi)*1] - fp389;
+LIBINT2_REALTYPE fp387;
+fp387 = inteval->oo2z[vi] * fp388;
+LIBINT2_REALTYPE fp391;
+fp391 = inteval->WP_y[vi] * src1[((hsi*45+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp392;
+fp392 = inteval->PA_y[vi] * src0[((hsi*45+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp390;
+fp390 = fp392 + fp391;
+LIBINT2_REALTYPE fp386;
+fp386 = fp390 + fp387;
+target[((hsi*63+9)*1+lsi)*1] = fp386;
+LIBINT2_REALTYPE fp394;
+fp394 = inteval->oo2ze[vi] * src4[((hsi*15+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp396;
+fp396 = inteval->WP_z[vi] * src1[((hsi*45+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp397;
+fp397 = inteval->PA_z[vi] * src0[((hsi*45+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp395;
+fp395 = fp397 + fp396;
+LIBINT2_REALTYPE fp393;
+fp393 = fp395 + fp394;
+target[((hsi*63+8)*1+lsi)*1] = fp393;
+LIBINT2_REALTYPE fp399;
+fp399 = inteval->WP_z[vi] * src1[((hsi*45+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp400;
+fp400 = inteval->PA_z[vi] * src0[((hsi*45+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp398;
+fp398 = fp400 + fp399;
+target[((hsi*63+7)*1+lsi)*1] = fp398;
+LIBINT2_REALTYPE fp402;
+fp402 = inteval->WP_z[vi] * src1[((hsi*45+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp403;
+fp403 = inteval->PA_z[vi] * src0[((hsi*45+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp401;
+fp401 = fp403 + fp402;
+target[((hsi*63+6)*1+lsi)*1] = fp401;
+LIBINT2_REALTYPE fp405;
+fp405 = inteval->WP_y[vi] * src1[((hsi*45+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp406;
+fp406 = inteval->PA_y[vi] * src0[((hsi*45+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp404;
+fp404 = fp406 + fp405;
+target[((hsi*63+5)*1+lsi)*1] = fp404;
+LIBINT2_REALTYPE fp408;
+fp408 = inteval->oo2ze[vi] * src4[((hsi*15+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp410;
+fp410 = inteval->WP_y[vi] * src1[((hsi*45+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp411;
+fp411 = inteval->PA_y[vi] * src0[((hsi*45+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp409;
+fp409 = fp411 + fp410;
+LIBINT2_REALTYPE fp407;
+fp407 = fp409 + fp408;
+target[((hsi*63+4)*1+lsi)*1] = fp407;
+LIBINT2_REALTYPE fp413;
+fp413 = inteval->WP_y[vi] * src1[((hsi*45+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp414;
+fp414 = inteval->PA_y[vi] * src0[((hsi*45+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp412;
+fp412 = fp414 + fp413;
+target[((hsi*63+3)*1+lsi)*1] = fp412;
+LIBINT2_REALTYPE fp418;
+fp418 = inteval->roz[vi] * src3[((hsi*30+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp417;
+fp417 = src2[((hsi*30+2)*1+lsi)*1] - fp418;
+LIBINT2_REALTYPE fp419;
+fp419 = 4 * inteval->oo2z[vi];
+LIBINT2_REALTYPE fp416;
+fp416 = fp419 * fp417;
+LIBINT2_REALTYPE fp421;
+fp421 = inteval->WP_x[vi] * src1[((hsi*45+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp422;
+fp422 = inteval->PA_x[vi] * src0[((hsi*45+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp420;
+fp420 = fp422 + fp421;
+LIBINT2_REALTYPE fp415;
+fp415 = fp420 + fp416;
+target[((hsi*63+2)*1+lsi)*1] = fp415;
+LIBINT2_REALTYPE fp426;
+fp426 = inteval->roz[vi] * src3[((hsi*30+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp425;
+fp425 = src2[((hsi*30+1)*1+lsi)*1] - fp426;
+LIBINT2_REALTYPE fp427;
+fp427 = 4 * inteval->oo2z[vi];
+LIBINT2_REALTYPE fp424;
+fp424 = fp427 * fp425;
+LIBINT2_REALTYPE fp429;
+fp429 = inteval->WP_x[vi] * src1[((hsi*45+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp430;
+fp430 = inteval->PA_x[vi] * src0[((hsi*45+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp428;
+fp428 = fp430 + fp429;
+LIBINT2_REALTYPE fp423;
+fp423 = fp428 + fp424;
+target[((hsi*63+1)*1+lsi)*1] = fp423;
+LIBINT2_REALTYPE fp432;
+fp432 = inteval->oo2ze[vi] * src4[((hsi*15+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp436;
+fp436 = inteval->roz[vi] * src3[((hsi*30+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp435;
+fp435 = src2[((hsi*30+0)*1+lsi)*1] - fp436;
+LIBINT2_REALTYPE fp437;
+fp437 = 4 * inteval->oo2z[vi];
+LIBINT2_REALTYPE fp434;
+fp434 = fp437 * fp435;
+LIBINT2_REALTYPE fp439;
+fp439 = inteval->WP_x[vi] * src1[((hsi*45+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp440;
+fp440 = inteval->PA_x[vi] * src0[((hsi*45+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp438;
+fp438 = fp440 + fp439;
+LIBINT2_REALTYPE fp433;
+fp433 = fp438 + fp434;
+LIBINT2_REALTYPE fp431;
+fp431 = fp433 + fp432;
+target[((hsi*63+0)*1+lsi)*1] = fp431;
 LIBINT2_REALTYPE fp1;
 fp1 = inteval->oo2ze[vi] * src4[((hsi*15+14)*1+lsi)*1];
 LIBINT2_REALTYPE fp5;
@@ -505,456 +957,6 @@ fp229 = fp231 + fp230;
 LIBINT2_REALTYPE fp224;
 fp224 = fp229 + fp225;
 target[((hsi*63+32)*1+lsi)*1] = fp224;
-LIBINT2_REALTYPE fp233;
-fp233 = inteval->oo2ze[vi] * src4[((hsi*15+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp237;
-fp237 = inteval->roz[vi] * src3[((hsi*30+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp236;
-fp236 = src2[((hsi*30+10)*1+lsi)*1] - fp237;
-LIBINT2_REALTYPE fp238;
-fp238 = 3 * inteval->oo2z[vi];
-LIBINT2_REALTYPE fp235;
-fp235 = fp238 * fp236;
-LIBINT2_REALTYPE fp240;
-fp240 = inteval->WP_y[vi] * src1[((hsi*45+19)*1+lsi)*1];
-LIBINT2_REALTYPE fp241;
-fp241 = inteval->PA_y[vi] * src0[((hsi*45+19)*1+lsi)*1];
-LIBINT2_REALTYPE fp239;
-fp239 = fp241 + fp240;
-LIBINT2_REALTYPE fp234;
-fp234 = fp239 + fp235;
-LIBINT2_REALTYPE fp232;
-fp232 = fp234 + fp233;
-target[((hsi*63+31)*1+lsi)*1] = fp232;
-LIBINT2_REALTYPE fp245;
-fp245 = inteval->roz[vi] * src3[((hsi*30+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp244;
-fp244 = src2[((hsi*30+9)*1+lsi)*1] - fp245;
-LIBINT2_REALTYPE fp246;
-fp246 = 3 * inteval->oo2z[vi];
-LIBINT2_REALTYPE fp243;
-fp243 = fp246 * fp244;
-LIBINT2_REALTYPE fp248;
-fp248 = inteval->WP_y[vi] * src1[((hsi*45+18)*1+lsi)*1];
-LIBINT2_REALTYPE fp249;
-fp249 = inteval->PA_y[vi] * src0[((hsi*45+18)*1+lsi)*1];
-LIBINT2_REALTYPE fp247;
-fp247 = fp249 + fp248;
-LIBINT2_REALTYPE fp242;
-fp242 = fp247 + fp243;
-target[((hsi*63+30)*1+lsi)*1] = fp242;
-LIBINT2_REALTYPE fp251;
-fp251 = inteval->oo2ze[vi] * src4[((hsi*15+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp255;
-fp255 = inteval->roz[vi] * src3[((hsi*30+8)*1+lsi)*1];
-LIBINT2_REALTYPE fp254;
-fp254 = src2[((hsi*30+8)*1+lsi)*1] - fp255;
-LIBINT2_REALTYPE fp256;
-fp256 = 2 * inteval->oo2z[vi];
-LIBINT2_REALTYPE fp253;
-fp253 = fp256 * fp254;
-LIBINT2_REALTYPE fp258;
-fp258 = inteval->WP_z[vi] * src1[((hsi*45+17)*1+lsi)*1];
-LIBINT2_REALTYPE fp259;
-fp259 = inteval->PA_z[vi] * src0[((hsi*45+17)*1+lsi)*1];
-LIBINT2_REALTYPE fp257;
-fp257 = fp259 + fp258;
-LIBINT2_REALTYPE fp252;
-fp252 = fp257 + fp253;
-LIBINT2_REALTYPE fp250;
-fp250 = fp252 + fp251;
-target[((hsi*63+29)*1+lsi)*1] = fp250;
-LIBINT2_REALTYPE fp263;
-fp263 = inteval->roz[vi] * src3[((hsi*30+7)*1+lsi)*1];
-LIBINT2_REALTYPE fp262;
-fp262 = src2[((hsi*30+7)*1+lsi)*1] - fp263;
-LIBINT2_REALTYPE fp264;
-fp264 = 2 * inteval->oo2z[vi];
-LIBINT2_REALTYPE fp261;
-fp261 = fp264 * fp262;
-LIBINT2_REALTYPE fp266;
-fp266 = inteval->WP_z[vi] * src1[((hsi*45+16)*1+lsi)*1];
-LIBINT2_REALTYPE fp267;
-fp267 = inteval->PA_z[vi] * src0[((hsi*45+16)*1+lsi)*1];
-LIBINT2_REALTYPE fp265;
-fp265 = fp267 + fp266;
-LIBINT2_REALTYPE fp260;
-fp260 = fp265 + fp261;
-target[((hsi*63+28)*1+lsi)*1] = fp260;
-LIBINT2_REALTYPE fp271;
-fp271 = inteval->roz[vi] * src3[((hsi*30+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp270;
-fp270 = src2[((hsi*30+6)*1+lsi)*1] - fp271;
-LIBINT2_REALTYPE fp272;
-fp272 = 2 * inteval->oo2z[vi];
-LIBINT2_REALTYPE fp269;
-fp269 = fp272 * fp270;
-LIBINT2_REALTYPE fp274;
-fp274 = inteval->WP_z[vi] * src1[((hsi*45+15)*1+lsi)*1];
-LIBINT2_REALTYPE fp275;
-fp275 = inteval->PA_z[vi] * src0[((hsi*45+15)*1+lsi)*1];
-LIBINT2_REALTYPE fp273;
-fp273 = fp275 + fp274;
-LIBINT2_REALTYPE fp268;
-fp268 = fp273 + fp269;
-target[((hsi*63+27)*1+lsi)*1] = fp268;
-LIBINT2_REALTYPE fp277;
-fp277 = inteval->oo2ze[vi] * src4[((hsi*15+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp281;
-fp281 = inteval->roz[vi] * src3[((hsi*30+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp280;
-fp280 = src2[((hsi*30+5)*1+lsi)*1] - fp281;
-LIBINT2_REALTYPE fp279;
-fp279 = inteval->oo2z[vi] * fp280;
-LIBINT2_REALTYPE fp283;
-fp283 = inteval->WP_z[vi] * src1[((hsi*45+14)*1+lsi)*1];
-LIBINT2_REALTYPE fp284;
-fp284 = inteval->PA_z[vi] * src0[((hsi*45+14)*1+lsi)*1];
-LIBINT2_REALTYPE fp282;
-fp282 = fp284 + fp283;
-LIBINT2_REALTYPE fp278;
-fp278 = fp282 + fp279;
-LIBINT2_REALTYPE fp276;
-fp276 = fp278 + fp277;
-target[((hsi*63+26)*1+lsi)*1] = fp276;
-LIBINT2_REALTYPE fp288;
-fp288 = inteval->roz[vi] * src3[((hsi*30+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp287;
-fp287 = src2[((hsi*30+4)*1+lsi)*1] - fp288;
-LIBINT2_REALTYPE fp286;
-fp286 = inteval->oo2z[vi] * fp287;
-LIBINT2_REALTYPE fp290;
-fp290 = inteval->WP_z[vi] * src1[((hsi*45+13)*1+lsi)*1];
-LIBINT2_REALTYPE fp291;
-fp291 = inteval->PA_z[vi] * src0[((hsi*45+13)*1+lsi)*1];
-LIBINT2_REALTYPE fp289;
-fp289 = fp291 + fp290;
-LIBINT2_REALTYPE fp285;
-fp285 = fp289 + fp286;
-target[((hsi*63+25)*1+lsi)*1] = fp285;
-LIBINT2_REALTYPE fp295;
-fp295 = inteval->roz[vi] * src3[((hsi*30+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp294;
-fp294 = src2[((hsi*30+3)*1+lsi)*1] - fp295;
-LIBINT2_REALTYPE fp293;
-fp293 = inteval->oo2z[vi] * fp294;
-LIBINT2_REALTYPE fp297;
-fp297 = inteval->WP_z[vi] * src1[((hsi*45+12)*1+lsi)*1];
-LIBINT2_REALTYPE fp298;
-fp298 = inteval->PA_z[vi] * src0[((hsi*45+12)*1+lsi)*1];
-LIBINT2_REALTYPE fp296;
-fp296 = fp298 + fp297;
-LIBINT2_REALTYPE fp292;
-fp292 = fp296 + fp293;
-target[((hsi*63+24)*1+lsi)*1] = fp292;
-LIBINT2_REALTYPE fp300;
-fp300 = inteval->oo2ze[vi] * src4[((hsi*15+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp302;
-fp302 = inteval->WP_z[vi] * src1[((hsi*45+11)*1+lsi)*1];
-LIBINT2_REALTYPE fp303;
-fp303 = inteval->PA_z[vi] * src0[((hsi*45+11)*1+lsi)*1];
-LIBINT2_REALTYPE fp301;
-fp301 = fp303 + fp302;
-LIBINT2_REALTYPE fp299;
-fp299 = fp301 + fp300;
-target[((hsi*63+23)*1+lsi)*1] = fp299;
-LIBINT2_REALTYPE fp305;
-fp305 = inteval->WP_z[vi] * src1[((hsi*45+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp306;
-fp306 = inteval->PA_z[vi] * src0[((hsi*45+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp304;
-fp304 = fp306 + fp305;
-target[((hsi*63+22)*1+lsi)*1] = fp304;
-LIBINT2_REALTYPE fp308;
-fp308 = inteval->WP_z[vi] * src1[((hsi*45+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp309;
-fp309 = inteval->PA_z[vi] * src0[((hsi*45+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp307;
-fp307 = fp309 + fp308;
-target[((hsi*63+21)*1+lsi)*1] = fp307;
-LIBINT2_REALTYPE fp313;
-fp313 = inteval->roz[vi] * src3[((hsi*30+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp312;
-fp312 = src2[((hsi*30+5)*1+lsi)*1] - fp313;
-LIBINT2_REALTYPE fp314;
-fp314 = 2 * inteval->oo2z[vi];
-LIBINT2_REALTYPE fp311;
-fp311 = fp314 * fp312;
-LIBINT2_REALTYPE fp316;
-fp316 = inteval->WP_y[vi] * src1[((hsi*45+11)*1+lsi)*1];
-LIBINT2_REALTYPE fp317;
-fp317 = inteval->PA_y[vi] * src0[((hsi*45+11)*1+lsi)*1];
-LIBINT2_REALTYPE fp315;
-fp315 = fp317 + fp316;
-LIBINT2_REALTYPE fp310;
-fp310 = fp315 + fp311;
-target[((hsi*63+20)*1+lsi)*1] = fp310;
-LIBINT2_REALTYPE fp319;
-fp319 = inteval->oo2ze[vi] * src4[((hsi*15+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp323;
-fp323 = inteval->roz[vi] * src3[((hsi*30+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp322;
-fp322 = src2[((hsi*30+4)*1+lsi)*1] - fp323;
-LIBINT2_REALTYPE fp324;
-fp324 = 2 * inteval->oo2z[vi];
-LIBINT2_REALTYPE fp321;
-fp321 = fp324 * fp322;
-LIBINT2_REALTYPE fp326;
-fp326 = inteval->WP_y[vi] * src1[((hsi*45+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp327;
-fp327 = inteval->PA_y[vi] * src0[((hsi*45+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp325;
-fp325 = fp327 + fp326;
-LIBINT2_REALTYPE fp320;
-fp320 = fp325 + fp321;
-LIBINT2_REALTYPE fp318;
-fp318 = fp320 + fp319;
-target[((hsi*63+19)*1+lsi)*1] = fp318;
-LIBINT2_REALTYPE fp331;
-fp331 = inteval->roz[vi] * src3[((hsi*30+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp330;
-fp330 = src2[((hsi*30+3)*1+lsi)*1] - fp331;
-LIBINT2_REALTYPE fp332;
-fp332 = 2 * inteval->oo2z[vi];
-LIBINT2_REALTYPE fp329;
-fp329 = fp332 * fp330;
-LIBINT2_REALTYPE fp334;
-fp334 = inteval->WP_y[vi] * src1[((hsi*45+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp335;
-fp335 = inteval->PA_y[vi] * src0[((hsi*45+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp333;
-fp333 = fp335 + fp334;
-LIBINT2_REALTYPE fp328;
-fp328 = fp333 + fp329;
-target[((hsi*63+18)*1+lsi)*1] = fp328;
-LIBINT2_REALTYPE fp337;
-fp337 = inteval->oo2ze[vi] * src4[((hsi*15+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp341;
-fp341 = inteval->roz[vi] * src3[((hsi*30+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp340;
-fp340 = src2[((hsi*30+2)*1+lsi)*1] - fp341;
-LIBINT2_REALTYPE fp339;
-fp339 = inteval->oo2z[vi] * fp340;
-LIBINT2_REALTYPE fp343;
-fp343 = inteval->WP_z[vi] * src1[((hsi*45+8)*1+lsi)*1];
-LIBINT2_REALTYPE fp344;
-fp344 = inteval->PA_z[vi] * src0[((hsi*45+8)*1+lsi)*1];
-LIBINT2_REALTYPE fp342;
-fp342 = fp344 + fp343;
-LIBINT2_REALTYPE fp338;
-fp338 = fp342 + fp339;
-LIBINT2_REALTYPE fp336;
-fp336 = fp338 + fp337;
-target[((hsi*63+17)*1+lsi)*1] = fp336;
-LIBINT2_REALTYPE fp348;
-fp348 = inteval->roz[vi] * src3[((hsi*30+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp347;
-fp347 = src2[((hsi*30+1)*1+lsi)*1] - fp348;
-LIBINT2_REALTYPE fp346;
-fp346 = inteval->oo2z[vi] * fp347;
-LIBINT2_REALTYPE fp350;
-fp350 = inteval->WP_z[vi] * src1[((hsi*45+7)*1+lsi)*1];
-LIBINT2_REALTYPE fp351;
-fp351 = inteval->PA_z[vi] * src0[((hsi*45+7)*1+lsi)*1];
-LIBINT2_REALTYPE fp349;
-fp349 = fp351 + fp350;
-LIBINT2_REALTYPE fp345;
-fp345 = fp349 + fp346;
-target[((hsi*63+16)*1+lsi)*1] = fp345;
-LIBINT2_REALTYPE fp355;
-fp355 = inteval->roz[vi] * src3[((hsi*30+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp354;
-fp354 = src2[((hsi*30+0)*1+lsi)*1] - fp355;
-LIBINT2_REALTYPE fp353;
-fp353 = inteval->oo2z[vi] * fp354;
-LIBINT2_REALTYPE fp357;
-fp357 = inteval->WP_z[vi] * src1[((hsi*45+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp358;
-fp358 = inteval->PA_z[vi] * src0[((hsi*45+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp356;
-fp356 = fp358 + fp357;
-LIBINT2_REALTYPE fp352;
-fp352 = fp356 + fp353;
-target[((hsi*63+15)*1+lsi)*1] = fp352;
-LIBINT2_REALTYPE fp360;
-fp360 = inteval->oo2ze[vi] * src4[((hsi*15+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp362;
-fp362 = inteval->WP_z[vi] * src1[((hsi*45+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp363;
-fp363 = inteval->PA_z[vi] * src0[((hsi*45+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp361;
-fp361 = fp363 + fp362;
-LIBINT2_REALTYPE fp359;
-fp359 = fp361 + fp360;
-target[((hsi*63+14)*1+lsi)*1] = fp359;
-LIBINT2_REALTYPE fp365;
-fp365 = inteval->WP_z[vi] * src1[((hsi*45+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp366;
-fp366 = inteval->PA_z[vi] * src0[((hsi*45+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp364;
-fp364 = fp366 + fp365;
-target[((hsi*63+13)*1+lsi)*1] = fp364;
-LIBINT2_REALTYPE fp368;
-fp368 = inteval->WP_z[vi] * src1[((hsi*45+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp369;
-fp369 = inteval->PA_z[vi] * src0[((hsi*45+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp367;
-fp367 = fp369 + fp368;
-target[((hsi*63+12)*1+lsi)*1] = fp367;
-LIBINT2_REALTYPE fp373;
-fp373 = inteval->roz[vi] * src3[((hsi*30+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp372;
-fp372 = src2[((hsi*30+2)*1+lsi)*1] - fp373;
-LIBINT2_REALTYPE fp371;
-fp371 = inteval->oo2z[vi] * fp372;
-LIBINT2_REALTYPE fp375;
-fp375 = inteval->WP_y[vi] * src1[((hsi*45+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp376;
-fp376 = inteval->PA_y[vi] * src0[((hsi*45+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp374;
-fp374 = fp376 + fp375;
-LIBINT2_REALTYPE fp370;
-fp370 = fp374 + fp371;
-target[((hsi*63+11)*1+lsi)*1] = fp370;
-LIBINT2_REALTYPE fp378;
-fp378 = inteval->oo2ze[vi] * src4[((hsi*15+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp382;
-fp382 = inteval->roz[vi] * src3[((hsi*30+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp381;
-fp381 = src2[((hsi*30+1)*1+lsi)*1] - fp382;
-LIBINT2_REALTYPE fp380;
-fp380 = inteval->oo2z[vi] * fp381;
-LIBINT2_REALTYPE fp384;
-fp384 = inteval->WP_y[vi] * src1[((hsi*45+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp385;
-fp385 = inteval->PA_y[vi] * src0[((hsi*45+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp383;
-fp383 = fp385 + fp384;
-LIBINT2_REALTYPE fp379;
-fp379 = fp383 + fp380;
-LIBINT2_REALTYPE fp377;
-fp377 = fp379 + fp378;
-target[((hsi*63+10)*1+lsi)*1] = fp377;
-LIBINT2_REALTYPE fp389;
-fp389 = inteval->roz[vi] * src3[((hsi*30+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp388;
-fp388 = src2[((hsi*30+0)*1+lsi)*1] - fp389;
-LIBINT2_REALTYPE fp387;
-fp387 = inteval->oo2z[vi] * fp388;
-LIBINT2_REALTYPE fp391;
-fp391 = inteval->WP_y[vi] * src1[((hsi*45+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp392;
-fp392 = inteval->PA_y[vi] * src0[((hsi*45+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp390;
-fp390 = fp392 + fp391;
-LIBINT2_REALTYPE fp386;
-fp386 = fp390 + fp387;
-target[((hsi*63+9)*1+lsi)*1] = fp386;
-LIBINT2_REALTYPE fp394;
-fp394 = inteval->oo2ze[vi] * src4[((hsi*15+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp396;
-fp396 = inteval->WP_z[vi] * src1[((hsi*45+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp397;
-fp397 = inteval->PA_z[vi] * src0[((hsi*45+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp395;
-fp395 = fp397 + fp396;
-LIBINT2_REALTYPE fp393;
-fp393 = fp395 + fp394;
-target[((hsi*63+8)*1+lsi)*1] = fp393;
-LIBINT2_REALTYPE fp399;
-fp399 = inteval->WP_z[vi] * src1[((hsi*45+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp400;
-fp400 = inteval->PA_z[vi] * src0[((hsi*45+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp398;
-fp398 = fp400 + fp399;
-target[((hsi*63+7)*1+lsi)*1] = fp398;
-LIBINT2_REALTYPE fp402;
-fp402 = inteval->WP_z[vi] * src1[((hsi*45+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp403;
-fp403 = inteval->PA_z[vi] * src0[((hsi*45+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp401;
-fp401 = fp403 + fp402;
-target[((hsi*63+6)*1+lsi)*1] = fp401;
-LIBINT2_REALTYPE fp405;
-fp405 = inteval->WP_y[vi] * src1[((hsi*45+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp406;
-fp406 = inteval->PA_y[vi] * src0[((hsi*45+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp404;
-fp404 = fp406 + fp405;
-target[((hsi*63+5)*1+lsi)*1] = fp404;
-LIBINT2_REALTYPE fp408;
-fp408 = inteval->oo2ze[vi] * src4[((hsi*15+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp410;
-fp410 = inteval->WP_y[vi] * src1[((hsi*45+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp411;
-fp411 = inteval->PA_y[vi] * src0[((hsi*45+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp409;
-fp409 = fp411 + fp410;
-LIBINT2_REALTYPE fp407;
-fp407 = fp409 + fp408;
-target[((hsi*63+4)*1+lsi)*1] = fp407;
-LIBINT2_REALTYPE fp413;
-fp413 = inteval->WP_y[vi] * src1[((hsi*45+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp414;
-fp414 = inteval->PA_y[vi] * src0[((hsi*45+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp412;
-fp412 = fp414 + fp413;
-target[((hsi*63+3)*1+lsi)*1] = fp412;
-LIBINT2_REALTYPE fp418;
-fp418 = inteval->roz[vi] * src3[((hsi*30+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp417;
-fp417 = src2[((hsi*30+2)*1+lsi)*1] - fp418;
-LIBINT2_REALTYPE fp419;
-fp419 = 4 * inteval->oo2z[vi];
-LIBINT2_REALTYPE fp416;
-fp416 = fp419 * fp417;
-LIBINT2_REALTYPE fp421;
-fp421 = inteval->WP_x[vi] * src1[((hsi*45+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp422;
-fp422 = inteval->PA_x[vi] * src0[((hsi*45+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp420;
-fp420 = fp422 + fp421;
-LIBINT2_REALTYPE fp415;
-fp415 = fp420 + fp416;
-target[((hsi*63+2)*1+lsi)*1] = fp415;
-LIBINT2_REALTYPE fp426;
-fp426 = inteval->roz[vi] * src3[((hsi*30+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp425;
-fp425 = src2[((hsi*30+1)*1+lsi)*1] - fp426;
-LIBINT2_REALTYPE fp427;
-fp427 = 4 * inteval->oo2z[vi];
-LIBINT2_REALTYPE fp424;
-fp424 = fp427 * fp425;
-LIBINT2_REALTYPE fp429;
-fp429 = inteval->WP_x[vi] * src1[((hsi*45+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp430;
-fp430 = inteval->PA_x[vi] * src0[((hsi*45+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp428;
-fp428 = fp430 + fp429;
-LIBINT2_REALTYPE fp423;
-fp423 = fp428 + fp424;
-target[((hsi*63+1)*1+lsi)*1] = fp423;
-LIBINT2_REALTYPE fp432;
-fp432 = inteval->oo2ze[vi] * src4[((hsi*15+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp436;
-fp436 = inteval->roz[vi] * src3[((hsi*30+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp435;
-fp435 = src2[((hsi*30+0)*1+lsi)*1] - fp436;
-LIBINT2_REALTYPE fp437;
-fp437 = 4 * inteval->oo2z[vi];
-LIBINT2_REALTYPE fp434;
-fp434 = fp437 * fp435;
-LIBINT2_REALTYPE fp439;
-fp439 = inteval->WP_x[vi] * src1[((hsi*45+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp440;
-fp440 = inteval->PA_x[vi] * src0[((hsi*45+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp438;
-fp438 = fp440 + fp439;
-LIBINT2_REALTYPE fp433;
-fp433 = fp438 + fp434;
-LIBINT2_REALTYPE fp431;
-fp431 = fp433 + fp432;
-target[((hsi*63+0)*1+lsi)*1] = fp431;
 }
 }
 }
@@ -964,4 +966,6 @@ const int vi = 0;
 /** Number of flops = 441 */
 }
 
+#ifdef __cplusplus
 };
+#endif
