@@ -1,6 +1,8 @@
 #include <libint2.h>
 
+#ifdef __cplusplus
 extern "C" {
+#endif
 void OSVRRP0InBra_aB_k__0__s__1___TwoPRep_s__0__s__1___Ab__up_0(const Libint_t* inteval, LIBINT2_REALTYPE* target, const LIBINT2_REALTYPE* src0, const LIBINT2_REALTYPE* src1, const LIBINT2_REALTYPE* src2, const LIBINT2_REALTYPE* src3) {
 
 LIBINT2_REALTYPE*const  stack = target;
@@ -10,6 +12,242 @@ const int hsi = 0;
 const int lsi = 0;
 {
 const int vi = 0;
+LIBINT2_REALTYPE fp135;
+fp135 = inteval->roz[vi] * src3[((hsi*21+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp134;
+fp134 = src2[((hsi*21+6)*1+lsi)*1] - fp135;
+LIBINT2_REALTYPE fp133;
+fp133 = inteval->oo2z[vi] * fp134;
+LIBINT2_REALTYPE fp137;
+fp137 = inteval->WP_z[vi] * src1[((hsi*28+11)*1+lsi)*1];
+LIBINT2_REALTYPE fp138;
+fp138 = inteval->PA_z[vi] * src0[((hsi*28+11)*1+lsi)*1];
+LIBINT2_REALTYPE fp136;
+fp136 = fp138 + fp137;
+LIBINT2_REALTYPE fp132;
+fp132 = fp136 + fp133;
+target[((hsi*36+17)*1+lsi)*1] = fp132;
+LIBINT2_REALTYPE fp140;
+fp140 = inteval->WP_z[vi] * src1[((hsi*28+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp141;
+fp141 = inteval->PA_z[vi] * src0[((hsi*28+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp139;
+fp139 = fp141 + fp140;
+target[((hsi*36+16)*1+lsi)*1] = fp139;
+LIBINT2_REALTYPE fp145;
+fp145 = inteval->roz[vi] * src3[((hsi*21+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp144;
+fp144 = src2[((hsi*21+6)*1+lsi)*1] - fp145;
+LIBINT2_REALTYPE fp146;
+fp146 = 4 * inteval->oo2z[vi];
+LIBINT2_REALTYPE fp143;
+fp143 = fp146 * fp144;
+LIBINT2_REALTYPE fp148;
+fp148 = inteval->WP_y[vi] * src1[((hsi*28+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp149;
+fp149 = inteval->PA_y[vi] * src0[((hsi*28+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp147;
+fp147 = fp149 + fp148;
+LIBINT2_REALTYPE fp142;
+fp142 = fp147 + fp143;
+target[((hsi*36+15)*1+lsi)*1] = fp142;
+LIBINT2_REALTYPE fp153;
+fp153 = inteval->roz[vi] * src3[((hsi*21+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp152;
+fp152 = src2[((hsi*21+5)*1+lsi)*1] - fp153;
+LIBINT2_REALTYPE fp154;
+fp154 = 3 * inteval->oo2z[vi];
+LIBINT2_REALTYPE fp151;
+fp151 = fp154 * fp152;
+LIBINT2_REALTYPE fp156;
+fp156 = inteval->WP_z[vi] * src1[((hsi*28+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp157;
+fp157 = inteval->PA_z[vi] * src0[((hsi*28+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp155;
+fp155 = fp157 + fp156;
+LIBINT2_REALTYPE fp150;
+fp150 = fp155 + fp151;
+target[((hsi*36+14)*1+lsi)*1] = fp150;
+LIBINT2_REALTYPE fp161;
+fp161 = inteval->roz[vi] * src3[((hsi*21+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp160;
+fp160 = src2[((hsi*21+4)*1+lsi)*1] - fp161;
+LIBINT2_REALTYPE fp162;
+fp162 = 2 * inteval->oo2z[vi];
+LIBINT2_REALTYPE fp159;
+fp159 = fp162 * fp160;
+LIBINT2_REALTYPE fp164;
+fp164 = inteval->WP_z[vi] * src1[((hsi*28+8)*1+lsi)*1];
+LIBINT2_REALTYPE fp165;
+fp165 = inteval->PA_z[vi] * src0[((hsi*28+8)*1+lsi)*1];
+LIBINT2_REALTYPE fp163;
+fp163 = fp165 + fp164;
+LIBINT2_REALTYPE fp158;
+fp158 = fp163 + fp159;
+target[((hsi*36+13)*1+lsi)*1] = fp158;
+LIBINT2_REALTYPE fp169;
+fp169 = inteval->roz[vi] * src3[((hsi*21+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp168;
+fp168 = src2[((hsi*21+3)*1+lsi)*1] - fp169;
+LIBINT2_REALTYPE fp167;
+fp167 = inteval->oo2z[vi] * fp168;
+LIBINT2_REALTYPE fp171;
+fp171 = inteval->WP_z[vi] * src1[((hsi*28+7)*1+lsi)*1];
+LIBINT2_REALTYPE fp172;
+fp172 = inteval->PA_z[vi] * src0[((hsi*28+7)*1+lsi)*1];
+LIBINT2_REALTYPE fp170;
+fp170 = fp172 + fp171;
+LIBINT2_REALTYPE fp166;
+fp166 = fp170 + fp167;
+target[((hsi*36+12)*1+lsi)*1] = fp166;
+LIBINT2_REALTYPE fp174;
+fp174 = inteval->WP_z[vi] * src1[((hsi*28+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp175;
+fp175 = inteval->PA_z[vi] * src0[((hsi*28+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp173;
+fp173 = fp175 + fp174;
+target[((hsi*36+11)*1+lsi)*1] = fp173;
+LIBINT2_REALTYPE fp179;
+fp179 = inteval->roz[vi] * src3[((hsi*21+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp178;
+fp178 = src2[((hsi*21+3)*1+lsi)*1] - fp179;
+LIBINT2_REALTYPE fp180;
+fp180 = 3 * inteval->oo2z[vi];
+LIBINT2_REALTYPE fp177;
+fp177 = fp180 * fp178;
+LIBINT2_REALTYPE fp182;
+fp182 = inteval->WP_y[vi] * src1[((hsi*28+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp183;
+fp183 = inteval->PA_y[vi] * src0[((hsi*28+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp181;
+fp181 = fp183 + fp182;
+LIBINT2_REALTYPE fp176;
+fp176 = fp181 + fp177;
+target[((hsi*36+10)*1+lsi)*1] = fp176;
+LIBINT2_REALTYPE fp187;
+fp187 = inteval->roz[vi] * src3[((hsi*21+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp186;
+fp186 = src2[((hsi*21+2)*1+lsi)*1] - fp187;
+LIBINT2_REALTYPE fp188;
+fp188 = 2 * inteval->oo2z[vi];
+LIBINT2_REALTYPE fp185;
+fp185 = fp188 * fp186;
+LIBINT2_REALTYPE fp190;
+fp190 = inteval->WP_z[vi] * src1[((hsi*28+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp191;
+fp191 = inteval->PA_z[vi] * src0[((hsi*28+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp189;
+fp189 = fp191 + fp190;
+LIBINT2_REALTYPE fp184;
+fp184 = fp189 + fp185;
+target[((hsi*36+9)*1+lsi)*1] = fp184;
+LIBINT2_REALTYPE fp195;
+fp195 = inteval->roz[vi] * src3[((hsi*21+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp194;
+fp194 = src2[((hsi*21+1)*1+lsi)*1] - fp195;
+LIBINT2_REALTYPE fp193;
+fp193 = inteval->oo2z[vi] * fp194;
+LIBINT2_REALTYPE fp197;
+fp197 = inteval->WP_z[vi] * src1[((hsi*28+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp198;
+fp198 = inteval->PA_z[vi] * src0[((hsi*28+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp196;
+fp196 = fp198 + fp197;
+LIBINT2_REALTYPE fp192;
+fp192 = fp196 + fp193;
+target[((hsi*36+8)*1+lsi)*1] = fp192;
+LIBINT2_REALTYPE fp200;
+fp200 = inteval->WP_z[vi] * src1[((hsi*28+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp201;
+fp201 = inteval->PA_z[vi] * src0[((hsi*28+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp199;
+fp199 = fp201 + fp200;
+target[((hsi*36+7)*1+lsi)*1] = fp199;
+LIBINT2_REALTYPE fp205;
+fp205 = inteval->roz[vi] * src3[((hsi*21+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp204;
+fp204 = src2[((hsi*21+1)*1+lsi)*1] - fp205;
+LIBINT2_REALTYPE fp206;
+fp206 = 2 * inteval->oo2z[vi];
+LIBINT2_REALTYPE fp203;
+fp203 = fp206 * fp204;
+LIBINT2_REALTYPE fp208;
+fp208 = inteval->WP_y[vi] * src1[((hsi*28+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp209;
+fp209 = inteval->PA_y[vi] * src0[((hsi*28+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp207;
+fp207 = fp209 + fp208;
+LIBINT2_REALTYPE fp202;
+fp202 = fp207 + fp203;
+target[((hsi*36+6)*1+lsi)*1] = fp202;
+LIBINT2_REALTYPE fp213;
+fp213 = inteval->roz[vi] * src3[((hsi*21+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp212;
+fp212 = src2[((hsi*21+0)*1+lsi)*1] - fp213;
+LIBINT2_REALTYPE fp211;
+fp211 = inteval->oo2z[vi] * fp212;
+LIBINT2_REALTYPE fp215;
+fp215 = inteval->WP_z[vi] * src1[((hsi*28+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp216;
+fp216 = inteval->PA_z[vi] * src0[((hsi*28+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp214;
+fp214 = fp216 + fp215;
+LIBINT2_REALTYPE fp210;
+fp210 = fp214 + fp211;
+target[((hsi*36+5)*1+lsi)*1] = fp210;
+LIBINT2_REALTYPE fp218;
+fp218 = inteval->WP_z[vi] * src1[((hsi*28+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp219;
+fp219 = inteval->PA_z[vi] * src0[((hsi*28+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp217;
+fp217 = fp219 + fp218;
+target[((hsi*36+4)*1+lsi)*1] = fp217;
+LIBINT2_REALTYPE fp223;
+fp223 = inteval->roz[vi] * src3[((hsi*21+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp222;
+fp222 = src2[((hsi*21+0)*1+lsi)*1] - fp223;
+LIBINT2_REALTYPE fp221;
+fp221 = inteval->oo2z[vi] * fp222;
+LIBINT2_REALTYPE fp225;
+fp225 = inteval->WP_y[vi] * src1[((hsi*28+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp226;
+fp226 = inteval->PA_y[vi] * src0[((hsi*28+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp224;
+fp224 = fp226 + fp225;
+LIBINT2_REALTYPE fp220;
+fp220 = fp224 + fp221;
+target[((hsi*36+3)*1+lsi)*1] = fp220;
+LIBINT2_REALTYPE fp228;
+fp228 = inteval->WP_z[vi] * src1[((hsi*28+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp229;
+fp229 = inteval->PA_z[vi] * src0[((hsi*28+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp227;
+fp227 = fp229 + fp228;
+target[((hsi*36+2)*1+lsi)*1] = fp227;
+LIBINT2_REALTYPE fp231;
+fp231 = inteval->WP_y[vi] * src1[((hsi*28+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp232;
+fp232 = inteval->PA_y[vi] * src0[((hsi*28+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp230;
+fp230 = fp232 + fp231;
+target[((hsi*36+1)*1+lsi)*1] = fp230;
+LIBINT2_REALTYPE fp236;
+fp236 = inteval->roz[vi] * src3[((hsi*21+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp235;
+fp235 = src2[((hsi*21+0)*1+lsi)*1] - fp236;
+LIBINT2_REALTYPE fp237;
+fp237 = 6 * inteval->oo2z[vi];
+LIBINT2_REALTYPE fp234;
+fp234 = fp237 * fp235;
+LIBINT2_REALTYPE fp239;
+fp239 = inteval->WP_x[vi] * src1[((hsi*28+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp240;
+fp240 = inteval->PA_x[vi] * src0[((hsi*28+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp238;
+fp238 = fp240 + fp239;
+LIBINT2_REALTYPE fp233;
+fp233 = fp238 + fp234;
+target[((hsi*36+0)*1+lsi)*1] = fp233;
 LIBINT2_REALTYPE fp3;
 fp3 = inteval->roz[vi] * src3[((hsi*21+20)*1+lsi)*1];
 LIBINT2_REALTYPE fp2;
@@ -292,242 +530,6 @@ fp129 = fp131 + fp130;
 LIBINT2_REALTYPE fp124;
 fp124 = fp129 + fp125;
 target[((hsi*36+18)*1+lsi)*1] = fp124;
-LIBINT2_REALTYPE fp135;
-fp135 = inteval->roz[vi] * src3[((hsi*21+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp134;
-fp134 = src2[((hsi*21+6)*1+lsi)*1] - fp135;
-LIBINT2_REALTYPE fp133;
-fp133 = inteval->oo2z[vi] * fp134;
-LIBINT2_REALTYPE fp137;
-fp137 = inteval->WP_z[vi] * src1[((hsi*28+11)*1+lsi)*1];
-LIBINT2_REALTYPE fp138;
-fp138 = inteval->PA_z[vi] * src0[((hsi*28+11)*1+lsi)*1];
-LIBINT2_REALTYPE fp136;
-fp136 = fp138 + fp137;
-LIBINT2_REALTYPE fp132;
-fp132 = fp136 + fp133;
-target[((hsi*36+17)*1+lsi)*1] = fp132;
-LIBINT2_REALTYPE fp140;
-fp140 = inteval->WP_z[vi] * src1[((hsi*28+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp141;
-fp141 = inteval->PA_z[vi] * src0[((hsi*28+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp139;
-fp139 = fp141 + fp140;
-target[((hsi*36+16)*1+lsi)*1] = fp139;
-LIBINT2_REALTYPE fp145;
-fp145 = inteval->roz[vi] * src3[((hsi*21+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp144;
-fp144 = src2[((hsi*21+6)*1+lsi)*1] - fp145;
-LIBINT2_REALTYPE fp146;
-fp146 = 4 * inteval->oo2z[vi];
-LIBINT2_REALTYPE fp143;
-fp143 = fp146 * fp144;
-LIBINT2_REALTYPE fp148;
-fp148 = inteval->WP_y[vi] * src1[((hsi*28+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp149;
-fp149 = inteval->PA_y[vi] * src0[((hsi*28+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp147;
-fp147 = fp149 + fp148;
-LIBINT2_REALTYPE fp142;
-fp142 = fp147 + fp143;
-target[((hsi*36+15)*1+lsi)*1] = fp142;
-LIBINT2_REALTYPE fp153;
-fp153 = inteval->roz[vi] * src3[((hsi*21+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp152;
-fp152 = src2[((hsi*21+5)*1+lsi)*1] - fp153;
-LIBINT2_REALTYPE fp154;
-fp154 = 3 * inteval->oo2z[vi];
-LIBINT2_REALTYPE fp151;
-fp151 = fp154 * fp152;
-LIBINT2_REALTYPE fp156;
-fp156 = inteval->WP_z[vi] * src1[((hsi*28+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp157;
-fp157 = inteval->PA_z[vi] * src0[((hsi*28+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp155;
-fp155 = fp157 + fp156;
-LIBINT2_REALTYPE fp150;
-fp150 = fp155 + fp151;
-target[((hsi*36+14)*1+lsi)*1] = fp150;
-LIBINT2_REALTYPE fp161;
-fp161 = inteval->roz[vi] * src3[((hsi*21+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp160;
-fp160 = src2[((hsi*21+4)*1+lsi)*1] - fp161;
-LIBINT2_REALTYPE fp162;
-fp162 = 2 * inteval->oo2z[vi];
-LIBINT2_REALTYPE fp159;
-fp159 = fp162 * fp160;
-LIBINT2_REALTYPE fp164;
-fp164 = inteval->WP_z[vi] * src1[((hsi*28+8)*1+lsi)*1];
-LIBINT2_REALTYPE fp165;
-fp165 = inteval->PA_z[vi] * src0[((hsi*28+8)*1+lsi)*1];
-LIBINT2_REALTYPE fp163;
-fp163 = fp165 + fp164;
-LIBINT2_REALTYPE fp158;
-fp158 = fp163 + fp159;
-target[((hsi*36+13)*1+lsi)*1] = fp158;
-LIBINT2_REALTYPE fp169;
-fp169 = inteval->roz[vi] * src3[((hsi*21+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp168;
-fp168 = src2[((hsi*21+3)*1+lsi)*1] - fp169;
-LIBINT2_REALTYPE fp167;
-fp167 = inteval->oo2z[vi] * fp168;
-LIBINT2_REALTYPE fp171;
-fp171 = inteval->WP_z[vi] * src1[((hsi*28+7)*1+lsi)*1];
-LIBINT2_REALTYPE fp172;
-fp172 = inteval->PA_z[vi] * src0[((hsi*28+7)*1+lsi)*1];
-LIBINT2_REALTYPE fp170;
-fp170 = fp172 + fp171;
-LIBINT2_REALTYPE fp166;
-fp166 = fp170 + fp167;
-target[((hsi*36+12)*1+lsi)*1] = fp166;
-LIBINT2_REALTYPE fp174;
-fp174 = inteval->WP_z[vi] * src1[((hsi*28+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp175;
-fp175 = inteval->PA_z[vi] * src0[((hsi*28+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp173;
-fp173 = fp175 + fp174;
-target[((hsi*36+11)*1+lsi)*1] = fp173;
-LIBINT2_REALTYPE fp179;
-fp179 = inteval->roz[vi] * src3[((hsi*21+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp178;
-fp178 = src2[((hsi*21+3)*1+lsi)*1] - fp179;
-LIBINT2_REALTYPE fp180;
-fp180 = 3 * inteval->oo2z[vi];
-LIBINT2_REALTYPE fp177;
-fp177 = fp180 * fp178;
-LIBINT2_REALTYPE fp182;
-fp182 = inteval->WP_y[vi] * src1[((hsi*28+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp183;
-fp183 = inteval->PA_y[vi] * src0[((hsi*28+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp181;
-fp181 = fp183 + fp182;
-LIBINT2_REALTYPE fp176;
-fp176 = fp181 + fp177;
-target[((hsi*36+10)*1+lsi)*1] = fp176;
-LIBINT2_REALTYPE fp187;
-fp187 = inteval->roz[vi] * src3[((hsi*21+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp186;
-fp186 = src2[((hsi*21+2)*1+lsi)*1] - fp187;
-LIBINT2_REALTYPE fp188;
-fp188 = 2 * inteval->oo2z[vi];
-LIBINT2_REALTYPE fp185;
-fp185 = fp188 * fp186;
-LIBINT2_REALTYPE fp190;
-fp190 = inteval->WP_z[vi] * src1[((hsi*28+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp191;
-fp191 = inteval->PA_z[vi] * src0[((hsi*28+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp189;
-fp189 = fp191 + fp190;
-LIBINT2_REALTYPE fp184;
-fp184 = fp189 + fp185;
-target[((hsi*36+9)*1+lsi)*1] = fp184;
-LIBINT2_REALTYPE fp195;
-fp195 = inteval->roz[vi] * src3[((hsi*21+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp194;
-fp194 = src2[((hsi*21+1)*1+lsi)*1] - fp195;
-LIBINT2_REALTYPE fp193;
-fp193 = inteval->oo2z[vi] * fp194;
-LIBINT2_REALTYPE fp197;
-fp197 = inteval->WP_z[vi] * src1[((hsi*28+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp198;
-fp198 = inteval->PA_z[vi] * src0[((hsi*28+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp196;
-fp196 = fp198 + fp197;
-LIBINT2_REALTYPE fp192;
-fp192 = fp196 + fp193;
-target[((hsi*36+8)*1+lsi)*1] = fp192;
-LIBINT2_REALTYPE fp200;
-fp200 = inteval->WP_z[vi] * src1[((hsi*28+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp201;
-fp201 = inteval->PA_z[vi] * src0[((hsi*28+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp199;
-fp199 = fp201 + fp200;
-target[((hsi*36+7)*1+lsi)*1] = fp199;
-LIBINT2_REALTYPE fp205;
-fp205 = inteval->roz[vi] * src3[((hsi*21+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp204;
-fp204 = src2[((hsi*21+1)*1+lsi)*1] - fp205;
-LIBINT2_REALTYPE fp206;
-fp206 = 2 * inteval->oo2z[vi];
-LIBINT2_REALTYPE fp203;
-fp203 = fp206 * fp204;
-LIBINT2_REALTYPE fp208;
-fp208 = inteval->WP_y[vi] * src1[((hsi*28+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp209;
-fp209 = inteval->PA_y[vi] * src0[((hsi*28+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp207;
-fp207 = fp209 + fp208;
-LIBINT2_REALTYPE fp202;
-fp202 = fp207 + fp203;
-target[((hsi*36+6)*1+lsi)*1] = fp202;
-LIBINT2_REALTYPE fp213;
-fp213 = inteval->roz[vi] * src3[((hsi*21+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp212;
-fp212 = src2[((hsi*21+0)*1+lsi)*1] - fp213;
-LIBINT2_REALTYPE fp211;
-fp211 = inteval->oo2z[vi] * fp212;
-LIBINT2_REALTYPE fp215;
-fp215 = inteval->WP_z[vi] * src1[((hsi*28+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp216;
-fp216 = inteval->PA_z[vi] * src0[((hsi*28+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp214;
-fp214 = fp216 + fp215;
-LIBINT2_REALTYPE fp210;
-fp210 = fp214 + fp211;
-target[((hsi*36+5)*1+lsi)*1] = fp210;
-LIBINT2_REALTYPE fp218;
-fp218 = inteval->WP_z[vi] * src1[((hsi*28+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp219;
-fp219 = inteval->PA_z[vi] * src0[((hsi*28+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp217;
-fp217 = fp219 + fp218;
-target[((hsi*36+4)*1+lsi)*1] = fp217;
-LIBINT2_REALTYPE fp223;
-fp223 = inteval->roz[vi] * src3[((hsi*21+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp222;
-fp222 = src2[((hsi*21+0)*1+lsi)*1] - fp223;
-LIBINT2_REALTYPE fp221;
-fp221 = inteval->oo2z[vi] * fp222;
-LIBINT2_REALTYPE fp225;
-fp225 = inteval->WP_y[vi] * src1[((hsi*28+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp226;
-fp226 = inteval->PA_y[vi] * src0[((hsi*28+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp224;
-fp224 = fp226 + fp225;
-LIBINT2_REALTYPE fp220;
-fp220 = fp224 + fp221;
-target[((hsi*36+3)*1+lsi)*1] = fp220;
-LIBINT2_REALTYPE fp228;
-fp228 = inteval->WP_z[vi] * src1[((hsi*28+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp229;
-fp229 = inteval->PA_z[vi] * src0[((hsi*28+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp227;
-fp227 = fp229 + fp228;
-target[((hsi*36+2)*1+lsi)*1] = fp227;
-LIBINT2_REALTYPE fp231;
-fp231 = inteval->WP_y[vi] * src1[((hsi*28+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp232;
-fp232 = inteval->PA_y[vi] * src0[((hsi*28+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp230;
-fp230 = fp232 + fp231;
-target[((hsi*36+1)*1+lsi)*1] = fp230;
-LIBINT2_REALTYPE fp236;
-fp236 = inteval->roz[vi] * src3[((hsi*21+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp235;
-fp235 = src2[((hsi*21+0)*1+lsi)*1] - fp236;
-LIBINT2_REALTYPE fp237;
-fp237 = 6 * inteval->oo2z[vi];
-LIBINT2_REALTYPE fp234;
-fp234 = fp237 * fp235;
-LIBINT2_REALTYPE fp239;
-fp239 = inteval->WP_x[vi] * src1[((hsi*28+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp240;
-fp240 = inteval->PA_x[vi] * src0[((hsi*28+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp238;
-fp238 = fp240 + fp239;
-LIBINT2_REALTYPE fp233;
-fp233 = fp238 + fp234;
-target[((hsi*36+0)*1+lsi)*1] = fp233;
 }
 }
 }
@@ -537,4 +539,6 @@ const int vi = 0;
 /** Number of flops = 241 */
 }
 
+#ifdef __cplusplus
 };
+#endif
