@@ -1,6 +1,8 @@
 #include <libint2.h>
 
+#ifdef __cplusplus
 extern "C" {
+#endif
 void OSVRRP0InBra_aB_p__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(const Libint_t* inteval, LIBINT2_REALTYPE* target, const LIBINT2_REALTYPE* src0, const LIBINT2_REALTYPE* src1, const LIBINT2_REALTYPE* src2) {
 
 LIBINT2_REALTYPE*const  stack = target;
@@ -10,6 +12,346 @@ const int hsi = 0;
 const int lsi = 0;
 {
 const int vi = 0;
+LIBINT2_REALTYPE fp157;
+fp157 = 4 * inteval->oo2ze[vi];
+LIBINT2_REALTYPE fp156;
+fp156 = fp157 * src2[((hsi*15+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp159;
+fp159 = inteval->WP_y[vi] * src1[((hsi*21+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp160;
+fp160 = inteval->PA_y[vi] * src0[((hsi*21+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp158;
+fp158 = fp160 + fp159;
+LIBINT2_REALTYPE fp155;
+fp155 = fp158 + fp156;
+target[((hsi*63+31)*1+lsi)*1] = fp155;
+LIBINT2_REALTYPE fp162;
+fp162 = inteval->WP_y[vi] * src1[((hsi*21+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp163;
+fp163 = inteval->PA_y[vi] * src0[((hsi*21+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp161;
+fp161 = fp163 + fp162;
+target[((hsi*63+30)*1+lsi)*1] = fp161;
+LIBINT2_REALTYPE fp165;
+fp165 = inteval->oo2ze[vi] * src2[((hsi*15+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp167;
+fp167 = inteval->WP_y[vi] * src1[((hsi*21+8)*1+lsi)*1];
+LIBINT2_REALTYPE fp168;
+fp168 = inteval->PA_y[vi] * src0[((hsi*21+8)*1+lsi)*1];
+LIBINT2_REALTYPE fp166;
+fp166 = fp168 + fp167;
+LIBINT2_REALTYPE fp164;
+fp164 = fp166 + fp165;
+target[((hsi*63+29)*1+lsi)*1] = fp164;
+LIBINT2_REALTYPE fp171;
+fp171 = 2 * inteval->oo2ze[vi];
+LIBINT2_REALTYPE fp170;
+fp170 = fp171 * src2[((hsi*15+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp173;
+fp173 = inteval->WP_y[vi] * src1[((hsi*21+7)*1+lsi)*1];
+LIBINT2_REALTYPE fp174;
+fp174 = inteval->PA_y[vi] * src0[((hsi*21+7)*1+lsi)*1];
+LIBINT2_REALTYPE fp172;
+fp172 = fp174 + fp173;
+LIBINT2_REALTYPE fp169;
+fp169 = fp172 + fp170;
+target[((hsi*63+28)*1+lsi)*1] = fp169;
+LIBINT2_REALTYPE fp177;
+fp177 = 3 * inteval->oo2ze[vi];
+LIBINT2_REALTYPE fp176;
+fp176 = fp177 * src2[((hsi*15+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp179;
+fp179 = inteval->WP_y[vi] * src1[((hsi*21+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp180;
+fp180 = inteval->PA_y[vi] * src0[((hsi*21+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp178;
+fp178 = fp180 + fp179;
+LIBINT2_REALTYPE fp175;
+fp175 = fp178 + fp176;
+target[((hsi*63+27)*1+lsi)*1] = fp175;
+LIBINT2_REALTYPE fp182;
+fp182 = inteval->WP_y[vi] * src1[((hsi*21+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp183;
+fp183 = inteval->PA_y[vi] * src0[((hsi*21+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp181;
+fp181 = fp183 + fp182;
+target[((hsi*63+26)*1+lsi)*1] = fp181;
+LIBINT2_REALTYPE fp185;
+fp185 = inteval->oo2ze[vi] * src2[((hsi*15+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp187;
+fp187 = inteval->WP_y[vi] * src1[((hsi*21+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp188;
+fp188 = inteval->PA_y[vi] * src0[((hsi*21+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp186;
+fp186 = fp188 + fp187;
+LIBINT2_REALTYPE fp184;
+fp184 = fp186 + fp185;
+target[((hsi*63+25)*1+lsi)*1] = fp184;
+LIBINT2_REALTYPE fp191;
+fp191 = 2 * inteval->oo2ze[vi];
+LIBINT2_REALTYPE fp190;
+fp190 = fp191 * src2[((hsi*15+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp193;
+fp193 = inteval->WP_y[vi] * src1[((hsi*21+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp194;
+fp194 = inteval->PA_y[vi] * src0[((hsi*21+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp192;
+fp192 = fp194 + fp193;
+LIBINT2_REALTYPE fp189;
+fp189 = fp192 + fp190;
+target[((hsi*63+24)*1+lsi)*1] = fp189;
+LIBINT2_REALTYPE fp196;
+fp196 = inteval->WP_y[vi] * src1[((hsi*21+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp197;
+fp197 = inteval->PA_y[vi] * src0[((hsi*21+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp195;
+fp195 = fp197 + fp196;
+target[((hsi*63+23)*1+lsi)*1] = fp195;
+LIBINT2_REALTYPE fp199;
+fp199 = inteval->oo2ze[vi] * src2[((hsi*15+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp201;
+fp201 = inteval->WP_y[vi] * src1[((hsi*21+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp202;
+fp202 = inteval->PA_y[vi] * src0[((hsi*21+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp200;
+fp200 = fp202 + fp201;
+LIBINT2_REALTYPE fp198;
+fp198 = fp200 + fp199;
+target[((hsi*63+22)*1+lsi)*1] = fp198;
+LIBINT2_REALTYPE fp204;
+fp204 = inteval->WP_y[vi] * src1[((hsi*21+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp205;
+fp205 = inteval->PA_y[vi] * src0[((hsi*21+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp203;
+fp203 = fp205 + fp204;
+target[((hsi*63+21)*1+lsi)*1] = fp203;
+LIBINT2_REALTYPE fp207;
+fp207 = inteval->WP_x[vi] * src1[((hsi*21+20)*1+lsi)*1];
+LIBINT2_REALTYPE fp208;
+fp208 = inteval->PA_x[vi] * src0[((hsi*21+20)*1+lsi)*1];
+LIBINT2_REALTYPE fp206;
+fp206 = fp208 + fp207;
+target[((hsi*63+20)*1+lsi)*1] = fp206;
+LIBINT2_REALTYPE fp210;
+fp210 = inteval->WP_x[vi] * src1[((hsi*21+19)*1+lsi)*1];
+LIBINT2_REALTYPE fp211;
+fp211 = inteval->PA_x[vi] * src0[((hsi*21+19)*1+lsi)*1];
+LIBINT2_REALTYPE fp209;
+fp209 = fp211 + fp210;
+target[((hsi*63+19)*1+lsi)*1] = fp209;
+LIBINT2_REALTYPE fp213;
+fp213 = inteval->WP_x[vi] * src1[((hsi*21+18)*1+lsi)*1];
+LIBINT2_REALTYPE fp214;
+fp214 = inteval->PA_x[vi] * src0[((hsi*21+18)*1+lsi)*1];
+LIBINT2_REALTYPE fp212;
+fp212 = fp214 + fp213;
+target[((hsi*63+18)*1+lsi)*1] = fp212;
+LIBINT2_REALTYPE fp216;
+fp216 = inteval->WP_x[vi] * src1[((hsi*21+17)*1+lsi)*1];
+LIBINT2_REALTYPE fp217;
+fp217 = inteval->PA_x[vi] * src0[((hsi*21+17)*1+lsi)*1];
+LIBINT2_REALTYPE fp215;
+fp215 = fp217 + fp216;
+target[((hsi*63+17)*1+lsi)*1] = fp215;
+LIBINT2_REALTYPE fp219;
+fp219 = inteval->WP_x[vi] * src1[((hsi*21+16)*1+lsi)*1];
+LIBINT2_REALTYPE fp220;
+fp220 = inteval->PA_x[vi] * src0[((hsi*21+16)*1+lsi)*1];
+LIBINT2_REALTYPE fp218;
+fp218 = fp220 + fp219;
+target[((hsi*63+16)*1+lsi)*1] = fp218;
+LIBINT2_REALTYPE fp222;
+fp222 = inteval->WP_x[vi] * src1[((hsi*21+15)*1+lsi)*1];
+LIBINT2_REALTYPE fp223;
+fp223 = inteval->PA_x[vi] * src0[((hsi*21+15)*1+lsi)*1];
+LIBINT2_REALTYPE fp221;
+fp221 = fp223 + fp222;
+target[((hsi*63+15)*1+lsi)*1] = fp221;
+LIBINT2_REALTYPE fp225;
+fp225 = inteval->oo2ze[vi] * src2[((hsi*15+14)*1+lsi)*1];
+LIBINT2_REALTYPE fp227;
+fp227 = inteval->WP_x[vi] * src1[((hsi*21+14)*1+lsi)*1];
+LIBINT2_REALTYPE fp228;
+fp228 = inteval->PA_x[vi] * src0[((hsi*21+14)*1+lsi)*1];
+LIBINT2_REALTYPE fp226;
+fp226 = fp228 + fp227;
+LIBINT2_REALTYPE fp224;
+fp224 = fp226 + fp225;
+target[((hsi*63+14)*1+lsi)*1] = fp224;
+LIBINT2_REALTYPE fp230;
+fp230 = inteval->oo2ze[vi] * src2[((hsi*15+13)*1+lsi)*1];
+LIBINT2_REALTYPE fp232;
+fp232 = inteval->WP_x[vi] * src1[((hsi*21+13)*1+lsi)*1];
+LIBINT2_REALTYPE fp233;
+fp233 = inteval->PA_x[vi] * src0[((hsi*21+13)*1+lsi)*1];
+LIBINT2_REALTYPE fp231;
+fp231 = fp233 + fp232;
+LIBINT2_REALTYPE fp229;
+fp229 = fp231 + fp230;
+target[((hsi*63+13)*1+lsi)*1] = fp229;
+LIBINT2_REALTYPE fp235;
+fp235 = inteval->oo2ze[vi] * src2[((hsi*15+12)*1+lsi)*1];
+LIBINT2_REALTYPE fp237;
+fp237 = inteval->WP_x[vi] * src1[((hsi*21+12)*1+lsi)*1];
+LIBINT2_REALTYPE fp238;
+fp238 = inteval->PA_x[vi] * src0[((hsi*21+12)*1+lsi)*1];
+LIBINT2_REALTYPE fp236;
+fp236 = fp238 + fp237;
+LIBINT2_REALTYPE fp234;
+fp234 = fp236 + fp235;
+target[((hsi*63+12)*1+lsi)*1] = fp234;
+LIBINT2_REALTYPE fp240;
+fp240 = inteval->oo2ze[vi] * src2[((hsi*15+11)*1+lsi)*1];
+LIBINT2_REALTYPE fp242;
+fp242 = inteval->WP_x[vi] * src1[((hsi*21+11)*1+lsi)*1];
+LIBINT2_REALTYPE fp243;
+fp243 = inteval->PA_x[vi] * src0[((hsi*21+11)*1+lsi)*1];
+LIBINT2_REALTYPE fp241;
+fp241 = fp243 + fp242;
+LIBINT2_REALTYPE fp239;
+fp239 = fp241 + fp240;
+target[((hsi*63+11)*1+lsi)*1] = fp239;
+LIBINT2_REALTYPE fp245;
+fp245 = inteval->oo2ze[vi] * src2[((hsi*15+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp247;
+fp247 = inteval->WP_x[vi] * src1[((hsi*21+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp248;
+fp248 = inteval->PA_x[vi] * src0[((hsi*21+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp246;
+fp246 = fp248 + fp247;
+LIBINT2_REALTYPE fp244;
+fp244 = fp246 + fp245;
+target[((hsi*63+10)*1+lsi)*1] = fp244;
+LIBINT2_REALTYPE fp251;
+fp251 = 2 * inteval->oo2ze[vi];
+LIBINT2_REALTYPE fp250;
+fp250 = fp251 * src2[((hsi*15+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp253;
+fp253 = inteval->WP_x[vi] * src1[((hsi*21+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp254;
+fp254 = inteval->PA_x[vi] * src0[((hsi*21+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp252;
+fp252 = fp254 + fp253;
+LIBINT2_REALTYPE fp249;
+fp249 = fp252 + fp250;
+target[((hsi*63+9)*1+lsi)*1] = fp249;
+LIBINT2_REALTYPE fp257;
+fp257 = 2 * inteval->oo2ze[vi];
+LIBINT2_REALTYPE fp256;
+fp256 = fp257 * src2[((hsi*15+8)*1+lsi)*1];
+LIBINT2_REALTYPE fp259;
+fp259 = inteval->WP_x[vi] * src1[((hsi*21+8)*1+lsi)*1];
+LIBINT2_REALTYPE fp260;
+fp260 = inteval->PA_x[vi] * src0[((hsi*21+8)*1+lsi)*1];
+LIBINT2_REALTYPE fp258;
+fp258 = fp260 + fp259;
+LIBINT2_REALTYPE fp255;
+fp255 = fp258 + fp256;
+target[((hsi*63+8)*1+lsi)*1] = fp255;
+LIBINT2_REALTYPE fp263;
+fp263 = 2 * inteval->oo2ze[vi];
+LIBINT2_REALTYPE fp262;
+fp262 = fp263 * src2[((hsi*15+7)*1+lsi)*1];
+LIBINT2_REALTYPE fp265;
+fp265 = inteval->WP_x[vi] * src1[((hsi*21+7)*1+lsi)*1];
+LIBINT2_REALTYPE fp266;
+fp266 = inteval->PA_x[vi] * src0[((hsi*21+7)*1+lsi)*1];
+LIBINT2_REALTYPE fp264;
+fp264 = fp266 + fp265;
+LIBINT2_REALTYPE fp261;
+fp261 = fp264 + fp262;
+target[((hsi*63+7)*1+lsi)*1] = fp261;
+LIBINT2_REALTYPE fp269;
+fp269 = 2 * inteval->oo2ze[vi];
+LIBINT2_REALTYPE fp268;
+fp268 = fp269 * src2[((hsi*15+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp271;
+fp271 = inteval->WP_x[vi] * src1[((hsi*21+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp272;
+fp272 = inteval->PA_x[vi] * src0[((hsi*21+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp270;
+fp270 = fp272 + fp271;
+LIBINT2_REALTYPE fp267;
+fp267 = fp270 + fp268;
+target[((hsi*63+6)*1+lsi)*1] = fp267;
+LIBINT2_REALTYPE fp275;
+fp275 = 3 * inteval->oo2ze[vi];
+LIBINT2_REALTYPE fp274;
+fp274 = fp275 * src2[((hsi*15+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp277;
+fp277 = inteval->WP_x[vi] * src1[((hsi*21+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp278;
+fp278 = inteval->PA_x[vi] * src0[((hsi*21+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp276;
+fp276 = fp278 + fp277;
+LIBINT2_REALTYPE fp273;
+fp273 = fp276 + fp274;
+target[((hsi*63+5)*1+lsi)*1] = fp273;
+LIBINT2_REALTYPE fp281;
+fp281 = 3 * inteval->oo2ze[vi];
+LIBINT2_REALTYPE fp280;
+fp280 = fp281 * src2[((hsi*15+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp283;
+fp283 = inteval->WP_x[vi] * src1[((hsi*21+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp284;
+fp284 = inteval->PA_x[vi] * src0[((hsi*21+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp282;
+fp282 = fp284 + fp283;
+LIBINT2_REALTYPE fp279;
+fp279 = fp282 + fp280;
+target[((hsi*63+4)*1+lsi)*1] = fp279;
+LIBINT2_REALTYPE fp287;
+fp287 = 3 * inteval->oo2ze[vi];
+LIBINT2_REALTYPE fp286;
+fp286 = fp287 * src2[((hsi*15+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp289;
+fp289 = inteval->WP_x[vi] * src1[((hsi*21+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp290;
+fp290 = inteval->PA_x[vi] * src0[((hsi*21+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp288;
+fp288 = fp290 + fp289;
+LIBINT2_REALTYPE fp285;
+fp285 = fp288 + fp286;
+target[((hsi*63+3)*1+lsi)*1] = fp285;
+LIBINT2_REALTYPE fp293;
+fp293 = 4 * inteval->oo2ze[vi];
+LIBINT2_REALTYPE fp292;
+fp292 = fp293 * src2[((hsi*15+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp295;
+fp295 = inteval->WP_x[vi] * src1[((hsi*21+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp296;
+fp296 = inteval->PA_x[vi] * src0[((hsi*21+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp294;
+fp294 = fp296 + fp295;
+LIBINT2_REALTYPE fp291;
+fp291 = fp294 + fp292;
+target[((hsi*63+2)*1+lsi)*1] = fp291;
+LIBINT2_REALTYPE fp299;
+fp299 = 4 * inteval->oo2ze[vi];
+LIBINT2_REALTYPE fp298;
+fp298 = fp299 * src2[((hsi*15+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp301;
+fp301 = inteval->WP_x[vi] * src1[((hsi*21+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp302;
+fp302 = inteval->PA_x[vi] * src0[((hsi*21+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp300;
+fp300 = fp302 + fp301;
+LIBINT2_REALTYPE fp297;
+fp297 = fp300 + fp298;
+target[((hsi*63+1)*1+lsi)*1] = fp297;
+LIBINT2_REALTYPE fp305;
+fp305 = 5 * inteval->oo2ze[vi];
+LIBINT2_REALTYPE fp304;
+fp304 = fp305 * src2[((hsi*15+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp307;
+fp307 = inteval->WP_x[vi] * src1[((hsi*21+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp308;
+fp308 = inteval->PA_x[vi] * src0[((hsi*21+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp306;
+fp306 = fp308 + fp307;
+LIBINT2_REALTYPE fp303;
+fp303 = fp306 + fp304;
+target[((hsi*63+0)*1+lsi)*1] = fp303;
 LIBINT2_REALTYPE fp2;
 fp2 = 5 * inteval->oo2ze[vi];
 LIBINT2_REALTYPE fp1;
@@ -351,346 +693,6 @@ fp152 = fp154 + fp153;
 LIBINT2_REALTYPE fp149;
 fp149 = fp152 + fp150;
 target[((hsi*63+32)*1+lsi)*1] = fp149;
-LIBINT2_REALTYPE fp157;
-fp157 = 4 * inteval->oo2ze[vi];
-LIBINT2_REALTYPE fp156;
-fp156 = fp157 * src2[((hsi*15+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp159;
-fp159 = inteval->WP_y[vi] * src1[((hsi*21+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp160;
-fp160 = inteval->PA_y[vi] * src0[((hsi*21+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp158;
-fp158 = fp160 + fp159;
-LIBINT2_REALTYPE fp155;
-fp155 = fp158 + fp156;
-target[((hsi*63+31)*1+lsi)*1] = fp155;
-LIBINT2_REALTYPE fp162;
-fp162 = inteval->WP_y[vi] * src1[((hsi*21+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp163;
-fp163 = inteval->PA_y[vi] * src0[((hsi*21+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp161;
-fp161 = fp163 + fp162;
-target[((hsi*63+30)*1+lsi)*1] = fp161;
-LIBINT2_REALTYPE fp165;
-fp165 = inteval->oo2ze[vi] * src2[((hsi*15+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp167;
-fp167 = inteval->WP_y[vi] * src1[((hsi*21+8)*1+lsi)*1];
-LIBINT2_REALTYPE fp168;
-fp168 = inteval->PA_y[vi] * src0[((hsi*21+8)*1+lsi)*1];
-LIBINT2_REALTYPE fp166;
-fp166 = fp168 + fp167;
-LIBINT2_REALTYPE fp164;
-fp164 = fp166 + fp165;
-target[((hsi*63+29)*1+lsi)*1] = fp164;
-LIBINT2_REALTYPE fp171;
-fp171 = 2 * inteval->oo2ze[vi];
-LIBINT2_REALTYPE fp170;
-fp170 = fp171 * src2[((hsi*15+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp173;
-fp173 = inteval->WP_y[vi] * src1[((hsi*21+7)*1+lsi)*1];
-LIBINT2_REALTYPE fp174;
-fp174 = inteval->PA_y[vi] * src0[((hsi*21+7)*1+lsi)*1];
-LIBINT2_REALTYPE fp172;
-fp172 = fp174 + fp173;
-LIBINT2_REALTYPE fp169;
-fp169 = fp172 + fp170;
-target[((hsi*63+28)*1+lsi)*1] = fp169;
-LIBINT2_REALTYPE fp177;
-fp177 = 3 * inteval->oo2ze[vi];
-LIBINT2_REALTYPE fp176;
-fp176 = fp177 * src2[((hsi*15+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp179;
-fp179 = inteval->WP_y[vi] * src1[((hsi*21+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp180;
-fp180 = inteval->PA_y[vi] * src0[((hsi*21+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp178;
-fp178 = fp180 + fp179;
-LIBINT2_REALTYPE fp175;
-fp175 = fp178 + fp176;
-target[((hsi*63+27)*1+lsi)*1] = fp175;
-LIBINT2_REALTYPE fp182;
-fp182 = inteval->WP_y[vi] * src1[((hsi*21+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp183;
-fp183 = inteval->PA_y[vi] * src0[((hsi*21+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp181;
-fp181 = fp183 + fp182;
-target[((hsi*63+26)*1+lsi)*1] = fp181;
-LIBINT2_REALTYPE fp185;
-fp185 = inteval->oo2ze[vi] * src2[((hsi*15+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp187;
-fp187 = inteval->WP_y[vi] * src1[((hsi*21+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp188;
-fp188 = inteval->PA_y[vi] * src0[((hsi*21+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp186;
-fp186 = fp188 + fp187;
-LIBINT2_REALTYPE fp184;
-fp184 = fp186 + fp185;
-target[((hsi*63+25)*1+lsi)*1] = fp184;
-LIBINT2_REALTYPE fp191;
-fp191 = 2 * inteval->oo2ze[vi];
-LIBINT2_REALTYPE fp190;
-fp190 = fp191 * src2[((hsi*15+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp193;
-fp193 = inteval->WP_y[vi] * src1[((hsi*21+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp194;
-fp194 = inteval->PA_y[vi] * src0[((hsi*21+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp192;
-fp192 = fp194 + fp193;
-LIBINT2_REALTYPE fp189;
-fp189 = fp192 + fp190;
-target[((hsi*63+24)*1+lsi)*1] = fp189;
-LIBINT2_REALTYPE fp196;
-fp196 = inteval->WP_y[vi] * src1[((hsi*21+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp197;
-fp197 = inteval->PA_y[vi] * src0[((hsi*21+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp195;
-fp195 = fp197 + fp196;
-target[((hsi*63+23)*1+lsi)*1] = fp195;
-LIBINT2_REALTYPE fp199;
-fp199 = inteval->oo2ze[vi] * src2[((hsi*15+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp201;
-fp201 = inteval->WP_y[vi] * src1[((hsi*21+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp202;
-fp202 = inteval->PA_y[vi] * src0[((hsi*21+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp200;
-fp200 = fp202 + fp201;
-LIBINT2_REALTYPE fp198;
-fp198 = fp200 + fp199;
-target[((hsi*63+22)*1+lsi)*1] = fp198;
-LIBINT2_REALTYPE fp204;
-fp204 = inteval->WP_y[vi] * src1[((hsi*21+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp205;
-fp205 = inteval->PA_y[vi] * src0[((hsi*21+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp203;
-fp203 = fp205 + fp204;
-target[((hsi*63+21)*1+lsi)*1] = fp203;
-LIBINT2_REALTYPE fp207;
-fp207 = inteval->WP_x[vi] * src1[((hsi*21+20)*1+lsi)*1];
-LIBINT2_REALTYPE fp208;
-fp208 = inteval->PA_x[vi] * src0[((hsi*21+20)*1+lsi)*1];
-LIBINT2_REALTYPE fp206;
-fp206 = fp208 + fp207;
-target[((hsi*63+20)*1+lsi)*1] = fp206;
-LIBINT2_REALTYPE fp210;
-fp210 = inteval->WP_x[vi] * src1[((hsi*21+19)*1+lsi)*1];
-LIBINT2_REALTYPE fp211;
-fp211 = inteval->PA_x[vi] * src0[((hsi*21+19)*1+lsi)*1];
-LIBINT2_REALTYPE fp209;
-fp209 = fp211 + fp210;
-target[((hsi*63+19)*1+lsi)*1] = fp209;
-LIBINT2_REALTYPE fp213;
-fp213 = inteval->WP_x[vi] * src1[((hsi*21+18)*1+lsi)*1];
-LIBINT2_REALTYPE fp214;
-fp214 = inteval->PA_x[vi] * src0[((hsi*21+18)*1+lsi)*1];
-LIBINT2_REALTYPE fp212;
-fp212 = fp214 + fp213;
-target[((hsi*63+18)*1+lsi)*1] = fp212;
-LIBINT2_REALTYPE fp216;
-fp216 = inteval->WP_x[vi] * src1[((hsi*21+17)*1+lsi)*1];
-LIBINT2_REALTYPE fp217;
-fp217 = inteval->PA_x[vi] * src0[((hsi*21+17)*1+lsi)*1];
-LIBINT2_REALTYPE fp215;
-fp215 = fp217 + fp216;
-target[((hsi*63+17)*1+lsi)*1] = fp215;
-LIBINT2_REALTYPE fp219;
-fp219 = inteval->WP_x[vi] * src1[((hsi*21+16)*1+lsi)*1];
-LIBINT2_REALTYPE fp220;
-fp220 = inteval->PA_x[vi] * src0[((hsi*21+16)*1+lsi)*1];
-LIBINT2_REALTYPE fp218;
-fp218 = fp220 + fp219;
-target[((hsi*63+16)*1+lsi)*1] = fp218;
-LIBINT2_REALTYPE fp222;
-fp222 = inteval->WP_x[vi] * src1[((hsi*21+15)*1+lsi)*1];
-LIBINT2_REALTYPE fp223;
-fp223 = inteval->PA_x[vi] * src0[((hsi*21+15)*1+lsi)*1];
-LIBINT2_REALTYPE fp221;
-fp221 = fp223 + fp222;
-target[((hsi*63+15)*1+lsi)*1] = fp221;
-LIBINT2_REALTYPE fp225;
-fp225 = inteval->oo2ze[vi] * src2[((hsi*15+14)*1+lsi)*1];
-LIBINT2_REALTYPE fp227;
-fp227 = inteval->WP_x[vi] * src1[((hsi*21+14)*1+lsi)*1];
-LIBINT2_REALTYPE fp228;
-fp228 = inteval->PA_x[vi] * src0[((hsi*21+14)*1+lsi)*1];
-LIBINT2_REALTYPE fp226;
-fp226 = fp228 + fp227;
-LIBINT2_REALTYPE fp224;
-fp224 = fp226 + fp225;
-target[((hsi*63+14)*1+lsi)*1] = fp224;
-LIBINT2_REALTYPE fp230;
-fp230 = inteval->oo2ze[vi] * src2[((hsi*15+13)*1+lsi)*1];
-LIBINT2_REALTYPE fp232;
-fp232 = inteval->WP_x[vi] * src1[((hsi*21+13)*1+lsi)*1];
-LIBINT2_REALTYPE fp233;
-fp233 = inteval->PA_x[vi] * src0[((hsi*21+13)*1+lsi)*1];
-LIBINT2_REALTYPE fp231;
-fp231 = fp233 + fp232;
-LIBINT2_REALTYPE fp229;
-fp229 = fp231 + fp230;
-target[((hsi*63+13)*1+lsi)*1] = fp229;
-LIBINT2_REALTYPE fp235;
-fp235 = inteval->oo2ze[vi] * src2[((hsi*15+12)*1+lsi)*1];
-LIBINT2_REALTYPE fp237;
-fp237 = inteval->WP_x[vi] * src1[((hsi*21+12)*1+lsi)*1];
-LIBINT2_REALTYPE fp238;
-fp238 = inteval->PA_x[vi] * src0[((hsi*21+12)*1+lsi)*1];
-LIBINT2_REALTYPE fp236;
-fp236 = fp238 + fp237;
-LIBINT2_REALTYPE fp234;
-fp234 = fp236 + fp235;
-target[((hsi*63+12)*1+lsi)*1] = fp234;
-LIBINT2_REALTYPE fp240;
-fp240 = inteval->oo2ze[vi] * src2[((hsi*15+11)*1+lsi)*1];
-LIBINT2_REALTYPE fp242;
-fp242 = inteval->WP_x[vi] * src1[((hsi*21+11)*1+lsi)*1];
-LIBINT2_REALTYPE fp243;
-fp243 = inteval->PA_x[vi] * src0[((hsi*21+11)*1+lsi)*1];
-LIBINT2_REALTYPE fp241;
-fp241 = fp243 + fp242;
-LIBINT2_REALTYPE fp239;
-fp239 = fp241 + fp240;
-target[((hsi*63+11)*1+lsi)*1] = fp239;
-LIBINT2_REALTYPE fp245;
-fp245 = inteval->oo2ze[vi] * src2[((hsi*15+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp247;
-fp247 = inteval->WP_x[vi] * src1[((hsi*21+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp248;
-fp248 = inteval->PA_x[vi] * src0[((hsi*21+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp246;
-fp246 = fp248 + fp247;
-LIBINT2_REALTYPE fp244;
-fp244 = fp246 + fp245;
-target[((hsi*63+10)*1+lsi)*1] = fp244;
-LIBINT2_REALTYPE fp251;
-fp251 = 2 * inteval->oo2ze[vi];
-LIBINT2_REALTYPE fp250;
-fp250 = fp251 * src2[((hsi*15+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp253;
-fp253 = inteval->WP_x[vi] * src1[((hsi*21+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp254;
-fp254 = inteval->PA_x[vi] * src0[((hsi*21+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp252;
-fp252 = fp254 + fp253;
-LIBINT2_REALTYPE fp249;
-fp249 = fp252 + fp250;
-target[((hsi*63+9)*1+lsi)*1] = fp249;
-LIBINT2_REALTYPE fp257;
-fp257 = 2 * inteval->oo2ze[vi];
-LIBINT2_REALTYPE fp256;
-fp256 = fp257 * src2[((hsi*15+8)*1+lsi)*1];
-LIBINT2_REALTYPE fp259;
-fp259 = inteval->WP_x[vi] * src1[((hsi*21+8)*1+lsi)*1];
-LIBINT2_REALTYPE fp260;
-fp260 = inteval->PA_x[vi] * src0[((hsi*21+8)*1+lsi)*1];
-LIBINT2_REALTYPE fp258;
-fp258 = fp260 + fp259;
-LIBINT2_REALTYPE fp255;
-fp255 = fp258 + fp256;
-target[((hsi*63+8)*1+lsi)*1] = fp255;
-LIBINT2_REALTYPE fp263;
-fp263 = 2 * inteval->oo2ze[vi];
-LIBINT2_REALTYPE fp262;
-fp262 = fp263 * src2[((hsi*15+7)*1+lsi)*1];
-LIBINT2_REALTYPE fp265;
-fp265 = inteval->WP_x[vi] * src1[((hsi*21+7)*1+lsi)*1];
-LIBINT2_REALTYPE fp266;
-fp266 = inteval->PA_x[vi] * src0[((hsi*21+7)*1+lsi)*1];
-LIBINT2_REALTYPE fp264;
-fp264 = fp266 + fp265;
-LIBINT2_REALTYPE fp261;
-fp261 = fp264 + fp262;
-target[((hsi*63+7)*1+lsi)*1] = fp261;
-LIBINT2_REALTYPE fp269;
-fp269 = 2 * inteval->oo2ze[vi];
-LIBINT2_REALTYPE fp268;
-fp268 = fp269 * src2[((hsi*15+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp271;
-fp271 = inteval->WP_x[vi] * src1[((hsi*21+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp272;
-fp272 = inteval->PA_x[vi] * src0[((hsi*21+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp270;
-fp270 = fp272 + fp271;
-LIBINT2_REALTYPE fp267;
-fp267 = fp270 + fp268;
-target[((hsi*63+6)*1+lsi)*1] = fp267;
-LIBINT2_REALTYPE fp275;
-fp275 = 3 * inteval->oo2ze[vi];
-LIBINT2_REALTYPE fp274;
-fp274 = fp275 * src2[((hsi*15+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp277;
-fp277 = inteval->WP_x[vi] * src1[((hsi*21+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp278;
-fp278 = inteval->PA_x[vi] * src0[((hsi*21+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp276;
-fp276 = fp278 + fp277;
-LIBINT2_REALTYPE fp273;
-fp273 = fp276 + fp274;
-target[((hsi*63+5)*1+lsi)*1] = fp273;
-LIBINT2_REALTYPE fp281;
-fp281 = 3 * inteval->oo2ze[vi];
-LIBINT2_REALTYPE fp280;
-fp280 = fp281 * src2[((hsi*15+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp283;
-fp283 = inteval->WP_x[vi] * src1[((hsi*21+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp284;
-fp284 = inteval->PA_x[vi] * src0[((hsi*21+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp282;
-fp282 = fp284 + fp283;
-LIBINT2_REALTYPE fp279;
-fp279 = fp282 + fp280;
-target[((hsi*63+4)*1+lsi)*1] = fp279;
-LIBINT2_REALTYPE fp287;
-fp287 = 3 * inteval->oo2ze[vi];
-LIBINT2_REALTYPE fp286;
-fp286 = fp287 * src2[((hsi*15+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp289;
-fp289 = inteval->WP_x[vi] * src1[((hsi*21+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp290;
-fp290 = inteval->PA_x[vi] * src0[((hsi*21+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp288;
-fp288 = fp290 + fp289;
-LIBINT2_REALTYPE fp285;
-fp285 = fp288 + fp286;
-target[((hsi*63+3)*1+lsi)*1] = fp285;
-LIBINT2_REALTYPE fp293;
-fp293 = 4 * inteval->oo2ze[vi];
-LIBINT2_REALTYPE fp292;
-fp292 = fp293 * src2[((hsi*15+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp295;
-fp295 = inteval->WP_x[vi] * src1[((hsi*21+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp296;
-fp296 = inteval->PA_x[vi] * src0[((hsi*21+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp294;
-fp294 = fp296 + fp295;
-LIBINT2_REALTYPE fp291;
-fp291 = fp294 + fp292;
-target[((hsi*63+2)*1+lsi)*1] = fp291;
-LIBINT2_REALTYPE fp299;
-fp299 = 4 * inteval->oo2ze[vi];
-LIBINT2_REALTYPE fp298;
-fp298 = fp299 * src2[((hsi*15+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp301;
-fp301 = inteval->WP_x[vi] * src1[((hsi*21+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp302;
-fp302 = inteval->PA_x[vi] * src0[((hsi*21+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp300;
-fp300 = fp302 + fp301;
-LIBINT2_REALTYPE fp297;
-fp297 = fp300 + fp298;
-target[((hsi*63+1)*1+lsi)*1] = fp297;
-LIBINT2_REALTYPE fp305;
-fp305 = 5 * inteval->oo2ze[vi];
-LIBINT2_REALTYPE fp304;
-fp304 = fp305 * src2[((hsi*15+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp307;
-fp307 = inteval->WP_x[vi] * src1[((hsi*21+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp308;
-fp308 = inteval->PA_x[vi] * src0[((hsi*21+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp306;
-fp306 = fp308 + fp307;
-LIBINT2_REALTYPE fp303;
-fp303 = fp306 + fp304;
-target[((hsi*63+0)*1+lsi)*1] = fp303;
 }
 }
 }
@@ -700,4 +702,6 @@ const int vi = 0;
 /** Number of flops = 309 */
 }
 
+#ifdef __cplusplus
 };
+#endif
