@@ -1,6 +1,8 @@
 #include <libint2.h>
 
+#ifdef __cplusplus
 extern "C" {
+#endif
 void OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(const Libint_t* inteval, LIBINT2_REALTYPE* target, const LIBINT2_REALTYPE* src0, const LIBINT2_REALTYPE* src1, const LIBINT2_REALTYPE* src2, const LIBINT2_REALTYPE* src3) {
 
 LIBINT2_REALTYPE*const  stack = target;
@@ -10,6 +12,317 @@ const int hsi = 0;
 const int lsi = 0;
 {
 const int vi = 0;
+LIBINT2_REALTYPE fp164;
+fp164 = inteval->WQ_z[vi] * src1[((hsi*36+15)*1+lsi)*1];
+LIBINT2_REALTYPE fp165;
+fp165 = inteval->QC_z[vi] * src0[((hsi*36+15)*1+lsi)*1];
+LIBINT2_REALTYPE fp163;
+fp163 = fp165 + fp164;
+target[((hsi*45+22)*1+lsi)*1] = fp163;
+LIBINT2_REALTYPE fp169;
+fp169 = inteval->roe[vi] * src3[((hsi*28+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp168;
+fp168 = src2[((hsi*28+10)*1+lsi)*1] - fp169;
+LIBINT2_REALTYPE fp170;
+fp170 = 5 * inteval->oo2e[vi];
+LIBINT2_REALTYPE fp167;
+fp167 = fp170 * fp168;
+LIBINT2_REALTYPE fp172;
+fp172 = inteval->WQ_y[vi] * src1[((hsi*36+15)*1+lsi)*1];
+LIBINT2_REALTYPE fp173;
+fp173 = inteval->QC_y[vi] * src0[((hsi*36+15)*1+lsi)*1];
+LIBINT2_REALTYPE fp171;
+fp171 = fp173 + fp172;
+LIBINT2_REALTYPE fp166;
+fp166 = fp171 + fp167;
+target[((hsi*45+21)*1+lsi)*1] = fp166;
+LIBINT2_REALTYPE fp177;
+fp177 = inteval->roe[vi] * src3[((hsi*28+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp176;
+fp176 = src2[((hsi*28+9)*1+lsi)*1] - fp177;
+LIBINT2_REALTYPE fp178;
+fp178 = 4 * inteval->oo2e[vi];
+LIBINT2_REALTYPE fp175;
+fp175 = fp178 * fp176;
+LIBINT2_REALTYPE fp180;
+fp180 = inteval->WQ_z[vi] * src1[((hsi*36+14)*1+lsi)*1];
+LIBINT2_REALTYPE fp181;
+fp181 = inteval->QC_z[vi] * src0[((hsi*36+14)*1+lsi)*1];
+LIBINT2_REALTYPE fp179;
+fp179 = fp181 + fp180;
+LIBINT2_REALTYPE fp174;
+fp174 = fp179 + fp175;
+target[((hsi*45+20)*1+lsi)*1] = fp174;
+LIBINT2_REALTYPE fp185;
+fp185 = inteval->roe[vi] * src3[((hsi*28+8)*1+lsi)*1];
+LIBINT2_REALTYPE fp184;
+fp184 = src2[((hsi*28+8)*1+lsi)*1] - fp185;
+LIBINT2_REALTYPE fp186;
+fp186 = 3 * inteval->oo2e[vi];
+LIBINT2_REALTYPE fp183;
+fp183 = fp186 * fp184;
+LIBINT2_REALTYPE fp188;
+fp188 = inteval->WQ_z[vi] * src1[((hsi*36+13)*1+lsi)*1];
+LIBINT2_REALTYPE fp189;
+fp189 = inteval->QC_z[vi] * src0[((hsi*36+13)*1+lsi)*1];
+LIBINT2_REALTYPE fp187;
+fp187 = fp189 + fp188;
+LIBINT2_REALTYPE fp182;
+fp182 = fp187 + fp183;
+target[((hsi*45+19)*1+lsi)*1] = fp182;
+LIBINT2_REALTYPE fp193;
+fp193 = inteval->roe[vi] * src3[((hsi*28+7)*1+lsi)*1];
+LIBINT2_REALTYPE fp192;
+fp192 = src2[((hsi*28+7)*1+lsi)*1] - fp193;
+LIBINT2_REALTYPE fp194;
+fp194 = 2 * inteval->oo2e[vi];
+LIBINT2_REALTYPE fp191;
+fp191 = fp194 * fp192;
+LIBINT2_REALTYPE fp196;
+fp196 = inteval->WQ_z[vi] * src1[((hsi*36+12)*1+lsi)*1];
+LIBINT2_REALTYPE fp197;
+fp197 = inteval->QC_z[vi] * src0[((hsi*36+12)*1+lsi)*1];
+LIBINT2_REALTYPE fp195;
+fp195 = fp197 + fp196;
+LIBINT2_REALTYPE fp190;
+fp190 = fp195 + fp191;
+target[((hsi*45+18)*1+lsi)*1] = fp190;
+LIBINT2_REALTYPE fp201;
+fp201 = inteval->roe[vi] * src3[((hsi*28+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp200;
+fp200 = src2[((hsi*28+6)*1+lsi)*1] - fp201;
+LIBINT2_REALTYPE fp199;
+fp199 = inteval->oo2e[vi] * fp200;
+LIBINT2_REALTYPE fp203;
+fp203 = inteval->WQ_z[vi] * src1[((hsi*36+11)*1+lsi)*1];
+LIBINT2_REALTYPE fp204;
+fp204 = inteval->QC_z[vi] * src0[((hsi*36+11)*1+lsi)*1];
+LIBINT2_REALTYPE fp202;
+fp202 = fp204 + fp203;
+LIBINT2_REALTYPE fp198;
+fp198 = fp202 + fp199;
+target[((hsi*45+17)*1+lsi)*1] = fp198;
+LIBINT2_REALTYPE fp206;
+fp206 = inteval->WQ_z[vi] * src1[((hsi*36+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp207;
+fp207 = inteval->QC_z[vi] * src0[((hsi*36+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp205;
+fp205 = fp207 + fp206;
+target[((hsi*45+16)*1+lsi)*1] = fp205;
+LIBINT2_REALTYPE fp211;
+fp211 = inteval->roe[vi] * src3[((hsi*28+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp210;
+fp210 = src2[((hsi*28+6)*1+lsi)*1] - fp211;
+LIBINT2_REALTYPE fp212;
+fp212 = 4 * inteval->oo2e[vi];
+LIBINT2_REALTYPE fp209;
+fp209 = fp212 * fp210;
+LIBINT2_REALTYPE fp214;
+fp214 = inteval->WQ_y[vi] * src1[((hsi*36+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp215;
+fp215 = inteval->QC_y[vi] * src0[((hsi*36+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp213;
+fp213 = fp215 + fp214;
+LIBINT2_REALTYPE fp208;
+fp208 = fp213 + fp209;
+target[((hsi*45+15)*1+lsi)*1] = fp208;
+LIBINT2_REALTYPE fp219;
+fp219 = inteval->roe[vi] * src3[((hsi*28+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp218;
+fp218 = src2[((hsi*28+5)*1+lsi)*1] - fp219;
+LIBINT2_REALTYPE fp220;
+fp220 = 3 * inteval->oo2e[vi];
+LIBINT2_REALTYPE fp217;
+fp217 = fp220 * fp218;
+LIBINT2_REALTYPE fp222;
+fp222 = inteval->WQ_z[vi] * src1[((hsi*36+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp223;
+fp223 = inteval->QC_z[vi] * src0[((hsi*36+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp221;
+fp221 = fp223 + fp222;
+LIBINT2_REALTYPE fp216;
+fp216 = fp221 + fp217;
+target[((hsi*45+14)*1+lsi)*1] = fp216;
+LIBINT2_REALTYPE fp227;
+fp227 = inteval->roe[vi] * src3[((hsi*28+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp226;
+fp226 = src2[((hsi*28+4)*1+lsi)*1] - fp227;
+LIBINT2_REALTYPE fp228;
+fp228 = 2 * inteval->oo2e[vi];
+LIBINT2_REALTYPE fp225;
+fp225 = fp228 * fp226;
+LIBINT2_REALTYPE fp230;
+fp230 = inteval->WQ_z[vi] * src1[((hsi*36+8)*1+lsi)*1];
+LIBINT2_REALTYPE fp231;
+fp231 = inteval->QC_z[vi] * src0[((hsi*36+8)*1+lsi)*1];
+LIBINT2_REALTYPE fp229;
+fp229 = fp231 + fp230;
+LIBINT2_REALTYPE fp224;
+fp224 = fp229 + fp225;
+target[((hsi*45+13)*1+lsi)*1] = fp224;
+LIBINT2_REALTYPE fp235;
+fp235 = inteval->roe[vi] * src3[((hsi*28+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp234;
+fp234 = src2[((hsi*28+3)*1+lsi)*1] - fp235;
+LIBINT2_REALTYPE fp233;
+fp233 = inteval->oo2e[vi] * fp234;
+LIBINT2_REALTYPE fp237;
+fp237 = inteval->WQ_z[vi] * src1[((hsi*36+7)*1+lsi)*1];
+LIBINT2_REALTYPE fp238;
+fp238 = inteval->QC_z[vi] * src0[((hsi*36+7)*1+lsi)*1];
+LIBINT2_REALTYPE fp236;
+fp236 = fp238 + fp237;
+LIBINT2_REALTYPE fp232;
+fp232 = fp236 + fp233;
+target[((hsi*45+12)*1+lsi)*1] = fp232;
+LIBINT2_REALTYPE fp240;
+fp240 = inteval->WQ_z[vi] * src1[((hsi*36+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp241;
+fp241 = inteval->QC_z[vi] * src0[((hsi*36+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp239;
+fp239 = fp241 + fp240;
+target[((hsi*45+11)*1+lsi)*1] = fp239;
+LIBINT2_REALTYPE fp245;
+fp245 = inteval->roe[vi] * src3[((hsi*28+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp244;
+fp244 = src2[((hsi*28+3)*1+lsi)*1] - fp245;
+LIBINT2_REALTYPE fp246;
+fp246 = 3 * inteval->oo2e[vi];
+LIBINT2_REALTYPE fp243;
+fp243 = fp246 * fp244;
+LIBINT2_REALTYPE fp248;
+fp248 = inteval->WQ_y[vi] * src1[((hsi*36+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp249;
+fp249 = inteval->QC_y[vi] * src0[((hsi*36+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp247;
+fp247 = fp249 + fp248;
+LIBINT2_REALTYPE fp242;
+fp242 = fp247 + fp243;
+target[((hsi*45+10)*1+lsi)*1] = fp242;
+LIBINT2_REALTYPE fp253;
+fp253 = inteval->roe[vi] * src3[((hsi*28+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp252;
+fp252 = src2[((hsi*28+2)*1+lsi)*1] - fp253;
+LIBINT2_REALTYPE fp254;
+fp254 = 2 * inteval->oo2e[vi];
+LIBINT2_REALTYPE fp251;
+fp251 = fp254 * fp252;
+LIBINT2_REALTYPE fp256;
+fp256 = inteval->WQ_z[vi] * src1[((hsi*36+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp257;
+fp257 = inteval->QC_z[vi] * src0[((hsi*36+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp255;
+fp255 = fp257 + fp256;
+LIBINT2_REALTYPE fp250;
+fp250 = fp255 + fp251;
+target[((hsi*45+9)*1+lsi)*1] = fp250;
+LIBINT2_REALTYPE fp261;
+fp261 = inteval->roe[vi] * src3[((hsi*28+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp260;
+fp260 = src2[((hsi*28+1)*1+lsi)*1] - fp261;
+LIBINT2_REALTYPE fp259;
+fp259 = inteval->oo2e[vi] * fp260;
+LIBINT2_REALTYPE fp263;
+fp263 = inteval->WQ_z[vi] * src1[((hsi*36+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp264;
+fp264 = inteval->QC_z[vi] * src0[((hsi*36+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp262;
+fp262 = fp264 + fp263;
+LIBINT2_REALTYPE fp258;
+fp258 = fp262 + fp259;
+target[((hsi*45+8)*1+lsi)*1] = fp258;
+LIBINT2_REALTYPE fp266;
+fp266 = inteval->WQ_z[vi] * src1[((hsi*36+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp267;
+fp267 = inteval->QC_z[vi] * src0[((hsi*36+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp265;
+fp265 = fp267 + fp266;
+target[((hsi*45+7)*1+lsi)*1] = fp265;
+LIBINT2_REALTYPE fp271;
+fp271 = inteval->roe[vi] * src3[((hsi*28+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp270;
+fp270 = src2[((hsi*28+1)*1+lsi)*1] - fp271;
+LIBINT2_REALTYPE fp272;
+fp272 = 2 * inteval->oo2e[vi];
+LIBINT2_REALTYPE fp269;
+fp269 = fp272 * fp270;
+LIBINT2_REALTYPE fp274;
+fp274 = inteval->WQ_y[vi] * src1[((hsi*36+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp275;
+fp275 = inteval->QC_y[vi] * src0[((hsi*36+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp273;
+fp273 = fp275 + fp274;
+LIBINT2_REALTYPE fp268;
+fp268 = fp273 + fp269;
+target[((hsi*45+6)*1+lsi)*1] = fp268;
+LIBINT2_REALTYPE fp279;
+fp279 = inteval->roe[vi] * src3[((hsi*28+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp278;
+fp278 = src2[((hsi*28+0)*1+lsi)*1] - fp279;
+LIBINT2_REALTYPE fp277;
+fp277 = inteval->oo2e[vi] * fp278;
+LIBINT2_REALTYPE fp281;
+fp281 = inteval->WQ_z[vi] * src1[((hsi*36+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp282;
+fp282 = inteval->QC_z[vi] * src0[((hsi*36+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp280;
+fp280 = fp282 + fp281;
+LIBINT2_REALTYPE fp276;
+fp276 = fp280 + fp277;
+target[((hsi*45+5)*1+lsi)*1] = fp276;
+LIBINT2_REALTYPE fp284;
+fp284 = inteval->WQ_z[vi] * src1[((hsi*36+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp285;
+fp285 = inteval->QC_z[vi] * src0[((hsi*36+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp283;
+fp283 = fp285 + fp284;
+target[((hsi*45+4)*1+lsi)*1] = fp283;
+LIBINT2_REALTYPE fp289;
+fp289 = inteval->roe[vi] * src3[((hsi*28+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp288;
+fp288 = src2[((hsi*28+0)*1+lsi)*1] - fp289;
+LIBINT2_REALTYPE fp287;
+fp287 = inteval->oo2e[vi] * fp288;
+LIBINT2_REALTYPE fp291;
+fp291 = inteval->WQ_y[vi] * src1[((hsi*36+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp292;
+fp292 = inteval->QC_y[vi] * src0[((hsi*36+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp290;
+fp290 = fp292 + fp291;
+LIBINT2_REALTYPE fp286;
+fp286 = fp290 + fp287;
+target[((hsi*45+3)*1+lsi)*1] = fp286;
+LIBINT2_REALTYPE fp294;
+fp294 = inteval->WQ_z[vi] * src1[((hsi*36+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp295;
+fp295 = inteval->QC_z[vi] * src0[((hsi*36+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp293;
+fp293 = fp295 + fp294;
+target[((hsi*45+2)*1+lsi)*1] = fp293;
+LIBINT2_REALTYPE fp297;
+fp297 = inteval->WQ_y[vi] * src1[((hsi*36+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp298;
+fp298 = inteval->QC_y[vi] * src0[((hsi*36+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp296;
+fp296 = fp298 + fp297;
+target[((hsi*45+1)*1+lsi)*1] = fp296;
+LIBINT2_REALTYPE fp302;
+fp302 = inteval->roe[vi] * src3[((hsi*28+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp301;
+fp301 = src2[((hsi*28+0)*1+lsi)*1] - fp302;
+LIBINT2_REALTYPE fp303;
+fp303 = 7 * inteval->oo2e[vi];
+LIBINT2_REALTYPE fp300;
+fp300 = fp303 * fp301;
+LIBINT2_REALTYPE fp305;
+fp305 = inteval->WQ_x[vi] * src1[((hsi*36+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp306;
+fp306 = inteval->QC_x[vi] * src0[((hsi*36+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp304;
+fp304 = fp306 + fp305;
+LIBINT2_REALTYPE fp299;
+fp299 = fp304 + fp300;
+target[((hsi*45+0)*1+lsi)*1] = fp299;
 LIBINT2_REALTYPE fp3;
 fp3 = inteval->roe[vi] * src3[((hsi*28+27)*1+lsi)*1];
 LIBINT2_REALTYPE fp2;
@@ -358,317 +671,6 @@ fp160 = fp162 + fp161;
 LIBINT2_REALTYPE fp156;
 fp156 = fp160 + fp157;
 target[((hsi*45+23)*1+lsi)*1] = fp156;
-LIBINT2_REALTYPE fp164;
-fp164 = inteval->WQ_z[vi] * src1[((hsi*36+15)*1+lsi)*1];
-LIBINT2_REALTYPE fp165;
-fp165 = inteval->QC_z[vi] * src0[((hsi*36+15)*1+lsi)*1];
-LIBINT2_REALTYPE fp163;
-fp163 = fp165 + fp164;
-target[((hsi*45+22)*1+lsi)*1] = fp163;
-LIBINT2_REALTYPE fp169;
-fp169 = inteval->roe[vi] * src3[((hsi*28+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp168;
-fp168 = src2[((hsi*28+10)*1+lsi)*1] - fp169;
-LIBINT2_REALTYPE fp170;
-fp170 = 5 * inteval->oo2e[vi];
-LIBINT2_REALTYPE fp167;
-fp167 = fp170 * fp168;
-LIBINT2_REALTYPE fp172;
-fp172 = inteval->WQ_y[vi] * src1[((hsi*36+15)*1+lsi)*1];
-LIBINT2_REALTYPE fp173;
-fp173 = inteval->QC_y[vi] * src0[((hsi*36+15)*1+lsi)*1];
-LIBINT2_REALTYPE fp171;
-fp171 = fp173 + fp172;
-LIBINT2_REALTYPE fp166;
-fp166 = fp171 + fp167;
-target[((hsi*45+21)*1+lsi)*1] = fp166;
-LIBINT2_REALTYPE fp177;
-fp177 = inteval->roe[vi] * src3[((hsi*28+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp176;
-fp176 = src2[((hsi*28+9)*1+lsi)*1] - fp177;
-LIBINT2_REALTYPE fp178;
-fp178 = 4 * inteval->oo2e[vi];
-LIBINT2_REALTYPE fp175;
-fp175 = fp178 * fp176;
-LIBINT2_REALTYPE fp180;
-fp180 = inteval->WQ_z[vi] * src1[((hsi*36+14)*1+lsi)*1];
-LIBINT2_REALTYPE fp181;
-fp181 = inteval->QC_z[vi] * src0[((hsi*36+14)*1+lsi)*1];
-LIBINT2_REALTYPE fp179;
-fp179 = fp181 + fp180;
-LIBINT2_REALTYPE fp174;
-fp174 = fp179 + fp175;
-target[((hsi*45+20)*1+lsi)*1] = fp174;
-LIBINT2_REALTYPE fp185;
-fp185 = inteval->roe[vi] * src3[((hsi*28+8)*1+lsi)*1];
-LIBINT2_REALTYPE fp184;
-fp184 = src2[((hsi*28+8)*1+lsi)*1] - fp185;
-LIBINT2_REALTYPE fp186;
-fp186 = 3 * inteval->oo2e[vi];
-LIBINT2_REALTYPE fp183;
-fp183 = fp186 * fp184;
-LIBINT2_REALTYPE fp188;
-fp188 = inteval->WQ_z[vi] * src1[((hsi*36+13)*1+lsi)*1];
-LIBINT2_REALTYPE fp189;
-fp189 = inteval->QC_z[vi] * src0[((hsi*36+13)*1+lsi)*1];
-LIBINT2_REALTYPE fp187;
-fp187 = fp189 + fp188;
-LIBINT2_REALTYPE fp182;
-fp182 = fp187 + fp183;
-target[((hsi*45+19)*1+lsi)*1] = fp182;
-LIBINT2_REALTYPE fp193;
-fp193 = inteval->roe[vi] * src3[((hsi*28+7)*1+lsi)*1];
-LIBINT2_REALTYPE fp192;
-fp192 = src2[((hsi*28+7)*1+lsi)*1] - fp193;
-LIBINT2_REALTYPE fp194;
-fp194 = 2 * inteval->oo2e[vi];
-LIBINT2_REALTYPE fp191;
-fp191 = fp194 * fp192;
-LIBINT2_REALTYPE fp196;
-fp196 = inteval->WQ_z[vi] * src1[((hsi*36+12)*1+lsi)*1];
-LIBINT2_REALTYPE fp197;
-fp197 = inteval->QC_z[vi] * src0[((hsi*36+12)*1+lsi)*1];
-LIBINT2_REALTYPE fp195;
-fp195 = fp197 + fp196;
-LIBINT2_REALTYPE fp190;
-fp190 = fp195 + fp191;
-target[((hsi*45+18)*1+lsi)*1] = fp190;
-LIBINT2_REALTYPE fp201;
-fp201 = inteval->roe[vi] * src3[((hsi*28+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp200;
-fp200 = src2[((hsi*28+6)*1+lsi)*1] - fp201;
-LIBINT2_REALTYPE fp199;
-fp199 = inteval->oo2e[vi] * fp200;
-LIBINT2_REALTYPE fp203;
-fp203 = inteval->WQ_z[vi] * src1[((hsi*36+11)*1+lsi)*1];
-LIBINT2_REALTYPE fp204;
-fp204 = inteval->QC_z[vi] * src0[((hsi*36+11)*1+lsi)*1];
-LIBINT2_REALTYPE fp202;
-fp202 = fp204 + fp203;
-LIBINT2_REALTYPE fp198;
-fp198 = fp202 + fp199;
-target[((hsi*45+17)*1+lsi)*1] = fp198;
-LIBINT2_REALTYPE fp206;
-fp206 = inteval->WQ_z[vi] * src1[((hsi*36+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp207;
-fp207 = inteval->QC_z[vi] * src0[((hsi*36+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp205;
-fp205 = fp207 + fp206;
-target[((hsi*45+16)*1+lsi)*1] = fp205;
-LIBINT2_REALTYPE fp211;
-fp211 = inteval->roe[vi] * src3[((hsi*28+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp210;
-fp210 = src2[((hsi*28+6)*1+lsi)*1] - fp211;
-LIBINT2_REALTYPE fp212;
-fp212 = 4 * inteval->oo2e[vi];
-LIBINT2_REALTYPE fp209;
-fp209 = fp212 * fp210;
-LIBINT2_REALTYPE fp214;
-fp214 = inteval->WQ_y[vi] * src1[((hsi*36+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp215;
-fp215 = inteval->QC_y[vi] * src0[((hsi*36+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp213;
-fp213 = fp215 + fp214;
-LIBINT2_REALTYPE fp208;
-fp208 = fp213 + fp209;
-target[((hsi*45+15)*1+lsi)*1] = fp208;
-LIBINT2_REALTYPE fp219;
-fp219 = inteval->roe[vi] * src3[((hsi*28+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp218;
-fp218 = src2[((hsi*28+5)*1+lsi)*1] - fp219;
-LIBINT2_REALTYPE fp220;
-fp220 = 3 * inteval->oo2e[vi];
-LIBINT2_REALTYPE fp217;
-fp217 = fp220 * fp218;
-LIBINT2_REALTYPE fp222;
-fp222 = inteval->WQ_z[vi] * src1[((hsi*36+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp223;
-fp223 = inteval->QC_z[vi] * src0[((hsi*36+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp221;
-fp221 = fp223 + fp222;
-LIBINT2_REALTYPE fp216;
-fp216 = fp221 + fp217;
-target[((hsi*45+14)*1+lsi)*1] = fp216;
-LIBINT2_REALTYPE fp227;
-fp227 = inteval->roe[vi] * src3[((hsi*28+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp226;
-fp226 = src2[((hsi*28+4)*1+lsi)*1] - fp227;
-LIBINT2_REALTYPE fp228;
-fp228 = 2 * inteval->oo2e[vi];
-LIBINT2_REALTYPE fp225;
-fp225 = fp228 * fp226;
-LIBINT2_REALTYPE fp230;
-fp230 = inteval->WQ_z[vi] * src1[((hsi*36+8)*1+lsi)*1];
-LIBINT2_REALTYPE fp231;
-fp231 = inteval->QC_z[vi] * src0[((hsi*36+8)*1+lsi)*1];
-LIBINT2_REALTYPE fp229;
-fp229 = fp231 + fp230;
-LIBINT2_REALTYPE fp224;
-fp224 = fp229 + fp225;
-target[((hsi*45+13)*1+lsi)*1] = fp224;
-LIBINT2_REALTYPE fp235;
-fp235 = inteval->roe[vi] * src3[((hsi*28+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp234;
-fp234 = src2[((hsi*28+3)*1+lsi)*1] - fp235;
-LIBINT2_REALTYPE fp233;
-fp233 = inteval->oo2e[vi] * fp234;
-LIBINT2_REALTYPE fp237;
-fp237 = inteval->WQ_z[vi] * src1[((hsi*36+7)*1+lsi)*1];
-LIBINT2_REALTYPE fp238;
-fp238 = inteval->QC_z[vi] * src0[((hsi*36+7)*1+lsi)*1];
-LIBINT2_REALTYPE fp236;
-fp236 = fp238 + fp237;
-LIBINT2_REALTYPE fp232;
-fp232 = fp236 + fp233;
-target[((hsi*45+12)*1+lsi)*1] = fp232;
-LIBINT2_REALTYPE fp240;
-fp240 = inteval->WQ_z[vi] * src1[((hsi*36+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp241;
-fp241 = inteval->QC_z[vi] * src0[((hsi*36+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp239;
-fp239 = fp241 + fp240;
-target[((hsi*45+11)*1+lsi)*1] = fp239;
-LIBINT2_REALTYPE fp245;
-fp245 = inteval->roe[vi] * src3[((hsi*28+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp244;
-fp244 = src2[((hsi*28+3)*1+lsi)*1] - fp245;
-LIBINT2_REALTYPE fp246;
-fp246 = 3 * inteval->oo2e[vi];
-LIBINT2_REALTYPE fp243;
-fp243 = fp246 * fp244;
-LIBINT2_REALTYPE fp248;
-fp248 = inteval->WQ_y[vi] * src1[((hsi*36+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp249;
-fp249 = inteval->QC_y[vi] * src0[((hsi*36+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp247;
-fp247 = fp249 + fp248;
-LIBINT2_REALTYPE fp242;
-fp242 = fp247 + fp243;
-target[((hsi*45+10)*1+lsi)*1] = fp242;
-LIBINT2_REALTYPE fp253;
-fp253 = inteval->roe[vi] * src3[((hsi*28+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp252;
-fp252 = src2[((hsi*28+2)*1+lsi)*1] - fp253;
-LIBINT2_REALTYPE fp254;
-fp254 = 2 * inteval->oo2e[vi];
-LIBINT2_REALTYPE fp251;
-fp251 = fp254 * fp252;
-LIBINT2_REALTYPE fp256;
-fp256 = inteval->WQ_z[vi] * src1[((hsi*36+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp257;
-fp257 = inteval->QC_z[vi] * src0[((hsi*36+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp255;
-fp255 = fp257 + fp256;
-LIBINT2_REALTYPE fp250;
-fp250 = fp255 + fp251;
-target[((hsi*45+9)*1+lsi)*1] = fp250;
-LIBINT2_REALTYPE fp261;
-fp261 = inteval->roe[vi] * src3[((hsi*28+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp260;
-fp260 = src2[((hsi*28+1)*1+lsi)*1] - fp261;
-LIBINT2_REALTYPE fp259;
-fp259 = inteval->oo2e[vi] * fp260;
-LIBINT2_REALTYPE fp263;
-fp263 = inteval->WQ_z[vi] * src1[((hsi*36+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp264;
-fp264 = inteval->QC_z[vi] * src0[((hsi*36+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp262;
-fp262 = fp264 + fp263;
-LIBINT2_REALTYPE fp258;
-fp258 = fp262 + fp259;
-target[((hsi*45+8)*1+lsi)*1] = fp258;
-LIBINT2_REALTYPE fp266;
-fp266 = inteval->WQ_z[vi] * src1[((hsi*36+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp267;
-fp267 = inteval->QC_z[vi] * src0[((hsi*36+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp265;
-fp265 = fp267 + fp266;
-target[((hsi*45+7)*1+lsi)*1] = fp265;
-LIBINT2_REALTYPE fp271;
-fp271 = inteval->roe[vi] * src3[((hsi*28+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp270;
-fp270 = src2[((hsi*28+1)*1+lsi)*1] - fp271;
-LIBINT2_REALTYPE fp272;
-fp272 = 2 * inteval->oo2e[vi];
-LIBINT2_REALTYPE fp269;
-fp269 = fp272 * fp270;
-LIBINT2_REALTYPE fp274;
-fp274 = inteval->WQ_y[vi] * src1[((hsi*36+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp275;
-fp275 = inteval->QC_y[vi] * src0[((hsi*36+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp273;
-fp273 = fp275 + fp274;
-LIBINT2_REALTYPE fp268;
-fp268 = fp273 + fp269;
-target[((hsi*45+6)*1+lsi)*1] = fp268;
-LIBINT2_REALTYPE fp279;
-fp279 = inteval->roe[vi] * src3[((hsi*28+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp278;
-fp278 = src2[((hsi*28+0)*1+lsi)*1] - fp279;
-LIBINT2_REALTYPE fp277;
-fp277 = inteval->oo2e[vi] * fp278;
-LIBINT2_REALTYPE fp281;
-fp281 = inteval->WQ_z[vi] * src1[((hsi*36+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp282;
-fp282 = inteval->QC_z[vi] * src0[((hsi*36+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp280;
-fp280 = fp282 + fp281;
-LIBINT2_REALTYPE fp276;
-fp276 = fp280 + fp277;
-target[((hsi*45+5)*1+lsi)*1] = fp276;
-LIBINT2_REALTYPE fp284;
-fp284 = inteval->WQ_z[vi] * src1[((hsi*36+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp285;
-fp285 = inteval->QC_z[vi] * src0[((hsi*36+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp283;
-fp283 = fp285 + fp284;
-target[((hsi*45+4)*1+lsi)*1] = fp283;
-LIBINT2_REALTYPE fp289;
-fp289 = inteval->roe[vi] * src3[((hsi*28+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp288;
-fp288 = src2[((hsi*28+0)*1+lsi)*1] - fp289;
-LIBINT2_REALTYPE fp287;
-fp287 = inteval->oo2e[vi] * fp288;
-LIBINT2_REALTYPE fp291;
-fp291 = inteval->WQ_y[vi] * src1[((hsi*36+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp292;
-fp292 = inteval->QC_y[vi] * src0[((hsi*36+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp290;
-fp290 = fp292 + fp291;
-LIBINT2_REALTYPE fp286;
-fp286 = fp290 + fp287;
-target[((hsi*45+3)*1+lsi)*1] = fp286;
-LIBINT2_REALTYPE fp294;
-fp294 = inteval->WQ_z[vi] * src1[((hsi*36+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp295;
-fp295 = inteval->QC_z[vi] * src0[((hsi*36+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp293;
-fp293 = fp295 + fp294;
-target[((hsi*45+2)*1+lsi)*1] = fp293;
-LIBINT2_REALTYPE fp297;
-fp297 = inteval->WQ_y[vi] * src1[((hsi*36+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp298;
-fp298 = inteval->QC_y[vi] * src0[((hsi*36+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp296;
-fp296 = fp298 + fp297;
-target[((hsi*45+1)*1+lsi)*1] = fp296;
-LIBINT2_REALTYPE fp302;
-fp302 = inteval->roe[vi] * src3[((hsi*28+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp301;
-fp301 = src2[((hsi*28+0)*1+lsi)*1] - fp302;
-LIBINT2_REALTYPE fp303;
-fp303 = 7 * inteval->oo2e[vi];
-LIBINT2_REALTYPE fp300;
-fp300 = fp303 * fp301;
-LIBINT2_REALTYPE fp305;
-fp305 = inteval->WQ_x[vi] * src1[((hsi*36+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp306;
-fp306 = inteval->QC_x[vi] * src0[((hsi*36+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp304;
-fp304 = fp306 + fp305;
-LIBINT2_REALTYPE fp299;
-fp299 = fp304 + fp300;
-target[((hsi*45+0)*1+lsi)*1] = fp299;
 }
 }
 }
@@ -678,4 +680,6 @@ const int vi = 0;
 /** Number of flops = 307 */
 }
 
+#ifdef __cplusplus
 };
+#endif
