@@ -1,6 +1,8 @@
 #include <libint2.h>
 
+#ifdef __cplusplus
 extern "C" {
+#endif
 void OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(const Libint_t* inteval, LIBINT2_REALTYPE* target, const LIBINT2_REALTYPE* src0, const LIBINT2_REALTYPE* src1, const LIBINT2_REALTYPE* src2, const LIBINT2_REALTYPE* src3) {
 
 LIBINT2_REALTYPE*const  stack = target;
@@ -10,6 +12,400 @@ const int hsi = 0;
 const int lsi = 0;
 {
 const int vi = 0;
+LIBINT2_REALTYPE fp201;
+fp201 = inteval->roe[vi] * src3[((hsi*36+14)*1+lsi)*1];
+LIBINT2_REALTYPE fp200;
+fp200 = src2[((hsi*36+14)*1+lsi)*1] - fp201;
+LIBINT2_REALTYPE fp202;
+fp202 = 5 * inteval->oo2e[vi];
+LIBINT2_REALTYPE fp199;
+fp199 = fp202 * fp200;
+LIBINT2_REALTYPE fp204;
+fp204 = inteval->WQ_z[vi] * src1[((hsi*45+20)*1+lsi)*1];
+LIBINT2_REALTYPE fp205;
+fp205 = inteval->QC_z[vi] * src0[((hsi*45+20)*1+lsi)*1];
+LIBINT2_REALTYPE fp203;
+fp203 = fp205 + fp204;
+LIBINT2_REALTYPE fp198;
+fp198 = fp203 + fp199;
+target[((hsi*55+27)*1+lsi)*1] = fp198;
+LIBINT2_REALTYPE fp209;
+fp209 = inteval->roe[vi] * src3[((hsi*36+13)*1+lsi)*1];
+LIBINT2_REALTYPE fp208;
+fp208 = src2[((hsi*36+13)*1+lsi)*1] - fp209;
+LIBINT2_REALTYPE fp210;
+fp210 = 4 * inteval->oo2e[vi];
+LIBINT2_REALTYPE fp207;
+fp207 = fp210 * fp208;
+LIBINT2_REALTYPE fp212;
+fp212 = inteval->WQ_z[vi] * src1[((hsi*45+19)*1+lsi)*1];
+LIBINT2_REALTYPE fp213;
+fp213 = inteval->QC_z[vi] * src0[((hsi*45+19)*1+lsi)*1];
+LIBINT2_REALTYPE fp211;
+fp211 = fp213 + fp212;
+LIBINT2_REALTYPE fp206;
+fp206 = fp211 + fp207;
+target[((hsi*55+26)*1+lsi)*1] = fp206;
+LIBINT2_REALTYPE fp217;
+fp217 = inteval->roe[vi] * src3[((hsi*36+12)*1+lsi)*1];
+LIBINT2_REALTYPE fp216;
+fp216 = src2[((hsi*36+12)*1+lsi)*1] - fp217;
+LIBINT2_REALTYPE fp218;
+fp218 = 3 * inteval->oo2e[vi];
+LIBINT2_REALTYPE fp215;
+fp215 = fp218 * fp216;
+LIBINT2_REALTYPE fp220;
+fp220 = inteval->WQ_z[vi] * src1[((hsi*45+18)*1+lsi)*1];
+LIBINT2_REALTYPE fp221;
+fp221 = inteval->QC_z[vi] * src0[((hsi*45+18)*1+lsi)*1];
+LIBINT2_REALTYPE fp219;
+fp219 = fp221 + fp220;
+LIBINT2_REALTYPE fp214;
+fp214 = fp219 + fp215;
+target[((hsi*55+25)*1+lsi)*1] = fp214;
+LIBINT2_REALTYPE fp225;
+fp225 = inteval->roe[vi] * src3[((hsi*36+11)*1+lsi)*1];
+LIBINT2_REALTYPE fp224;
+fp224 = src2[((hsi*36+11)*1+lsi)*1] - fp225;
+LIBINT2_REALTYPE fp226;
+fp226 = 2 * inteval->oo2e[vi];
+LIBINT2_REALTYPE fp223;
+fp223 = fp226 * fp224;
+LIBINT2_REALTYPE fp228;
+fp228 = inteval->WQ_z[vi] * src1[((hsi*45+17)*1+lsi)*1];
+LIBINT2_REALTYPE fp229;
+fp229 = inteval->QC_z[vi] * src0[((hsi*45+17)*1+lsi)*1];
+LIBINT2_REALTYPE fp227;
+fp227 = fp229 + fp228;
+LIBINT2_REALTYPE fp222;
+fp222 = fp227 + fp223;
+target[((hsi*55+24)*1+lsi)*1] = fp222;
+LIBINT2_REALTYPE fp233;
+fp233 = inteval->roe[vi] * src3[((hsi*36+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp232;
+fp232 = src2[((hsi*36+10)*1+lsi)*1] - fp233;
+LIBINT2_REALTYPE fp231;
+fp231 = inteval->oo2e[vi] * fp232;
+LIBINT2_REALTYPE fp235;
+fp235 = inteval->WQ_z[vi] * src1[((hsi*45+16)*1+lsi)*1];
+LIBINT2_REALTYPE fp236;
+fp236 = inteval->QC_z[vi] * src0[((hsi*45+16)*1+lsi)*1];
+LIBINT2_REALTYPE fp234;
+fp234 = fp236 + fp235;
+LIBINT2_REALTYPE fp230;
+fp230 = fp234 + fp231;
+target[((hsi*55+23)*1+lsi)*1] = fp230;
+LIBINT2_REALTYPE fp238;
+fp238 = inteval->WQ_z[vi] * src1[((hsi*45+15)*1+lsi)*1];
+LIBINT2_REALTYPE fp239;
+fp239 = inteval->QC_z[vi] * src0[((hsi*45+15)*1+lsi)*1];
+LIBINT2_REALTYPE fp237;
+fp237 = fp239 + fp238;
+target[((hsi*55+22)*1+lsi)*1] = fp237;
+LIBINT2_REALTYPE fp243;
+fp243 = inteval->roe[vi] * src3[((hsi*36+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp242;
+fp242 = src2[((hsi*36+10)*1+lsi)*1] - fp243;
+LIBINT2_REALTYPE fp244;
+fp244 = 5 * inteval->oo2e[vi];
+LIBINT2_REALTYPE fp241;
+fp241 = fp244 * fp242;
+LIBINT2_REALTYPE fp246;
+fp246 = inteval->WQ_y[vi] * src1[((hsi*45+15)*1+lsi)*1];
+LIBINT2_REALTYPE fp247;
+fp247 = inteval->QC_y[vi] * src0[((hsi*45+15)*1+lsi)*1];
+LIBINT2_REALTYPE fp245;
+fp245 = fp247 + fp246;
+LIBINT2_REALTYPE fp240;
+fp240 = fp245 + fp241;
+target[((hsi*55+21)*1+lsi)*1] = fp240;
+LIBINT2_REALTYPE fp251;
+fp251 = inteval->roe[vi] * src3[((hsi*36+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp250;
+fp250 = src2[((hsi*36+9)*1+lsi)*1] - fp251;
+LIBINT2_REALTYPE fp252;
+fp252 = 4 * inteval->oo2e[vi];
+LIBINT2_REALTYPE fp249;
+fp249 = fp252 * fp250;
+LIBINT2_REALTYPE fp254;
+fp254 = inteval->WQ_z[vi] * src1[((hsi*45+14)*1+lsi)*1];
+LIBINT2_REALTYPE fp255;
+fp255 = inteval->QC_z[vi] * src0[((hsi*45+14)*1+lsi)*1];
+LIBINT2_REALTYPE fp253;
+fp253 = fp255 + fp254;
+LIBINT2_REALTYPE fp248;
+fp248 = fp253 + fp249;
+target[((hsi*55+20)*1+lsi)*1] = fp248;
+LIBINT2_REALTYPE fp259;
+fp259 = inteval->roe[vi] * src3[((hsi*36+8)*1+lsi)*1];
+LIBINT2_REALTYPE fp258;
+fp258 = src2[((hsi*36+8)*1+lsi)*1] - fp259;
+LIBINT2_REALTYPE fp260;
+fp260 = 3 * inteval->oo2e[vi];
+LIBINT2_REALTYPE fp257;
+fp257 = fp260 * fp258;
+LIBINT2_REALTYPE fp262;
+fp262 = inteval->WQ_z[vi] * src1[((hsi*45+13)*1+lsi)*1];
+LIBINT2_REALTYPE fp263;
+fp263 = inteval->QC_z[vi] * src0[((hsi*45+13)*1+lsi)*1];
+LIBINT2_REALTYPE fp261;
+fp261 = fp263 + fp262;
+LIBINT2_REALTYPE fp256;
+fp256 = fp261 + fp257;
+target[((hsi*55+19)*1+lsi)*1] = fp256;
+LIBINT2_REALTYPE fp267;
+fp267 = inteval->roe[vi] * src3[((hsi*36+7)*1+lsi)*1];
+LIBINT2_REALTYPE fp266;
+fp266 = src2[((hsi*36+7)*1+lsi)*1] - fp267;
+LIBINT2_REALTYPE fp268;
+fp268 = 2 * inteval->oo2e[vi];
+LIBINT2_REALTYPE fp265;
+fp265 = fp268 * fp266;
+LIBINT2_REALTYPE fp270;
+fp270 = inteval->WQ_z[vi] * src1[((hsi*45+12)*1+lsi)*1];
+LIBINT2_REALTYPE fp271;
+fp271 = inteval->QC_z[vi] * src0[((hsi*45+12)*1+lsi)*1];
+LIBINT2_REALTYPE fp269;
+fp269 = fp271 + fp270;
+LIBINT2_REALTYPE fp264;
+fp264 = fp269 + fp265;
+target[((hsi*55+18)*1+lsi)*1] = fp264;
+LIBINT2_REALTYPE fp275;
+fp275 = inteval->roe[vi] * src3[((hsi*36+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp274;
+fp274 = src2[((hsi*36+6)*1+lsi)*1] - fp275;
+LIBINT2_REALTYPE fp273;
+fp273 = inteval->oo2e[vi] * fp274;
+LIBINT2_REALTYPE fp277;
+fp277 = inteval->WQ_z[vi] * src1[((hsi*45+11)*1+lsi)*1];
+LIBINT2_REALTYPE fp278;
+fp278 = inteval->QC_z[vi] * src0[((hsi*45+11)*1+lsi)*1];
+LIBINT2_REALTYPE fp276;
+fp276 = fp278 + fp277;
+LIBINT2_REALTYPE fp272;
+fp272 = fp276 + fp273;
+target[((hsi*55+17)*1+lsi)*1] = fp272;
+LIBINT2_REALTYPE fp280;
+fp280 = inteval->WQ_z[vi] * src1[((hsi*45+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp281;
+fp281 = inteval->QC_z[vi] * src0[((hsi*45+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp279;
+fp279 = fp281 + fp280;
+target[((hsi*55+16)*1+lsi)*1] = fp279;
+LIBINT2_REALTYPE fp285;
+fp285 = inteval->roe[vi] * src3[((hsi*36+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp284;
+fp284 = src2[((hsi*36+6)*1+lsi)*1] - fp285;
+LIBINT2_REALTYPE fp286;
+fp286 = 4 * inteval->oo2e[vi];
+LIBINT2_REALTYPE fp283;
+fp283 = fp286 * fp284;
+LIBINT2_REALTYPE fp288;
+fp288 = inteval->WQ_y[vi] * src1[((hsi*45+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp289;
+fp289 = inteval->QC_y[vi] * src0[((hsi*45+10)*1+lsi)*1];
+LIBINT2_REALTYPE fp287;
+fp287 = fp289 + fp288;
+LIBINT2_REALTYPE fp282;
+fp282 = fp287 + fp283;
+target[((hsi*55+15)*1+lsi)*1] = fp282;
+LIBINT2_REALTYPE fp293;
+fp293 = inteval->roe[vi] * src3[((hsi*36+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp292;
+fp292 = src2[((hsi*36+5)*1+lsi)*1] - fp293;
+LIBINT2_REALTYPE fp294;
+fp294 = 3 * inteval->oo2e[vi];
+LIBINT2_REALTYPE fp291;
+fp291 = fp294 * fp292;
+LIBINT2_REALTYPE fp296;
+fp296 = inteval->WQ_z[vi] * src1[((hsi*45+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp297;
+fp297 = inteval->QC_z[vi] * src0[((hsi*45+9)*1+lsi)*1];
+LIBINT2_REALTYPE fp295;
+fp295 = fp297 + fp296;
+LIBINT2_REALTYPE fp290;
+fp290 = fp295 + fp291;
+target[((hsi*55+14)*1+lsi)*1] = fp290;
+LIBINT2_REALTYPE fp301;
+fp301 = inteval->roe[vi] * src3[((hsi*36+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp300;
+fp300 = src2[((hsi*36+4)*1+lsi)*1] - fp301;
+LIBINT2_REALTYPE fp302;
+fp302 = 2 * inteval->oo2e[vi];
+LIBINT2_REALTYPE fp299;
+fp299 = fp302 * fp300;
+LIBINT2_REALTYPE fp304;
+fp304 = inteval->WQ_z[vi] * src1[((hsi*45+8)*1+lsi)*1];
+LIBINT2_REALTYPE fp305;
+fp305 = inteval->QC_z[vi] * src0[((hsi*45+8)*1+lsi)*1];
+LIBINT2_REALTYPE fp303;
+fp303 = fp305 + fp304;
+LIBINT2_REALTYPE fp298;
+fp298 = fp303 + fp299;
+target[((hsi*55+13)*1+lsi)*1] = fp298;
+LIBINT2_REALTYPE fp309;
+fp309 = inteval->roe[vi] * src3[((hsi*36+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp308;
+fp308 = src2[((hsi*36+3)*1+lsi)*1] - fp309;
+LIBINT2_REALTYPE fp307;
+fp307 = inteval->oo2e[vi] * fp308;
+LIBINT2_REALTYPE fp311;
+fp311 = inteval->WQ_z[vi] * src1[((hsi*45+7)*1+lsi)*1];
+LIBINT2_REALTYPE fp312;
+fp312 = inteval->QC_z[vi] * src0[((hsi*45+7)*1+lsi)*1];
+LIBINT2_REALTYPE fp310;
+fp310 = fp312 + fp311;
+LIBINT2_REALTYPE fp306;
+fp306 = fp310 + fp307;
+target[((hsi*55+12)*1+lsi)*1] = fp306;
+LIBINT2_REALTYPE fp314;
+fp314 = inteval->WQ_z[vi] * src1[((hsi*45+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp315;
+fp315 = inteval->QC_z[vi] * src0[((hsi*45+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp313;
+fp313 = fp315 + fp314;
+target[((hsi*55+11)*1+lsi)*1] = fp313;
+LIBINT2_REALTYPE fp319;
+fp319 = inteval->roe[vi] * src3[((hsi*36+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp318;
+fp318 = src2[((hsi*36+3)*1+lsi)*1] - fp319;
+LIBINT2_REALTYPE fp320;
+fp320 = 3 * inteval->oo2e[vi];
+LIBINT2_REALTYPE fp317;
+fp317 = fp320 * fp318;
+LIBINT2_REALTYPE fp322;
+fp322 = inteval->WQ_y[vi] * src1[((hsi*45+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp323;
+fp323 = inteval->QC_y[vi] * src0[((hsi*45+6)*1+lsi)*1];
+LIBINT2_REALTYPE fp321;
+fp321 = fp323 + fp322;
+LIBINT2_REALTYPE fp316;
+fp316 = fp321 + fp317;
+target[((hsi*55+10)*1+lsi)*1] = fp316;
+LIBINT2_REALTYPE fp327;
+fp327 = inteval->roe[vi] * src3[((hsi*36+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp326;
+fp326 = src2[((hsi*36+2)*1+lsi)*1] - fp327;
+LIBINT2_REALTYPE fp328;
+fp328 = 2 * inteval->oo2e[vi];
+LIBINT2_REALTYPE fp325;
+fp325 = fp328 * fp326;
+LIBINT2_REALTYPE fp330;
+fp330 = inteval->WQ_z[vi] * src1[((hsi*45+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp331;
+fp331 = inteval->QC_z[vi] * src0[((hsi*45+5)*1+lsi)*1];
+LIBINT2_REALTYPE fp329;
+fp329 = fp331 + fp330;
+LIBINT2_REALTYPE fp324;
+fp324 = fp329 + fp325;
+target[((hsi*55+9)*1+lsi)*1] = fp324;
+LIBINT2_REALTYPE fp335;
+fp335 = inteval->roe[vi] * src3[((hsi*36+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp334;
+fp334 = src2[((hsi*36+1)*1+lsi)*1] - fp335;
+LIBINT2_REALTYPE fp333;
+fp333 = inteval->oo2e[vi] * fp334;
+LIBINT2_REALTYPE fp337;
+fp337 = inteval->WQ_z[vi] * src1[((hsi*45+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp338;
+fp338 = inteval->QC_z[vi] * src0[((hsi*45+4)*1+lsi)*1];
+LIBINT2_REALTYPE fp336;
+fp336 = fp338 + fp337;
+LIBINT2_REALTYPE fp332;
+fp332 = fp336 + fp333;
+target[((hsi*55+8)*1+lsi)*1] = fp332;
+LIBINT2_REALTYPE fp340;
+fp340 = inteval->WQ_z[vi] * src1[((hsi*45+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp341;
+fp341 = inteval->QC_z[vi] * src0[((hsi*45+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp339;
+fp339 = fp341 + fp340;
+target[((hsi*55+7)*1+lsi)*1] = fp339;
+LIBINT2_REALTYPE fp345;
+fp345 = inteval->roe[vi] * src3[((hsi*36+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp344;
+fp344 = src2[((hsi*36+1)*1+lsi)*1] - fp345;
+LIBINT2_REALTYPE fp346;
+fp346 = 2 * inteval->oo2e[vi];
+LIBINT2_REALTYPE fp343;
+fp343 = fp346 * fp344;
+LIBINT2_REALTYPE fp348;
+fp348 = inteval->WQ_y[vi] * src1[((hsi*45+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp349;
+fp349 = inteval->QC_y[vi] * src0[((hsi*45+3)*1+lsi)*1];
+LIBINT2_REALTYPE fp347;
+fp347 = fp349 + fp348;
+LIBINT2_REALTYPE fp342;
+fp342 = fp347 + fp343;
+target[((hsi*55+6)*1+lsi)*1] = fp342;
+LIBINT2_REALTYPE fp353;
+fp353 = inteval->roe[vi] * src3[((hsi*36+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp352;
+fp352 = src2[((hsi*36+0)*1+lsi)*1] - fp353;
+LIBINT2_REALTYPE fp351;
+fp351 = inteval->oo2e[vi] * fp352;
+LIBINT2_REALTYPE fp355;
+fp355 = inteval->WQ_z[vi] * src1[((hsi*45+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp356;
+fp356 = inteval->QC_z[vi] * src0[((hsi*45+2)*1+lsi)*1];
+LIBINT2_REALTYPE fp354;
+fp354 = fp356 + fp355;
+LIBINT2_REALTYPE fp350;
+fp350 = fp354 + fp351;
+target[((hsi*55+5)*1+lsi)*1] = fp350;
+LIBINT2_REALTYPE fp358;
+fp358 = inteval->WQ_z[vi] * src1[((hsi*45+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp359;
+fp359 = inteval->QC_z[vi] * src0[((hsi*45+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp357;
+fp357 = fp359 + fp358;
+target[((hsi*55+4)*1+lsi)*1] = fp357;
+LIBINT2_REALTYPE fp363;
+fp363 = inteval->roe[vi] * src3[((hsi*36+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp362;
+fp362 = src2[((hsi*36+0)*1+lsi)*1] - fp363;
+LIBINT2_REALTYPE fp361;
+fp361 = inteval->oo2e[vi] * fp362;
+LIBINT2_REALTYPE fp365;
+fp365 = inteval->WQ_y[vi] * src1[((hsi*45+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp366;
+fp366 = inteval->QC_y[vi] * src0[((hsi*45+1)*1+lsi)*1];
+LIBINT2_REALTYPE fp364;
+fp364 = fp366 + fp365;
+LIBINT2_REALTYPE fp360;
+fp360 = fp364 + fp361;
+target[((hsi*55+3)*1+lsi)*1] = fp360;
+LIBINT2_REALTYPE fp368;
+fp368 = inteval->WQ_z[vi] * src1[((hsi*45+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp369;
+fp369 = inteval->QC_z[vi] * src0[((hsi*45+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp367;
+fp367 = fp369 + fp368;
+target[((hsi*55+2)*1+lsi)*1] = fp367;
+LIBINT2_REALTYPE fp371;
+fp371 = inteval->WQ_y[vi] * src1[((hsi*45+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp372;
+fp372 = inteval->QC_y[vi] * src0[((hsi*45+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp370;
+fp370 = fp372 + fp371;
+target[((hsi*55+1)*1+lsi)*1] = fp370;
+LIBINT2_REALTYPE fp376;
+fp376 = inteval->roe[vi] * src3[((hsi*36+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp375;
+fp375 = src2[((hsi*36+0)*1+lsi)*1] - fp376;
+LIBINT2_REALTYPE fp377;
+fp377 = 8 * inteval->oo2e[vi];
+LIBINT2_REALTYPE fp374;
+fp374 = fp377 * fp375;
+LIBINT2_REALTYPE fp379;
+fp379 = inteval->WQ_x[vi] * src1[((hsi*45+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp380;
+fp380 = inteval->QC_x[vi] * src0[((hsi*45+0)*1+lsi)*1];
+LIBINT2_REALTYPE fp378;
+fp378 = fp380 + fp379;
+LIBINT2_REALTYPE fp373;
+fp373 = fp378 + fp374;
+target[((hsi*55+0)*1+lsi)*1] = fp373;
 LIBINT2_REALTYPE fp3;
 fp3 = inteval->roe[vi] * src3[((hsi*36+35)*1+lsi)*1];
 LIBINT2_REALTYPE fp2;
@@ -433,400 +829,6 @@ fp195 = fp197 + fp196;
 LIBINT2_REALTYPE fp190;
 fp190 = fp195 + fp191;
 target[((hsi*55+28)*1+lsi)*1] = fp190;
-LIBINT2_REALTYPE fp201;
-fp201 = inteval->roe[vi] * src3[((hsi*36+14)*1+lsi)*1];
-LIBINT2_REALTYPE fp200;
-fp200 = src2[((hsi*36+14)*1+lsi)*1] - fp201;
-LIBINT2_REALTYPE fp202;
-fp202 = 5 * inteval->oo2e[vi];
-LIBINT2_REALTYPE fp199;
-fp199 = fp202 * fp200;
-LIBINT2_REALTYPE fp204;
-fp204 = inteval->WQ_z[vi] * src1[((hsi*45+20)*1+lsi)*1];
-LIBINT2_REALTYPE fp205;
-fp205 = inteval->QC_z[vi] * src0[((hsi*45+20)*1+lsi)*1];
-LIBINT2_REALTYPE fp203;
-fp203 = fp205 + fp204;
-LIBINT2_REALTYPE fp198;
-fp198 = fp203 + fp199;
-target[((hsi*55+27)*1+lsi)*1] = fp198;
-LIBINT2_REALTYPE fp209;
-fp209 = inteval->roe[vi] * src3[((hsi*36+13)*1+lsi)*1];
-LIBINT2_REALTYPE fp208;
-fp208 = src2[((hsi*36+13)*1+lsi)*1] - fp209;
-LIBINT2_REALTYPE fp210;
-fp210 = 4 * inteval->oo2e[vi];
-LIBINT2_REALTYPE fp207;
-fp207 = fp210 * fp208;
-LIBINT2_REALTYPE fp212;
-fp212 = inteval->WQ_z[vi] * src1[((hsi*45+19)*1+lsi)*1];
-LIBINT2_REALTYPE fp213;
-fp213 = inteval->QC_z[vi] * src0[((hsi*45+19)*1+lsi)*1];
-LIBINT2_REALTYPE fp211;
-fp211 = fp213 + fp212;
-LIBINT2_REALTYPE fp206;
-fp206 = fp211 + fp207;
-target[((hsi*55+26)*1+lsi)*1] = fp206;
-LIBINT2_REALTYPE fp217;
-fp217 = inteval->roe[vi] * src3[((hsi*36+12)*1+lsi)*1];
-LIBINT2_REALTYPE fp216;
-fp216 = src2[((hsi*36+12)*1+lsi)*1] - fp217;
-LIBINT2_REALTYPE fp218;
-fp218 = 3 * inteval->oo2e[vi];
-LIBINT2_REALTYPE fp215;
-fp215 = fp218 * fp216;
-LIBINT2_REALTYPE fp220;
-fp220 = inteval->WQ_z[vi] * src1[((hsi*45+18)*1+lsi)*1];
-LIBINT2_REALTYPE fp221;
-fp221 = inteval->QC_z[vi] * src0[((hsi*45+18)*1+lsi)*1];
-LIBINT2_REALTYPE fp219;
-fp219 = fp221 + fp220;
-LIBINT2_REALTYPE fp214;
-fp214 = fp219 + fp215;
-target[((hsi*55+25)*1+lsi)*1] = fp214;
-LIBINT2_REALTYPE fp225;
-fp225 = inteval->roe[vi] * src3[((hsi*36+11)*1+lsi)*1];
-LIBINT2_REALTYPE fp224;
-fp224 = src2[((hsi*36+11)*1+lsi)*1] - fp225;
-LIBINT2_REALTYPE fp226;
-fp226 = 2 * inteval->oo2e[vi];
-LIBINT2_REALTYPE fp223;
-fp223 = fp226 * fp224;
-LIBINT2_REALTYPE fp228;
-fp228 = inteval->WQ_z[vi] * src1[((hsi*45+17)*1+lsi)*1];
-LIBINT2_REALTYPE fp229;
-fp229 = inteval->QC_z[vi] * src0[((hsi*45+17)*1+lsi)*1];
-LIBINT2_REALTYPE fp227;
-fp227 = fp229 + fp228;
-LIBINT2_REALTYPE fp222;
-fp222 = fp227 + fp223;
-target[((hsi*55+24)*1+lsi)*1] = fp222;
-LIBINT2_REALTYPE fp233;
-fp233 = inteval->roe[vi] * src3[((hsi*36+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp232;
-fp232 = src2[((hsi*36+10)*1+lsi)*1] - fp233;
-LIBINT2_REALTYPE fp231;
-fp231 = inteval->oo2e[vi] * fp232;
-LIBINT2_REALTYPE fp235;
-fp235 = inteval->WQ_z[vi] * src1[((hsi*45+16)*1+lsi)*1];
-LIBINT2_REALTYPE fp236;
-fp236 = inteval->QC_z[vi] * src0[((hsi*45+16)*1+lsi)*1];
-LIBINT2_REALTYPE fp234;
-fp234 = fp236 + fp235;
-LIBINT2_REALTYPE fp230;
-fp230 = fp234 + fp231;
-target[((hsi*55+23)*1+lsi)*1] = fp230;
-LIBINT2_REALTYPE fp238;
-fp238 = inteval->WQ_z[vi] * src1[((hsi*45+15)*1+lsi)*1];
-LIBINT2_REALTYPE fp239;
-fp239 = inteval->QC_z[vi] * src0[((hsi*45+15)*1+lsi)*1];
-LIBINT2_REALTYPE fp237;
-fp237 = fp239 + fp238;
-target[((hsi*55+22)*1+lsi)*1] = fp237;
-LIBINT2_REALTYPE fp243;
-fp243 = inteval->roe[vi] * src3[((hsi*36+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp242;
-fp242 = src2[((hsi*36+10)*1+lsi)*1] - fp243;
-LIBINT2_REALTYPE fp244;
-fp244 = 5 * inteval->oo2e[vi];
-LIBINT2_REALTYPE fp241;
-fp241 = fp244 * fp242;
-LIBINT2_REALTYPE fp246;
-fp246 = inteval->WQ_y[vi] * src1[((hsi*45+15)*1+lsi)*1];
-LIBINT2_REALTYPE fp247;
-fp247 = inteval->QC_y[vi] * src0[((hsi*45+15)*1+lsi)*1];
-LIBINT2_REALTYPE fp245;
-fp245 = fp247 + fp246;
-LIBINT2_REALTYPE fp240;
-fp240 = fp245 + fp241;
-target[((hsi*55+21)*1+lsi)*1] = fp240;
-LIBINT2_REALTYPE fp251;
-fp251 = inteval->roe[vi] * src3[((hsi*36+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp250;
-fp250 = src2[((hsi*36+9)*1+lsi)*1] - fp251;
-LIBINT2_REALTYPE fp252;
-fp252 = 4 * inteval->oo2e[vi];
-LIBINT2_REALTYPE fp249;
-fp249 = fp252 * fp250;
-LIBINT2_REALTYPE fp254;
-fp254 = inteval->WQ_z[vi] * src1[((hsi*45+14)*1+lsi)*1];
-LIBINT2_REALTYPE fp255;
-fp255 = inteval->QC_z[vi] * src0[((hsi*45+14)*1+lsi)*1];
-LIBINT2_REALTYPE fp253;
-fp253 = fp255 + fp254;
-LIBINT2_REALTYPE fp248;
-fp248 = fp253 + fp249;
-target[((hsi*55+20)*1+lsi)*1] = fp248;
-LIBINT2_REALTYPE fp259;
-fp259 = inteval->roe[vi] * src3[((hsi*36+8)*1+lsi)*1];
-LIBINT2_REALTYPE fp258;
-fp258 = src2[((hsi*36+8)*1+lsi)*1] - fp259;
-LIBINT2_REALTYPE fp260;
-fp260 = 3 * inteval->oo2e[vi];
-LIBINT2_REALTYPE fp257;
-fp257 = fp260 * fp258;
-LIBINT2_REALTYPE fp262;
-fp262 = inteval->WQ_z[vi] * src1[((hsi*45+13)*1+lsi)*1];
-LIBINT2_REALTYPE fp263;
-fp263 = inteval->QC_z[vi] * src0[((hsi*45+13)*1+lsi)*1];
-LIBINT2_REALTYPE fp261;
-fp261 = fp263 + fp262;
-LIBINT2_REALTYPE fp256;
-fp256 = fp261 + fp257;
-target[((hsi*55+19)*1+lsi)*1] = fp256;
-LIBINT2_REALTYPE fp267;
-fp267 = inteval->roe[vi] * src3[((hsi*36+7)*1+lsi)*1];
-LIBINT2_REALTYPE fp266;
-fp266 = src2[((hsi*36+7)*1+lsi)*1] - fp267;
-LIBINT2_REALTYPE fp268;
-fp268 = 2 * inteval->oo2e[vi];
-LIBINT2_REALTYPE fp265;
-fp265 = fp268 * fp266;
-LIBINT2_REALTYPE fp270;
-fp270 = inteval->WQ_z[vi] * src1[((hsi*45+12)*1+lsi)*1];
-LIBINT2_REALTYPE fp271;
-fp271 = inteval->QC_z[vi] * src0[((hsi*45+12)*1+lsi)*1];
-LIBINT2_REALTYPE fp269;
-fp269 = fp271 + fp270;
-LIBINT2_REALTYPE fp264;
-fp264 = fp269 + fp265;
-target[((hsi*55+18)*1+lsi)*1] = fp264;
-LIBINT2_REALTYPE fp275;
-fp275 = inteval->roe[vi] * src3[((hsi*36+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp274;
-fp274 = src2[((hsi*36+6)*1+lsi)*1] - fp275;
-LIBINT2_REALTYPE fp273;
-fp273 = inteval->oo2e[vi] * fp274;
-LIBINT2_REALTYPE fp277;
-fp277 = inteval->WQ_z[vi] * src1[((hsi*45+11)*1+lsi)*1];
-LIBINT2_REALTYPE fp278;
-fp278 = inteval->QC_z[vi] * src0[((hsi*45+11)*1+lsi)*1];
-LIBINT2_REALTYPE fp276;
-fp276 = fp278 + fp277;
-LIBINT2_REALTYPE fp272;
-fp272 = fp276 + fp273;
-target[((hsi*55+17)*1+lsi)*1] = fp272;
-LIBINT2_REALTYPE fp280;
-fp280 = inteval->WQ_z[vi] * src1[((hsi*45+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp281;
-fp281 = inteval->QC_z[vi] * src0[((hsi*45+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp279;
-fp279 = fp281 + fp280;
-target[((hsi*55+16)*1+lsi)*1] = fp279;
-LIBINT2_REALTYPE fp285;
-fp285 = inteval->roe[vi] * src3[((hsi*36+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp284;
-fp284 = src2[((hsi*36+6)*1+lsi)*1] - fp285;
-LIBINT2_REALTYPE fp286;
-fp286 = 4 * inteval->oo2e[vi];
-LIBINT2_REALTYPE fp283;
-fp283 = fp286 * fp284;
-LIBINT2_REALTYPE fp288;
-fp288 = inteval->WQ_y[vi] * src1[((hsi*45+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp289;
-fp289 = inteval->QC_y[vi] * src0[((hsi*45+10)*1+lsi)*1];
-LIBINT2_REALTYPE fp287;
-fp287 = fp289 + fp288;
-LIBINT2_REALTYPE fp282;
-fp282 = fp287 + fp283;
-target[((hsi*55+15)*1+lsi)*1] = fp282;
-LIBINT2_REALTYPE fp293;
-fp293 = inteval->roe[vi] * src3[((hsi*36+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp292;
-fp292 = src2[((hsi*36+5)*1+lsi)*1] - fp293;
-LIBINT2_REALTYPE fp294;
-fp294 = 3 * inteval->oo2e[vi];
-LIBINT2_REALTYPE fp291;
-fp291 = fp294 * fp292;
-LIBINT2_REALTYPE fp296;
-fp296 = inteval->WQ_z[vi] * src1[((hsi*45+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp297;
-fp297 = inteval->QC_z[vi] * src0[((hsi*45+9)*1+lsi)*1];
-LIBINT2_REALTYPE fp295;
-fp295 = fp297 + fp296;
-LIBINT2_REALTYPE fp290;
-fp290 = fp295 + fp291;
-target[((hsi*55+14)*1+lsi)*1] = fp290;
-LIBINT2_REALTYPE fp301;
-fp301 = inteval->roe[vi] * src3[((hsi*36+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp300;
-fp300 = src2[((hsi*36+4)*1+lsi)*1] - fp301;
-LIBINT2_REALTYPE fp302;
-fp302 = 2 * inteval->oo2e[vi];
-LIBINT2_REALTYPE fp299;
-fp299 = fp302 * fp300;
-LIBINT2_REALTYPE fp304;
-fp304 = inteval->WQ_z[vi] * src1[((hsi*45+8)*1+lsi)*1];
-LIBINT2_REALTYPE fp305;
-fp305 = inteval->QC_z[vi] * src0[((hsi*45+8)*1+lsi)*1];
-LIBINT2_REALTYPE fp303;
-fp303 = fp305 + fp304;
-LIBINT2_REALTYPE fp298;
-fp298 = fp303 + fp299;
-target[((hsi*55+13)*1+lsi)*1] = fp298;
-LIBINT2_REALTYPE fp309;
-fp309 = inteval->roe[vi] * src3[((hsi*36+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp308;
-fp308 = src2[((hsi*36+3)*1+lsi)*1] - fp309;
-LIBINT2_REALTYPE fp307;
-fp307 = inteval->oo2e[vi] * fp308;
-LIBINT2_REALTYPE fp311;
-fp311 = inteval->WQ_z[vi] * src1[((hsi*45+7)*1+lsi)*1];
-LIBINT2_REALTYPE fp312;
-fp312 = inteval->QC_z[vi] * src0[((hsi*45+7)*1+lsi)*1];
-LIBINT2_REALTYPE fp310;
-fp310 = fp312 + fp311;
-LIBINT2_REALTYPE fp306;
-fp306 = fp310 + fp307;
-target[((hsi*55+12)*1+lsi)*1] = fp306;
-LIBINT2_REALTYPE fp314;
-fp314 = inteval->WQ_z[vi] * src1[((hsi*45+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp315;
-fp315 = inteval->QC_z[vi] * src0[((hsi*45+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp313;
-fp313 = fp315 + fp314;
-target[((hsi*55+11)*1+lsi)*1] = fp313;
-LIBINT2_REALTYPE fp319;
-fp319 = inteval->roe[vi] * src3[((hsi*36+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp318;
-fp318 = src2[((hsi*36+3)*1+lsi)*1] - fp319;
-LIBINT2_REALTYPE fp320;
-fp320 = 3 * inteval->oo2e[vi];
-LIBINT2_REALTYPE fp317;
-fp317 = fp320 * fp318;
-LIBINT2_REALTYPE fp322;
-fp322 = inteval->WQ_y[vi] * src1[((hsi*45+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp323;
-fp323 = inteval->QC_y[vi] * src0[((hsi*45+6)*1+lsi)*1];
-LIBINT2_REALTYPE fp321;
-fp321 = fp323 + fp322;
-LIBINT2_REALTYPE fp316;
-fp316 = fp321 + fp317;
-target[((hsi*55+10)*1+lsi)*1] = fp316;
-LIBINT2_REALTYPE fp327;
-fp327 = inteval->roe[vi] * src3[((hsi*36+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp326;
-fp326 = src2[((hsi*36+2)*1+lsi)*1] - fp327;
-LIBINT2_REALTYPE fp328;
-fp328 = 2 * inteval->oo2e[vi];
-LIBINT2_REALTYPE fp325;
-fp325 = fp328 * fp326;
-LIBINT2_REALTYPE fp330;
-fp330 = inteval->WQ_z[vi] * src1[((hsi*45+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp331;
-fp331 = inteval->QC_z[vi] * src0[((hsi*45+5)*1+lsi)*1];
-LIBINT2_REALTYPE fp329;
-fp329 = fp331 + fp330;
-LIBINT2_REALTYPE fp324;
-fp324 = fp329 + fp325;
-target[((hsi*55+9)*1+lsi)*1] = fp324;
-LIBINT2_REALTYPE fp335;
-fp335 = inteval->roe[vi] * src3[((hsi*36+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp334;
-fp334 = src2[((hsi*36+1)*1+lsi)*1] - fp335;
-LIBINT2_REALTYPE fp333;
-fp333 = inteval->oo2e[vi] * fp334;
-LIBINT2_REALTYPE fp337;
-fp337 = inteval->WQ_z[vi] * src1[((hsi*45+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp338;
-fp338 = inteval->QC_z[vi] * src0[((hsi*45+4)*1+lsi)*1];
-LIBINT2_REALTYPE fp336;
-fp336 = fp338 + fp337;
-LIBINT2_REALTYPE fp332;
-fp332 = fp336 + fp333;
-target[((hsi*55+8)*1+lsi)*1] = fp332;
-LIBINT2_REALTYPE fp340;
-fp340 = inteval->WQ_z[vi] * src1[((hsi*45+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp341;
-fp341 = inteval->QC_z[vi] * src0[((hsi*45+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp339;
-fp339 = fp341 + fp340;
-target[((hsi*55+7)*1+lsi)*1] = fp339;
-LIBINT2_REALTYPE fp345;
-fp345 = inteval->roe[vi] * src3[((hsi*36+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp344;
-fp344 = src2[((hsi*36+1)*1+lsi)*1] - fp345;
-LIBINT2_REALTYPE fp346;
-fp346 = 2 * inteval->oo2e[vi];
-LIBINT2_REALTYPE fp343;
-fp343 = fp346 * fp344;
-LIBINT2_REALTYPE fp348;
-fp348 = inteval->WQ_y[vi] * src1[((hsi*45+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp349;
-fp349 = inteval->QC_y[vi] * src0[((hsi*45+3)*1+lsi)*1];
-LIBINT2_REALTYPE fp347;
-fp347 = fp349 + fp348;
-LIBINT2_REALTYPE fp342;
-fp342 = fp347 + fp343;
-target[((hsi*55+6)*1+lsi)*1] = fp342;
-LIBINT2_REALTYPE fp353;
-fp353 = inteval->roe[vi] * src3[((hsi*36+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp352;
-fp352 = src2[((hsi*36+0)*1+lsi)*1] - fp353;
-LIBINT2_REALTYPE fp351;
-fp351 = inteval->oo2e[vi] * fp352;
-LIBINT2_REALTYPE fp355;
-fp355 = inteval->WQ_z[vi] * src1[((hsi*45+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp356;
-fp356 = inteval->QC_z[vi] * src0[((hsi*45+2)*1+lsi)*1];
-LIBINT2_REALTYPE fp354;
-fp354 = fp356 + fp355;
-LIBINT2_REALTYPE fp350;
-fp350 = fp354 + fp351;
-target[((hsi*55+5)*1+lsi)*1] = fp350;
-LIBINT2_REALTYPE fp358;
-fp358 = inteval->WQ_z[vi] * src1[((hsi*45+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp359;
-fp359 = inteval->QC_z[vi] * src0[((hsi*45+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp357;
-fp357 = fp359 + fp358;
-target[((hsi*55+4)*1+lsi)*1] = fp357;
-LIBINT2_REALTYPE fp363;
-fp363 = inteval->roe[vi] * src3[((hsi*36+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp362;
-fp362 = src2[((hsi*36+0)*1+lsi)*1] - fp363;
-LIBINT2_REALTYPE fp361;
-fp361 = inteval->oo2e[vi] * fp362;
-LIBINT2_REALTYPE fp365;
-fp365 = inteval->WQ_y[vi] * src1[((hsi*45+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp366;
-fp366 = inteval->QC_y[vi] * src0[((hsi*45+1)*1+lsi)*1];
-LIBINT2_REALTYPE fp364;
-fp364 = fp366 + fp365;
-LIBINT2_REALTYPE fp360;
-fp360 = fp364 + fp361;
-target[((hsi*55+3)*1+lsi)*1] = fp360;
-LIBINT2_REALTYPE fp368;
-fp368 = inteval->WQ_z[vi] * src1[((hsi*45+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp369;
-fp369 = inteval->QC_z[vi] * src0[((hsi*45+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp367;
-fp367 = fp369 + fp368;
-target[((hsi*55+2)*1+lsi)*1] = fp367;
-LIBINT2_REALTYPE fp371;
-fp371 = inteval->WQ_y[vi] * src1[((hsi*45+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp372;
-fp372 = inteval->QC_y[vi] * src0[((hsi*45+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp370;
-fp370 = fp372 + fp371;
-target[((hsi*55+1)*1+lsi)*1] = fp370;
-LIBINT2_REALTYPE fp376;
-fp376 = inteval->roe[vi] * src3[((hsi*36+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp375;
-fp375 = src2[((hsi*36+0)*1+lsi)*1] - fp376;
-LIBINT2_REALTYPE fp377;
-fp377 = 8 * inteval->oo2e[vi];
-LIBINT2_REALTYPE fp374;
-fp374 = fp377 * fp375;
-LIBINT2_REALTYPE fp379;
-fp379 = inteval->WQ_x[vi] * src1[((hsi*45+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp380;
-fp380 = inteval->QC_x[vi] * src0[((hsi*45+0)*1+lsi)*1];
-LIBINT2_REALTYPE fp378;
-fp378 = fp380 + fp379;
-LIBINT2_REALTYPE fp373;
-fp373 = fp378 + fp374;
-target[((hsi*55+0)*1+lsi)*1] = fp373;
 }
 }
 }
@@ -836,4 +838,6 @@ const int vi = 0;
 /** Number of flops = 381 */
 }
 
+#ifdef __cplusplus
 };
+#endif
