@@ -4,11 +4,16 @@
 #include <HRRPart1bra0ket0ip.h>
 #include <_aB_F__0__H__1___TwoPRep_S__0__D__1___Ab__up_0_prereq.h>
 
+#ifdef __cplusplus
 extern "C" {
+#endif
 void _aB_F__0__H__1___TwoPRep_S__0__D__1___Ab__up_0(const Libint_t* inteval) {
 
 _libint2_static_api_bzero_short_(inteval->stack+0*1,850)
 const int contrdepth = inteval->contrdepth;
+#ifdef __INTEL_COMPILER
+#pragma ivdep
+#endif
 for(int c = 0; c<contrdepth; c++) {
 _aB_F__0__H__1___TwoPRep_S__0__D__1___Ab__up_0_prereq(inteval+c, inteval->stack);
 }
@@ -20,17 +25,19 @@ const int hsi = 0;
 const int lsi = 0;
 {
 const int vi = 0;
-HRRPart1bra0ket0hp(inteval, &(stack[((hsi*630+2110)*1+lsi)*1]), &(stack[((hsi*280+210)*1+lsi)*1]), &(stack[((hsi*210+0)*1+lsi)*1]),10);
-HRRPart1bra0ket0ip(inteval, &(stack[((hsi*840+2740)*1+lsi)*1]), &(stack[((hsi*360+490)*1+lsi)*1]), &(stack[((hsi*280+210)*1+lsi)*1]),10);
-HRRPart1bra0ket0hd(inteval, &(stack[((hsi*1260+850)*1+lsi)*1]), &(stack[((hsi*840+2740)*1+lsi)*1]), &(stack[((hsi*630+2110)*1+lsi)*1]),10);
+HRRPart1bra0ket0hp(inteval, &(inteval->stack[((hsi*630+2110)*1+lsi)*1]), &(inteval->stack[((hsi*280+210)*1+lsi)*1]), &(inteval->stack[((hsi*210+0)*1+lsi)*1]),10);
+HRRPart1bra0ket0ip(inteval, &(inteval->stack[((hsi*840+2740)*1+lsi)*1]), &(inteval->stack[((hsi*360+490)*1+lsi)*1]), &(inteval->stack[((hsi*280+210)*1+lsi)*1]),10);
+HRRPart1bra0ket0hd(inteval, &(inteval->stack[((hsi*1260+850)*1+lsi)*1]), &(inteval->stack[((hsi*840+2740)*1+lsi)*1]), &(inteval->stack[((hsi*630+2110)*1+lsi)*1]),10);
 }
 }
 }
 const int hsi = 0;
 const int lsi = 0;
 const int vi = 0;
-inteval->targets[0] = &(stack[((hsi*1260+850)*1+lsi)*1]);
+inteval->targets[0] = &(inteval->stack[((hsi*1260+850)*1+lsi)*1]);
 /** Number of flops = 0 */
 }
 
+#ifdef __cplusplus
 };
+#endif
