@@ -3,11 +3,16 @@
 #include <HRRPart1bra0ket0kp.h>
 #include <_aB_F__0__K__1___TwoPRep_P__0__P__1___Ab__up_0_prereq.h>
 
+#ifdef __cplusplus
 extern "C" {
+#endif
 void _aB_F__0__K__1___TwoPRep_P__0__P__1___Ab__up_0(const Libint_t* inteval) {
 
 _libint2_static_api_bzero_short_(inteval->stack+0*1,2025)
 const int contrdepth = inteval->contrdepth;
+#ifdef __INTEL_COMPILER
+#pragma ivdep
+#endif
 for(int c = 0; c<contrdepth; c++) {
 _aB_F__0__K__1___TwoPRep_P__0__P__1___Ab__up_0_prereq(inteval+c, inteval->stack);
 }
@@ -19,17 +24,19 @@ const int hsi = 0;
 const int lsi = 0;
 {
 const int vi = 0;
-HRRPart1bra0ket0kp(inteval, &(stack[((hsi*1080+5265)*1+lsi)*1]), &(stack[((hsi*450+360)*1+lsi)*1]), &(stack[((hsi*360+0)*1+lsi)*1]),10);
-HRRPart1bra0ket0kp(inteval, &(stack[((hsi*1620+6345)*1+lsi)*1]), &(stack[((hsi*675+1350)*1+lsi)*1]), &(stack[((hsi*540+810)*1+lsi)*1]),15);
-HRRPart0bra0ket0fp(inteval, &(stack[((hsi*3240+2025)*1+lsi)*1]), &(stack[((hsi*1620+6345)*1+lsi)*1]), &(stack[((hsi*1080+5265)*1+lsi)*1]),108);
+HRRPart1bra0ket0kp(inteval, &(inteval->stack[((hsi*1080+5265)*1+lsi)*1]), &(inteval->stack[((hsi*450+360)*1+lsi)*1]), &(inteval->stack[((hsi*360+0)*1+lsi)*1]),10);
+HRRPart1bra0ket0kp(inteval, &(inteval->stack[((hsi*1620+6345)*1+lsi)*1]), &(inteval->stack[((hsi*675+1350)*1+lsi)*1]), &(inteval->stack[((hsi*540+810)*1+lsi)*1]),15);
+HRRPart0bra0ket0fp(inteval, &(inteval->stack[((hsi*3240+2025)*1+lsi)*1]), &(inteval->stack[((hsi*1620+6345)*1+lsi)*1]), &(inteval->stack[((hsi*1080+5265)*1+lsi)*1]),108);
 }
 }
 }
 const int hsi = 0;
 const int lsi = 0;
 const int vi = 0;
-inteval->targets[0] = &(stack[((hsi*3240+2025)*1+lsi)*1]);
+inteval->targets[0] = &(inteval->stack[((hsi*3240+2025)*1+lsi)*1]);
 /** Number of flops = 0 */
 }
 
+#ifdef __cplusplus
 };
+#endif
