@@ -2,11 +2,16 @@
 #include <HRRPart0bra0ket0fp.h>
 #include <_aB_F__0__K__1___TwoPRep_P__0__S__1___Ab__up_0_prereq.h>
 
+#ifdef __cplusplus
 extern "C" {
+#endif
 void _aB_F__0__K__1___TwoPRep_P__0__S__1___Ab__up_0(const Libint_t* inteval) {
 
 _libint2_static_api_bzero_short_(inteval->stack+0*1,900)
 const int contrdepth = inteval->contrdepth;
+#ifdef __INTEL_COMPILER
+#pragma ivdep
+#endif
 for(int c = 0; c<contrdepth; c++) {
 _aB_F__0__K__1___TwoPRep_P__0__S__1___Ab__up_0_prereq(inteval+c, inteval->stack);
 }
@@ -18,15 +23,17 @@ const int hsi = 0;
 const int lsi = 0;
 {
 const int vi = 0;
-HRRPart0bra0ket0fp(inteval, &(stack[((hsi*1080+900)*1+lsi)*1]), &(stack[((hsi*540+360)*1+lsi)*1]), &(stack[((hsi*360+0)*1+lsi)*1]),36);
+HRRPart0bra0ket0fp(inteval, &(inteval->stack[((hsi*1080+900)*1+lsi)*1]), &(inteval->stack[((hsi*540+360)*1+lsi)*1]), &(inteval->stack[((hsi*360+0)*1+lsi)*1]),36);
 }
 }
 }
 const int hsi = 0;
 const int lsi = 0;
 const int vi = 0;
-inteval->targets[0] = &(stack[((hsi*1080+900)*1+lsi)*1]);
+inteval->targets[0] = &(inteval->stack[((hsi*1080+900)*1+lsi)*1]);
 /** Number of flops = 0 */
 }
 
+#ifdef __cplusplus
 };
+#endif
