@@ -4,11 +4,16 @@
 #include <HRRPart1bra0ket0hp.h>
 #include <_aB_G__0__G__1___TwoPRep_S__0__D__1___Ab__up_0_prereq.h>
 
+#ifdef __cplusplus
 extern "C" {
+#endif
 void _aB_G__0__G__1___TwoPRep_S__0__D__1___Ab__up_0(const Libint_t* inteval) {
 
 _libint2_static_api_bzero_short_(inteval->stack+0*1,960)
 const int contrdepth = inteval->contrdepth;
+#ifdef __INTEL_COMPILER
+#pragma ivdep
+#endif
 for(int c = 0; c<contrdepth; c++) {
 _aB_G__0__G__1___TwoPRep_S__0__D__1___Ab__up_0_prereq(inteval+c, inteval->stack);
 }
@@ -20,17 +25,19 @@ const int hsi = 0;
 const int lsi = 0;
 {
 const int vi = 0;
-HRRPart1bra0ket0gp(inteval, &(stack[((hsi*675+2310)*1+lsi)*1]), &(stack[((hsi*315+225)*1+lsi)*1]), &(stack[((hsi*225+0)*1+lsi)*1]),15);
-HRRPart1bra0ket0hp(inteval, &(stack[((hsi*945+2985)*1+lsi)*1]), &(stack[((hsi*420+540)*1+lsi)*1]), &(stack[((hsi*315+225)*1+lsi)*1]),15);
-HRRPart1bra0ket0gd(inteval, &(stack[((hsi*1350+960)*1+lsi)*1]), &(stack[((hsi*945+2985)*1+lsi)*1]), &(stack[((hsi*675+2310)*1+lsi)*1]),15);
+HRRPart1bra0ket0gp(inteval, &(inteval->stack[((hsi*675+2310)*1+lsi)*1]), &(inteval->stack[((hsi*315+225)*1+lsi)*1]), &(inteval->stack[((hsi*225+0)*1+lsi)*1]),15);
+HRRPart1bra0ket0hp(inteval, &(inteval->stack[((hsi*945+2985)*1+lsi)*1]), &(inteval->stack[((hsi*420+540)*1+lsi)*1]), &(inteval->stack[((hsi*315+225)*1+lsi)*1]),15);
+HRRPart1bra0ket0gd(inteval, &(inteval->stack[((hsi*1350+960)*1+lsi)*1]), &(inteval->stack[((hsi*945+2985)*1+lsi)*1]), &(inteval->stack[((hsi*675+2310)*1+lsi)*1]),15);
 }
 }
 }
 const int hsi = 0;
 const int lsi = 0;
 const int vi = 0;
-inteval->targets[0] = &(stack[((hsi*1350+960)*1+lsi)*1]);
+inteval->targets[0] = &(inteval->stack[((hsi*1350+960)*1+lsi)*1]);
 /** Number of flops = 0 */
 }
 
+#ifdef __cplusplus
 };
+#endif
