@@ -3,11 +3,16 @@
 #include <HRRPart1bra0ket0ip.h>
 #include <_aB_G__0__I__1___TwoPRep_P__0__P__1___Ab__up_0_prereq.h>
 
+#ifdef __cplusplus
 extern "C" {
+#endif
 void _aB_G__0__I__1___TwoPRep_P__0__P__1___Ab__up_0(const Libint_t* inteval) {
 
 _libint2_static_api_bzero_short_(inteval->stack+0*1,2304)
 const int contrdepth = inteval->contrdepth;
+#ifdef __INTEL_COMPILER
+#pragma ivdep
+#endif
 for(int c = 0; c<contrdepth; c++) {
 _aB_G__0__I__1___TwoPRep_P__0__P__1___Ab__up_0_prereq(inteval+c, inteval->stack);
 }
@@ -19,17 +24,19 @@ const int hsi = 0;
 const int lsi = 0;
 {
 const int vi = 0;
-HRRPart1bra0ket0ip(inteval, &(stack[((hsi*1260+6084)*1+lsi)*1]), &(stack[((hsi*540+420)*1+lsi)*1]), &(stack[((hsi*420+0)*1+lsi)*1]),15);
-HRRPart1bra0ket0ip(inteval, &(stack[((hsi*1764+7344)*1+lsi)*1]), &(stack[((hsi*756+1548)*1+lsi)*1]), &(stack[((hsi*588+960)*1+lsi)*1]),21);
-HRRPart0bra0ket0gp(inteval, &(stack[((hsi*3780+2304)*1+lsi)*1]), &(stack[((hsi*1764+7344)*1+lsi)*1]), &(stack[((hsi*1260+6084)*1+lsi)*1]),84);
+HRRPart1bra0ket0ip(inteval, &(inteval->stack[((hsi*1260+6084)*1+lsi)*1]), &(inteval->stack[((hsi*540+420)*1+lsi)*1]), &(inteval->stack[((hsi*420+0)*1+lsi)*1]),15);
+HRRPart1bra0ket0ip(inteval, &(inteval->stack[((hsi*1764+7344)*1+lsi)*1]), &(inteval->stack[((hsi*756+1548)*1+lsi)*1]), &(inteval->stack[((hsi*588+960)*1+lsi)*1]),21);
+HRRPart0bra0ket0gp(inteval, &(inteval->stack[((hsi*3780+2304)*1+lsi)*1]), &(inteval->stack[((hsi*1764+7344)*1+lsi)*1]), &(inteval->stack[((hsi*1260+6084)*1+lsi)*1]),84);
 }
 }
 }
 const int hsi = 0;
 const int lsi = 0;
 const int vi = 0;
-inteval->targets[0] = &(stack[((hsi*3780+2304)*1+lsi)*1]);
+inteval->targets[0] = &(inteval->stack[((hsi*3780+2304)*1+lsi)*1]);
 /** Number of flops = 0 */
 }
 
+#ifdef __cplusplus
 };
+#endif
