@@ -1,11 +1,16 @@
 #include <libint2.h>
 #include <_aB_G__0__K__1___TwoPRep_S__0__S__1___Ab__up_0_prereq.h>
 
+#ifdef __cplusplus
 extern "C" {
+#endif
 void _aB_G__0__K__1___TwoPRep_S__0__S__1___Ab__up_0(const Libint_t* inteval) {
 
 _libint2_static_api_bzero_short_(inteval->stack+0*1,540)
 const int contrdepth = inteval->contrdepth;
+#ifdef __INTEL_COMPILER
+#pragma ivdep
+#endif
 for(int c = 0; c<contrdepth; c++) {
 _aB_G__0__K__1___TwoPRep_S__0__S__1___Ab__up_0_prereq(inteval+c, inteval->stack);
 }
@@ -23,8 +28,10 @@ const int vi = 0;
 const int hsi = 0;
 const int lsi = 0;
 const int vi = 0;
-inteval->targets[0] = &(stack[((hsi*540+0)*1+lsi)*1]);
+inteval->targets[0] = &(inteval->stack[((hsi*540+0)*1+lsi)*1]);
 /** Number of flops = 0 */
 }
 
+#ifdef __cplusplus
 };
+#endif
