@@ -2,11 +2,16 @@
 #include <HRRPart0bra0ket0pp.h>
 #include <_aB_P__0__H__1___TwoPRep_P__0__S__1___Ab__up_0_prereq.h>
 
+#ifdef __cplusplus
 extern "C" {
+#endif
 void _aB_P__0__H__1___TwoPRep_P__0__S__1___Ab__up_0(const Libint_t* inteval) {
 
 _libint2_static_api_bzero_short_(inteval->stack+0*1,189)
 const int contrdepth = inteval->contrdepth;
+#ifdef __INTEL_COMPILER
+#pragma ivdep
+#endif
 for(int c = 0; c<contrdepth; c++) {
 _aB_P__0__H__1___TwoPRep_P__0__S__1___Ab__up_0_prereq(inteval+c, inteval->stack);
 }
@@ -18,15 +23,17 @@ const int hsi = 0;
 const int lsi = 0;
 {
 const int vi = 0;
-HRRPart0bra0ket0pp(inteval, &(stack[((hsi*189+189)*1+lsi)*1]), &(stack[((hsi*126+63)*1+lsi)*1]), &(stack[((hsi*63+0)*1+lsi)*1]),21);
+HRRPart0bra0ket0pp(inteval, &(inteval->stack[((hsi*189+189)*1+lsi)*1]), &(inteval->stack[((hsi*126+63)*1+lsi)*1]), &(inteval->stack[((hsi*63+0)*1+lsi)*1]),21);
 }
 }
 }
 const int hsi = 0;
 const int lsi = 0;
 const int vi = 0;
-inteval->targets[0] = &(stack[((hsi*189+189)*1+lsi)*1]);
+inteval->targets[0] = &(inteval->stack[((hsi*189+189)*1+lsi)*1]);
 /** Number of flops = 0 */
 }
 
+#ifdef __cplusplus
 };
+#endif
