@@ -16,7 +16,9 @@
 #include <OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0.h>
 #include <OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0.h>
 
+#ifdef __cplusplus
 extern "C" {
+#endif
 void _aB_P__0__I__1___TwoPRep_S__0__G__1___Ab__up_0_prereq(const Libint_t* inteval, LIBINT2_REALTYPE* parent_stack) {
 
 LIBINT2_REALTYPE*const  stack = parent_stack;
@@ -110,4 +112,6 @@ const int vi = 0;
 /** Number of flops = 690 */
 }
 
+#ifdef __cplusplus
 };
+#endif
