@@ -4,11 +4,16 @@
 #include <HRRPart1bra0ket0lp.h>
 #include <_aB_P__0__K__1___TwoPRep_S__0__D__1___Ab__up_0_prereq.h>
 
+#ifdef __cplusplus
 extern "C" {
+#endif
 void _aB_P__0__K__1___TwoPRep_S__0__D__1___Ab__up_0(const Libint_t* inteval) {
 
 _libint2_static_api_bzero_short_(inteval->stack+0*1,408)
 const int contrdepth = inteval->contrdepth;
+#ifdef __INTEL_COMPILER
+#pragma ivdep
+#endif
 for(int c = 0; c<contrdepth; c++) {
 _aB_P__0__K__1___TwoPRep_S__0__D__1___Ab__up_0_prereq(inteval+c, inteval->stack);
 }
@@ -20,17 +25,19 @@ const int hsi = 0;
 const int lsi = 0;
 {
 const int vi = 0;
-HRRPart1bra0ket0kp(inteval, &(stack[((hsi*324+1056)*1+lsi)*1]), &(stack[((hsi*135+108)*1+lsi)*1]), &(stack[((hsi*108+0)*1+lsi)*1]),3);
-HRRPart1bra0ket0lp(inteval, &(stack[((hsi*405+1380)*1+lsi)*1]), &(stack[((hsi*165+243)*1+lsi)*1]), &(stack[((hsi*135+108)*1+lsi)*1]),3);
-HRRPart1bra0ket0kd(inteval, &(stack[((hsi*648+408)*1+lsi)*1]), &(stack[((hsi*405+1380)*1+lsi)*1]), &(stack[((hsi*324+1056)*1+lsi)*1]),3);
+HRRPart1bra0ket0kp(inteval, &(inteval->stack[((hsi*324+1056)*1+lsi)*1]), &(inteval->stack[((hsi*135+108)*1+lsi)*1]), &(inteval->stack[((hsi*108+0)*1+lsi)*1]),3);
+HRRPart1bra0ket0lp(inteval, &(inteval->stack[((hsi*405+1380)*1+lsi)*1]), &(inteval->stack[((hsi*165+243)*1+lsi)*1]), &(inteval->stack[((hsi*135+108)*1+lsi)*1]),3);
+HRRPart1bra0ket0kd(inteval, &(inteval->stack[((hsi*648+408)*1+lsi)*1]), &(inteval->stack[((hsi*405+1380)*1+lsi)*1]), &(inteval->stack[((hsi*324+1056)*1+lsi)*1]),3);
 }
 }
 }
 const int hsi = 0;
 const int lsi = 0;
 const int vi = 0;
-inteval->targets[0] = &(stack[((hsi*648+408)*1+lsi)*1]);
+inteval->targets[0] = &(inteval->stack[((hsi*648+408)*1+lsi)*1]);
 /** Number of flops = 0 */
 }
 
+#ifdef __cplusplus
 };
+#endif
