@@ -4,11 +4,16 @@
 #include <HRRPart1bra0ket0fp.h>
 #include <_aB_S__0__D__1___TwoPRep_S__0__D__1___Ab__up_0_prereq.h>
 
+#ifdef __cplusplus
 extern "C" {
+#endif
 void _aB_S__0__D__1___TwoPRep_S__0__D__1___Ab__up_0(const Libint_t* inteval) {
 
 _libint2_static_api_bzero_short_(inteval->stack+0*1,31)
 const int contrdepth = inteval->contrdepth;
+#ifdef __INTEL_COMPILER
+#pragma ivdep
+#endif
 for(int c = 0; c<contrdepth; c++) {
 _aB_S__0__D__1___TwoPRep_S__0__D__1___Ab__up_0_prereq(inteval+c, inteval->stack);
 }
@@ -20,17 +25,19 @@ const int hsi = 0;
 const int lsi = 0;
 {
 const int vi = 0;
-HRRPart1bra0ket0dp(inteval, &(stack[((hsi*18+67)*1+lsi)*1]), &(stack[((hsi*10+6)*1+lsi)*1]), &(stack[((hsi*6+0)*1+lsi)*1]),1);
-HRRPart1bra0ket0fp(inteval, &(stack[((hsi*30+85)*1+lsi)*1]), &(stack[((hsi*15+16)*1+lsi)*1]), &(stack[((hsi*10+6)*1+lsi)*1]),1);
-HRRPart1bra0ket0dd(inteval, &(stack[((hsi*36+31)*1+lsi)*1]), &(stack[((hsi*30+85)*1+lsi)*1]), &(stack[((hsi*18+67)*1+lsi)*1]),1);
+HRRPart1bra0ket0dp(inteval, &(inteval->stack[((hsi*18+67)*1+lsi)*1]), &(inteval->stack[((hsi*10+6)*1+lsi)*1]), &(inteval->stack[((hsi*6+0)*1+lsi)*1]),1);
+HRRPart1bra0ket0fp(inteval, &(inteval->stack[((hsi*30+85)*1+lsi)*1]), &(inteval->stack[((hsi*15+16)*1+lsi)*1]), &(inteval->stack[((hsi*10+6)*1+lsi)*1]),1);
+HRRPart1bra0ket0dd(inteval, &(inteval->stack[((hsi*36+31)*1+lsi)*1]), &(inteval->stack[((hsi*30+85)*1+lsi)*1]), &(inteval->stack[((hsi*18+67)*1+lsi)*1]),1);
 }
 }
 }
 const int hsi = 0;
 const int lsi = 0;
 const int vi = 0;
-inteval->targets[0] = &(stack[((hsi*36+31)*1+lsi)*1]);
+inteval->targets[0] = &(inteval->stack[((hsi*36+31)*1+lsi)*1]);
 /** Number of flops = 0 */
 }
 
+#ifdef __cplusplus
 };
+#endif
