@@ -2,7 +2,9 @@
 #include <GenericContract.h>
 #include <OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0.h>
 
+#ifdef __cplusplus
 extern "C" {
+#endif
 void _aB_S__0__P__1___TwoPRep_S__0__S__1___Ab__up_0_prereq(const Libint_t* inteval, LIBINT2_REALTYPE* parent_stack) {
 
 LIBINT2_REALTYPE*const  stack = parent_stack;
@@ -23,4 +25,6 @@ const int vi = 0;
 /** Number of flops = 3 */
 }
 
+#ifdef __cplusplus
 };
+#endif
