@@ -3,10 +3,15 @@
 #include <libint2_iface_internal.h>
 #include <cstddef>
 #include <cassert>
+#include <cstdlib>
+#ifdef __cplusplus
 extern "C" {
+#endif
 void (*libint2_build_default[8][8][8][8])(const Libint_t*);
 void (*libint2_build_eri[8][8][8][8])(const Libint_t*);
 void libint2_static_init() {
+libint2_build_eri[0][0][0][0] = _aB_S__0__S__1___TwoPRep_S__0__S__1___Ab__up_0;
+
 libint2_build_eri[0][0][1][0] = _aB_S__0__P__1___TwoPRep_S__0__S__1___Ab__up_0;
 
 libint2_build_eri[0][0][1][1] = _aB_S__0__P__1___TwoPRep_S__0__P__1___Ab__up_0;
@@ -1406,6 +1411,8 @@ libint2_build_eri[7][6][7][7] = _aB_K__0__K__1___TwoPRep_I__0__K__1___Ab__up_0;
 libint2_build_eri[7][7][7][7] = _aB_K__0__K__1___TwoPRep_K__0__K__1___Ab__up_0;
 
 }
+#ifdef __cplusplus
 };
+#endif
 
 
